function [new_age] = updateage(P)
% updateage  Updates the age of a population based on evaluation status.
%
% [new_age] = updateage(P)
%
% Inputs:
% P        = population structure
%
% Outputs:
%
% new_age  = vector of new ages
%
% Written by:
% S.D. Sudhoff
% School of Electrical and Computer Engineering
% 1285 Electrical Engineering Building
% West Lafayette, IN 47907-1285
% Phone: 765-494-3246
% Fax: 765-494-0676
% E-mail: sudhoff@ecn.purdue.edu

% intilize new_ages to 1
new_age=P.age;

% find population members who will age
update_indices=find(P.eval==1);

% update those population member who age one generation
new_age(update_indices)=new_age(update_indices)+1;

% find population members who age will be new (1 generation olds)
update_indices=find(P.eval==0);

% make these individuals 0 generation old
new_age(update_indices)=0;

%  Copyright 2010 - Scott Sudhoff 
% 
%  The program is distributed under the terms of the GNU Lesser
%  General Public License(GNU LGPL). 
% 
%  This file is part of GOSET
% 
%  GOSET is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published
%  by the Free Software Foundation, either version 3 of the License, or 
%  (at your option) any later version.
% 
%  GOSET is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
% 
%  You should have received a copy of the GNU Lesser General Public
%  License along with GOSET.  If not, see <http://www.gnu.org/licenses/>.
