function goset(varargin)

% GOSET GOSET GUI Version 2.3
%
% Coded by Yonggon Lee 
% yonggon@ecn.purdue.edu
% 08-14-2007

% -------------------------------------------------------------------------
%   INITIALIZATION
% -------------------------------------------------------------------------

testbtn = 0;            % testing button activation flag

VersionNo = '2.3';     % GOSET version

global simflag      % status flag  -1:stop 0:command mode 1:start&running 2:continue

figHandles = allchild(0);
figH = findobj(figHandles, 'flat', 'Name', ['GOSET v' VersionNo], 'Tag', 'GOSET GUI');

if nargin == 0                      % if there is no argument
    
    if ~isempty(figH)                   % if the GUI already exist,
        figure(figH);                           % activate it
        data = getappdata(figH, 'Userdata');    % get parameter data
        handles = guidata(figH);                % get handles of the GUI   
      
    else                                % if the GUI does not exist,

        % =================================================================
        %
        %
        %   INITIALIZE THE GUI PANEL
      %
    %
  %  
% =================================================================

% -------------------------------------------------------------------------
%   CREATE MAIN WINDOW
% -------------------------------------------------------------------------
set(0,'DefaultUIcontrolFontname','MS Sans Serif');  % Set default fontname

fWidth = 410;
fHeight = 452;

screen_s = get(0,'ScreenSize');     % detect current screen size
pos = [screen_s(3)/2 - fWidth/2, screen_s(4)/2 - fHeight/2, fWidth, fHeight];

figH = figure('Position',pos,'Resize','off','NumberTitle','off',...
    'Name',['GOSET v' VersionNo],'Interruptible','on',...
    'Menubar','none','Tag','GOSET GUI',...
    'CloseRequestFcn','goset(''closecheck'',gcbo,guidata(gcbo))',...
    'Color',get(0,'DefaultUIControlBackgroundColor'));

%set(figH,'Userdata',1)  % set the initialization flag to 1 (Abnormal initialization)

handles = guihandles(figH);
handles.figH = figH;

% -------------------------------------------------------------------------
%   LOAD GOSET GUI GRAHICS
% -------------------------------------------------------------------------
load gosetlogo.mat;

% -------------------------------------------------------------------------
%   TESTING BUTTON 
% -------------------------------------------------------------------------
if testbtn    
handles.testbtn = uicontrol('Style','pushbutton',...
      'Position',[0 353 190 100],'Backgroundcolor','y','String','Click me !!!',...
      'Fontsize',14,'Callback','goset(''testbtn'',gcbo,guidata(gcbo))');
uicontrol('Style','text','Position',[5 430 180 20],...
       'Backgroundcolor','k','Foregroundcolor','w','fontsize',12,...
       'String','BIG TEST BUTTON','Fontweight','Bold');
end
  
% -------------------------------------------------------------------------
%   LOAD THE LAST SETTING OF THE GOSET GUI
% -------------------------------------------------------------------------
location = which('goset.p');    % find the directory of GOSET.P file
if isempty(location)    % if GOSET.P does not exist, find the directory of GOSET.M file
    location = which('goset.m');
end
gosetpath = fileparts(location); 

initgosetsetting = 0;
if exist([gosetpath filesep 'goset.set'],'file')      % if the last setting file exists, LOAD
    load('-mat',[gosetpath filesep 'goset.set']);   
       
    % if 'recentfiles' exist, test the existence of each and fix any error
    if exist('recentfiles','var')
        recentfilesbuf = {'', '', '', '', '', ''}; 
        idx = 1;
        for i = 1:6
            if exist(recentfiles{i},'file')
               recentfilesbuf{idx} = recentfiles{i}; 
               idx = idx + 1;
            end
        end
        recentfiles = recentfilesbuf;
                
        if ~isempty(recentfiles{1})             % saved previous setting exists
            [lastpath,lastname] = fileparts(recentfiles{1});
            cd(lastpath);                       % change directory
            if exist([lastname '.set'],'file')  
                load('-mat',[lastname '.set']);     % load previous setting
                data = checksetting(data);          % check and fix setting
            else
                initgosetsetting = 1;
            end
        else                                    % no saved previous setting
            initgosetsetting = 1;
        end
    else
        recentfiles = {'', '', '', '', '', ''};  
        initgosetsetting = 1;
    end
else
    recentfiles = {'', '', '', '', '', ''};  
    initgosetsetting = 1;
end


if initgosetsetting
    data = gapdefault;              
    data.ff_name = 'Choose fitness function';
    data.ff_path = [];
    data.ff_data = [];
    data.ff_data_store = [];
    data.ngenes = 3;
    data.dspgene = 1;
    data.descgene = {'gene #1'  'gene #2'  'gene #3'};
    data.gd_min = [0 0 0];
    data.gd_max = [1 1 1];
    data.gd_type = [2 2 2];
    data.gd_cid = [1 1 1];  
    data.ur_pre = [];
    data.ur_post = [];
    nofitfun = 1;
else
    nofitfun = 0;
end

data.gosetpath = gosetpath;

GAS.cg = 1;     % set current generation as '1'
  
% -------------------------------------------------------------------------
%   MENU
% -------------------------------------------------------------------------
% === File ================================================================
% Data save and load
handles.filemenu=uimenu(gcf,'label','File');
uimenu(handles.filemenu,'label','Save current project',...
      'callback','goset(''savedata'',gcbo,guidata(gcbo))');
uimenu(handles.filemenu,'label','Load saved project',...
      'callback','goset(''loaddata'',gcbo,guidata(gcbo))');

% Handles for Recent files - No. # in 'Userdata' refer to recentfile{#}
handles.recentfile1 = uimenu(handles.filemenu,'Userdata','2',...
             'Separator','on','Callback','goset(''loadrecentfitfun'',gcbo,guidata(gcbo))');
for i = 2:5
    eval(['handles.recentfile' num2str(i) '=uimenu(handles.filemenu,''Userdata'',''' num2str(i+1)...
           ''',''callback'',''goset(''''loadrecentfitfun'''',gcbo,guidata(gcbo))'');']);
end

% Exit GOSET 
uimenu(handles.filemenu,'label','Exit GOSET','Separator','on','Accelerator','q',...
      'callback','goset(''closecheck'',gcbo,guidata(gcbo))');


% === Setting Save/Load Menu ==============================================
handles.setmenu=uimenu(gcf,'label','Setting');
uimenu(handles.setmenu,'label','View settings',...
      'callback','goset(''viewsetting'',gcbo,guidata(gcbo))');
uimenu(handles.setmenu,'label','Load default setting',...
      'callback','goset(''defaultsetting'',gcbo,guidata(gcbo))','separator','on');

% === Option Menu =========================================================
handles.optionmenu=uimenu(gcf,'label','Tools');
uimenu(handles.optionmenu,'label','Trim GA',...
      'callback','goset(''trim_ga'',gcbo,guidata(gcbo))');
uimenu(handles.optionmenu,'label','Extra user routines',...
      'callback','goset(''userroutine'',gcbo,guidata(gcbo))');
 
% === Help Menu============================================================
handles.helpmenu=uimenu(gcf,'label','Help');
uimenu(handles.helpmenu,'label','About GOSET',...
    'callback','goset(''aboutgoset'',gcbo,guidata(gcbo))');
uimenu(handles.helpmenu,'label','Forced Exit','Separator','on',...
      'callback','goset(''forcedexit'',gcbo,guidata(gcbo))');

% -------------------------------------------------------------------------
%   EVOLUTION STATUS DISPLAY
% -------------------------------------------------------------------------

xpos = 6;  ypos =222;

uicontrol('Style','frame','Position',[xpos ypos 180 110]);  % Frame
uicontrol('Style','text','Position',[xpos ypos+108 180 16],'Fontsize',10,...
      'BackgroundColor','K','ForegroundColor','W',...
      'Fontweight','bold','String','EVOLUTION STATUS');   
uicontrol('Style','text','Position',[xpos+10 ypos+55 100 16],...
      'HorizontalAlignment','Left','FontSize',10,'String','Generation #');
handles.cg=uicontrol('Style','text','Position',[xpos+105 ypos+56 60 15],...
      'HorizontalAlignment','Left','FontSize',10,'String','-'); 
uicontrol('Style','text','Position',[xpos+10 ypos+32 110 16],...
      'HorizontalAlignment','Left','FontSize',10,'String','Best fitness');  
handles.bestfit=uicontrol('Style','text','Position',[xpos+100 ypos+33 75 15],...
      'HorizontalAlignment','Left','FontSize',10,'String',' -'); 
uicontrol('Style','text','Position',[xpos+10 ypos+10 110 16],...
      'HorizontalAlignment','Left','FontSize',10,'String','Mean fitness');
handles.meanfit=uicontrol('Style','text','Position',[xpos+100 ypos+11 75 15],...
      'HorizontalAlignment','Left','FontSize',10,'String',' -'); 

%    pos = get(handles.pbar,'Position');  
uicontrol('Style','frame','Position',[xpos+5 ypos+78 170 24],...
      'BackgroundColor',[0.9 0.9 0.9],'ForegroundColor','k');  
handles.pbar=uicontrol('Style','text','Position',[xpos+5 ypos+80 170 20],...
    'BackgroundColor',[0 0 0.627],'ForegroundColor','w',...
    'String','Progress bar','Fontsize',12); 


% -------------------------------------------------------------------------
%   Output reporting
% -------------------------------------------------------------------------

ypos = 85;

uicontrol('Style','frame','Position',[xpos ypos 180 120]);  % Frame
uicontrol('Style','text','Position',[xpos ypos+115 180 16],'Fontsize',10,...
      'BackgroundColor','K','ForegroundColor','W',...
      'Fontweight','bold','String','OUTPUT REPORT');   
uicontrol('Style','text','Position',[xpos+10 ypos+88 110 18],...
      'HorizontalAlignment','Left','String','Report level');
handles.rp_lvl = uicontrol('Style','popupmenu','Position',...
      [xpos+80 ypos+92 90 18],'String',{'No reporting','Text only','Text & plot'},...
      'BackgroundColor','W','Value',data.rp_lvl+2,...
      'Callback','goset(''rp_lvl'',gcbo,guidata(gcbo))'); 
uicontrol('Style','text','Position',[xpos+10 ypos+64 165 18],...
      'HorizontalAlignment','Left','String','Report interval',...
      'ToolTipString','Report interval in generation');

if data.rp_lvl == -1
    rp_gbr_enable = 'off';
else
    rp_gbr_enable = 'on';   
end
handles.rp_gbr = uicontrol('Style','edit','Position',[xpos+110 ypos+67 60 18],...
      'String',data.rp_gbr,'Enable',rp_gbr_enable,'Backgroundcolor','w','Userdata',4,...
      'Callback','goset(''rp_gbr'',gcbo,guidata(gcbo))');
handles.rp_crh_browse = uicontrol('Style','Pushbutton','Position',...
      [xpos+8 ypos+39 50 23],'String','Custom',...
      'ToolTipString','Click to select an M-file for custom reporting',...
      'Callback','goset(''rp_crh_browse'',gcbo,guidata(gcbo))');
if isempty(data.rp_crh)
    rpcrhdisp = 'none';
    data.rp_crh = [];
else
    rpcrhdisp = [data.rp_crh,'.m'];
end  
handles.rp_crh = uicontrol('Style','text','Position',[xpos+59 ypos+42 93 16],...
    'BackgroundColor','W','String',rpcrhdisp);    
handles.rp_crh_reset = uicontrol('Style','Pushbutton','Position',...
      [xpos+150 ypos+39 23 23],'String','R','Fontsize',8,...
      'Fontweight','bold',...
      'ToolTipString','Reset the custom reporting file',...
      'Callback','goset(''rp_crh_reset'',gcbo,guidata(gcbo))');
handles.plotdata = uicontrol('Style','Pushbutton','Position',[xpos+8 ypos+6 80 26],...
      'HorizontalAlignment','Center','String','Plot current',...
      'Callback','goset(''plotdata'',gcbo,guidata(gcbo))');
handles.dispbst = uicontrol('Style','Pushbutton','Position',[xpos+93 ypos+6 80 26],...
      'HorizontalAlignment','Center','String','Display best',...
      'Callback','goset(''dispbst'',gcbo,guidata(gcbo))');

  
% -------------------------------------------------------------------------
%     Main buttons
% -------------------------------------------------------------------------
ypos = 7;

uicontrol('Style','frame','Position',[xpos ypos 180 70]);  % Frame

% === The START button ====================================================
handles.startbtn=uicontrol('Style','pushbutton',...
      'Position',[xpos+9 ypos+5 75 60],...
      'CData',startbutton,'Interruptible','on',...
      'BusyAction','queue',...
      'Callback','goset(''startbtn'',gcbo,guidata(gcbo))');

handles.startbtnoff=uicontrol('Style','pushbutton',...
      'Position',[xpos+9 ypos+5 75 60],'CData',startbuttonoff,...
      'Interruptible','on','BusyAction','queue','visible','off','Enable','off');
  
% === The STOP button =====================================================
handles.stopbtn=uicontrol('Style','pushbutton',...
      'Position',[xpos+95 ypos+5 75 60],'CData',stopbutton,...
      'Interruptible','on','BusyAction','queue','visible','off',...
      'Callback','goset(''stopbtn'',gcbo,guidata(gcbo))');

handles.stopbtnoff=uicontrol('Style','pushbutton',...
      'Position',[xpos+95 ypos+5 75 60],'CData',stopbuttonoff,...
      'Interruptible','on','BusyAction','queue','Enable','off');  
 
% === The CONTINUE button =================================================
handles.contbtn=uicontrol('Style','pushbutton',...
      'Position',[xpos+95 ypos+5 75 60],...
      'CData',contbutton,'Interruptible','on',...
      'BusyAction','queue','Visible','off',...
      'Callback','goset(''contbtn'',gcbo,guidata(gcbo))');  
handles.contbtnoff=uicontrol('Style','pushbutton',...
      'Position',[xpos+95 ypos+5 75 60],'CData',contbuttonoff,...
      'Interruptible','on','BusyAction','queue','Visible','off','Enable','off'); 
  
% -------------------------------------------------------------------------
%   Main windows 
% -------------------------------------------------------------------------
gaopbtnbgd = [0.8 0.8 0.8];
gaopacton = 'w';
gaopactoff = [0.7 0.7 0.7];
gaopbtnwdt = 210; 
gaopbtnhgt = 27;
gaopbtnspc = 28;

% === Fitness function ====================================================

xpos = 194; ypos = 400;

handles.ff_btn=uicontrol('Style','pushbutton','position',[xpos ypos+23 gaopbtnwdt gaopbtnhgt],...
   'ForegroundColor',[0 0 0.6],'Backgroundcolor',[0.75 0.75 0.8],...
   'String','Fitness function','Fontsize',12,'Fontweight','Bold',......
   'Callback','goset(''ff_btn'',gcbo,guidata(gcbo))');

handles.ff_subfld=uicontrol('Style','Frame','position',[xpos+1 ypos+1 gaopbtnwdt-1 22],...
    'Foregroundcolor','w','Backgroundcolor',gaopbtnbgd);

if data.fp_nobj == 1;
    objmode = 'S'; objmodetip = 'Single-objective optimization';
else 
    objmode = 'M'; objmodetip = 'Multi-objective optimization';
end

if strcmp(data.ff_name,'Choose fitness function');
    str_ff_dsp = data.ff_name;
    fclr = 'R';
    objmode = ''; objmodetip = '';
else
    str_ff_dsp = [data.ff_name '.m'];
    fclr = 'K';
end
handles.ff_dsp=uicontrol('Style','text','position',[xpos+40 ypos+5 gaopbtnwdt-65 14],...
   'String',str_ff_dsp,'ForegroundColor',fclr,...
   'HorizontalAlignment','center','BackgroundColor','W');
handles.ff_mode=uicontrol('Style','text','position',[xpos+24 ypos+5 12 14],...
   'String',objmode,'ForegroundColor',[0 0 0.6],'Fontweight','Bold',...
   'HorizontalAlignment','Center','BackgroundColor','W',...
   'Tooltipstring',objmodetip);

% === Gene Parameters =====================================================

ypos = ypos-gaopbtnspc;

handles.gp_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Gene parameters','Fontsize',12,'Fontweight','Bold',...
   'ForegroundColor',[0 0 0.6],'Backgroundcolor',gaopbtnbgd,...
   'Callback','goset(''gp_btn'',gcbo,guidata(gcbo))');

% === Fundamental Parameters ==============================================

ypos = ypos-gaopbtnspc;

handles.fp_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Fundamental parameters','Fontsize',12,'Fontweight','Bold',...
   'ForegroundColor',[0 0 0.6],'Backgroundcolor',gaopbtnbgd,...
   'Callback','goset(''fp_btn'',gcbo,guidata(gcbo))');


% === Diversity control ===================================================
if data.dc_act 
    actflg = 'on'; actbgd = gaopacton; 
else 
    actflg = 'off'; actbgd = gaopactoff;
end
ypos = ypos-gaopbtnspc;
handles.dc_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Diversity control','Fontsize',12,'Fontweight','Bold','Enable',actflg,...
   'Foregroundcolor',0.25*ones(1,3),'Backgroundcolor',gaopbtnbgd,...
   'Callback','goset(''dc_btn'',gcbo,guidata(gcbo))');
handles.dc_act=uicontrol('Style','togglebutton','position',[xpos+5 ypos+5 18 18],...
    'value',data.dc_act,'BackgroundColor',actbgd,'ToolTipString',...
    'Activate diversity control',...
    'Callback','goset(''dc_act'',gcbo,guidata(gcbo))');

% === Scaling Operator ====================================================

ypos = ypos-gaopbtnspc;    
       
handles.sc_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Scaling','Fontsize',12,'Fontweight','Bold','Backgroundcolor',gaopbtnbgd,...
   'Foregroundcolor',0.25*ones(1,3),'Callback','goset(''sc_btn'',gcbo,guidata(gcbo))');

% === Selection Operator ==================================================

ypos = ypos-gaopbtnspc;

handles.sl_btn=uicontrol('Style','pushbutton','position',...
        [xpos ypos gaopbtnwdt gaopbtnhgt],...
        'String','Selection','Fontsize',12,'Fontweight','Bold',...
        'Backgroundcolor',gaopbtnbgd,'Foregroundcolor',0.25*ones(1,3),...
        'Callback','goset(''sl_btn'',gcbo,guidata(gcbo))');

% === Death Operator ======================================================

ypos = ypos-gaopbtnspc;

handles.dt_btn=uicontrol('Style','pushbutton','position',...
        [xpos ypos gaopbtnwdt gaopbtnhgt],...
        'String','Death','Fontsize',12,'Fontweight','Bold',...
        'Backgroundcolor',gaopbtnbgd,'Foregroundcolor',0.25*ones(1,3),...
        'Callback','goset(''dt_btn'',gcbo,guidata(gcbo))');

% === Mating and Crossover Operator =======================================

ypos = ypos-gaopbtnspc;
   
handles.mc_btn=uicontrol('Style','pushbutton','position',...
        [xpos ypos gaopbtnwdt gaopbtnhgt],...
        'String','Mating crossover','Fontsize',12,'Fontweight','Bold',...
        'Backgroundcolor',gaopbtnbgd,'Foregroundcolor',0.25*ones(1,3),...
        'Callback','goset(''mc_btn'',gcbo,guidata(gcbo))');
    
% === Mutation Operator ===================================================

ypos = ypos-gaopbtnspc;
 
handles.mt_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Mutation','Fontsize',12,'Fontweight','Bold','Backgroundcolor',gaopbtnbgd,...
   'Foregroundcolor',0.25*ones(1,3),'Callback','goset(''mt_btn'',gcbo,guidata(gcbo))');

% === Gene Repair =======================================

ypos = ypos-gaopbtnspc;
 
handles.gr_btn=uicontrol('Style','pushbutton','position',...
        [xpos ypos gaopbtnwdt gaopbtnhgt],...
        'String','Gene repair','Fontsize',12,'Fontweight','Bold',...
        'Backgroundcolor',gaopbtnbgd,'Foregroundcolor',0.25*ones(1,3),...
        'Callback','goset(''gr_btn'',gcbo,guidata(gcbo))');

% === Migration Operator ==================================================

ypos = ypos-gaopbtnspc;

handles.mg_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Migration','Fontsize',12,'Fontweight','Bold','Backgroundcolor',gaopbtnbgd,...
   'Foregroundcolor',0.25*ones(1,3),'Callback','goset(''mg_btn'',gcbo,guidata(gcbo))');

% === Evaluation option ===================================================

ypos = ypos-gaopbtnspc;

handles.ev_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Evaluation option','Fontsize',12,'Fontweight','Bold',...
   'Foregroundcolor',0.25*ones(1,3),'Backgroundcolor',gaopbtnbgd,...
   'Callback','goset(''ev_btn'',gcbo,guidata(gcbo))');

% === Elitism Operator ====================================================
if data.el_act 
    actflg = 'on'; actbgd = gaopacton; 
else 
    actflg = 'off'; actbgd = gaopactoff;
end
ypos = ypos-gaopbtnspc;
handles.el_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Elitism ','Fontsize',12,'Fontweight','Bold','Backgroundcolor',gaopbtnbgd,'Enable',actflg,...
   'Foregroundcolor',0.25*ones(1,3),'Callback','goset(''el_btn'',gcbo,guidata(gcbo))');
handles.el_act=uicontrol('Style','togglebutton','position',[xpos+5 ypos+5 18 18],...
    'value',data.el_act,'BackgroundColor',actbgd,'ToolTipString',...
    'Activate elitism','Callback','goset(''el_act'',gcbo,guidata(gcbo))');

    
% === Random Search Operator ==============================================

ypos = ypos-gaopbtnspc;
                           
handles.rs_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Random search','Fontsize',12,'Fontweight','Bold','Backgroundcolor',gaopbtnbgd,...
   'Foregroundcolor',0.25*ones(1,3),'Callback','goset(''rs_btn'',gcbo,guidata(gcbo))');


% === Output Report =======================================================
    
ypos = ypos-gaopbtnspc;
                           
handles.or_btn=uicontrol('Style','pushbutton','position',[xpos ypos gaopbtnwdt gaopbtnhgt],...
   'String','Plotting parameters','Fontsize',12,'Fontweight','Bold',...
   'ForegroundColor',[0 0 0.6],'Backgroundcolor',[0.75 0.75 0.8],...
   'Callback','goset(''or_btn'',gcbo,guidata(gcbo))');

% -------------------------------------------------------------------------
%   LOAD GOSET GUI LOGO 
% -------------------------------------------------------------------------
dsrdW = 188;                        % desired width
dsrdH = 100;                        % desired height
banner = axes('Position',[0 (fHeight-dsrdH)/fHeight dsrdW/fWidth dsrdH/fHeight]);
axes(banner);                       % make the axis current
image(gosetlogo);                   % display the logo image
set(banner,'Visible','off');        % Remove the axis
text(140,85,['v' VersionNo],'FontSize',14,'Color','w');

 % -------------------------------------------------------------------------
%   Input windows 
% -------------------------------------------------------------------------

% === The Fitness Function button =========================================
xpos = 190;
ypos = fHeight/2-100;

handles.ff_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 190],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.ff_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 190],...
    'Visible','off','BackgroundColor','w');
handles.ff_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 184],...
    'Visible','off');
handles.ff_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+160 206 25],...
    'String','Fitness Function','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.ff_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''ff_inbxapp'',gcbo,guidata(gcbo))');
handles.ff_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''ff_inbxcncl'',gcbo,guidata(gcbo))'); 
handles.ff_name_txt=uicontrol('Style','text','Position',[xpos+15 ypos+130 160 18],...
    'HorizontalAlignment','Left','String','Fitness function file',...
    'Fontweight','Bold','ToolTipString','Name of the fitness function mfile',...
    'Visible','off');
handles.ff_name_browse=uicontrol('Style','pushbutton','Position',...
      [xpos+150 ypos+132 50 18],'String','Browse',...
      'Callback','goset(''ff_name_browse'',gcbo,guidata(gcbo))','Visible','off');
handles.ff_name=uicontrol('Style','text','Position',[xpos+15 ypos+114 185 15],...
    'BackgroundColor','W','Foregroundcolor',fclr,'String',str_ff_dsp,'Visible','off'); 
handles.ff_data_txt=uicontrol('Style','text','Position',[xpos+15 ypos+81 160 18],...
    'HorizontalAlignment','Left','String','Fitness function data',...
    'Fontweight','Bold','ToolTipString','Optional data for fitness function',...
    'Visible','off');
handles.ff_data_browse=uicontrol('Style','pushbutton','Position',...
      [xpos+150 ypos+83 50 18],'String','Browse',...
      'Callback','goset(''ff_data_browse'',gcbo,guidata(gcbo))','Visible','off');

[data,datafiledisp] = checkoptdata(data);
  
handles.ff_data = uicontrol('Style','edit','Position',[xpos+15 ypos+60 185 20],...
    'BackgroundColor','W','String',datafiledisp,'Visible','off',...
    'Callback','goset(''ff_data_input'',gcbo,guidata(gcbo))','Visible','off'); 

% === Gene parameters======================================================

ypos = fHeight/2-165;

handles.gp_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 330],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.gp_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 330],...
    'Visible','off','BackgroundColor','w');
handles.gp_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 324],...
    'Visible','off');
handles.gp_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+300 206 25],...
    'String','Gene parameters','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.gp_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''gp_inbxapp'',gcbo,guidata(gcbo))');
handles.gp_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''gp_inbxcncl'',gcbo,guidata(gcbo))');

handles.ngenes_txt=uicontrol('Style','text','Position',[xpos+15 ypos+273 160 18],...
    'HorizontalAlignment','Left','String','Total number of genes','Visible','off',...
    'ToolTipString','Total number of genes');    
handles.ngenes=uicontrol('Style','edit','Position',[xpos+150 ypos+275 55 18],...
    'BackgroundColor','W','String',data.ngenes,'Visible','off','Userdata',4,...
    'Callback','goset(''ngenes_CB'',gcbo,guidata(gcbo))'); 
handles.gp_paraframe=uicontrol('Style','frame','position',[xpos+10 ypos+50 195 220],...
    'Visible','off');
 
if data.ngenes == 1;
    slidermx = 2;
    sliderenable = 'off';
else
    slidermx = data.ngenes;
    sliderenable = 'on';
end
handles.selectgene_txt=uicontrol('Style','text','Position',[xpos+18 ypos+245 180 18],...
    'HorizontalAlignment','Left','Fontweight','Bold',...
    'String','Select the gene number to edit','Visible','off','Enable',sliderenable);   
handles.selectgene=uicontrol('Style','slider','Position',[xpos+20 ypos+227 176 18],...
    'BackgroundColor','W','value',1,'Max',slidermx,'Min',1,'SliderStep',...
    [1 ceil((data.ngenes-1)*0.2)]/(slidermx-1),'Visible','off',...
    'Enable',sliderenable,'Callback','goset(''dspgene_CB'',gcbo,guidata(gcbo))'); 
handles.gp_editframe=uicontrol('Style','frame','position',[xpos+14 ypos+54 186 168],...
    'Visible','off','BackgroundColor',gaopactoff,'Foregroundcolor','w');
handles.dspgene_txt=uicontrol('Style','text','Position',[xpos+20 ypos+198 160 18],...
    'HorizontalAlignment','Left','String','Parameters for gene No.',...
    'Fontweight','Bold','ForegroundColor','k','BackgroundColor',gaopactoff,...
    'Visible','off');    
handles.dspgene=uicontrol('Style','text','Position',[xpos+163 ypos+198 32 18],...
    'BackgroundColor',gaopactoff,'ForegroundColor','W','String',data.dspgene,'Visible','off',...
    'Fontweight','Bold'); 
handles.descgene_txt=uicontrol('Style','text','Position',[xpos+30 ypos+180 155 18],...
    'HorizontalAlignment','Left','String','Gene description',...
    'ToolTipString','Description of each gene','BackgroundColor',gaopactoff,'Visible','off');    
handles.descgene=uicontrol('Style','edit','Position',[xpos+30 ypos+160 160 18],...
    'BackgroundColor','W','String',data.descgene(data.dspgene),'Visible','off',...
    'Callback','goset(''descgene_CB'',gcbo,guidata(gcbo))');  
handles.min_txt=uicontrol('Style','text','Position',[xpos+30 ypos+133 160 18],...
    'HorizontalAlignment','Left','String','Minimum gene value',...
    'ToolTipString','Minimum value of the gene','BackgroundColor',gaopactoff,...
    'Visible','off');    
handles.min=uicontrol('Style','edit','Position',[xpos+140 ypos+135 50 18],...
    'BackgroundColor','W','String',data.gd_min(data.dspgene),'Visible','off',...
    'Callback','goset(''min_CB'',gcbo,guidata(gcbo))'); 
handles.max_txt=uicontrol('Style','text','Position',[xpos+30 ypos+108 160 18],...
    'HorizontalAlignment','Left','String','Maximum gene value',...
    'ToolTipString','Maximum value of the gene','BackgroundColor',gaopactoff,...
    'Visible','off');    
handles.max=uicontrol('Style','edit','Position',[xpos+140 ypos+110 50 18],...
    'BackgroundColor','W','String',data.gd_max(data.dspgene),'Visible','off',...
    'Callback','goset(''max_CB'',gcbo,guidata(gcbo))'); 
handles.type_txt=uicontrol('Style','text','Position',[xpos+30 ypos+81 160 18],...
    'HorizontalAlignment','Left','String','Gene type','BackgroundColor',gaopactoff,...
    'ToolTipString','Type of the gene','Visible','off'); 
handles.type = uicontrol('Style','popupmenu','Position',[xpos+100 ypos+85 90 18],...
      'Tag','type','String',{'Integer','Linear','Logarithmic'},...
      'BackgroundColor','W','Userdata',1,'Value',data.gd_type(data.dspgene),'Visible','off',...
      'Callback','goset(''type_CB'',gcbo,guidata(gcbo))');  
handles.cid_txt = uicontrol('Style','text','Position',[xpos+30 ypos+58 160 18],...
    'HorizontalAlignment','Left','String','Chromosome ID number','Visible','off',...
    'ToolTipString','Chromosome identification number for multiple chromosome scheme',...
    'BackgroundColor',gaopactoff);   
handles.cid = uicontrol('Style','edit','Position',[xpos+155 ypos+60 35 18],...
    'BackgroundColor','W','String',data.gd_cid(data.dspgene),'Visible','off',...
    'Callback','goset(''cid_CB'',gcbo,guidata(gcbo))');  

% === Fundamental parameters===============================================

ypos = fHeight/2-110;

handles.fp_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 210],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.fp_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 210],...
    'Visible','off','BackgroundColor','w');
handles.fp_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 204],...
    'Visible','off');
handles.fp_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+180 206 25],...
    'String','Fundamental paremeters','Fontsize',12,'Fontweight','Bold',...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.fp_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''fp_inbxapp'',gcbo,guidata(gcbo))');
handles.fp_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''fp_inbxcncl'',gcbo,guidata(gcbo))');

handles.fp_ngen_txt=uicontrol('Style','text','Position',[xpos+15 ypos+153 160 18],...
    'HorizontalAlignment','Left','String','Total generation No.',...
    'ToolTipString','Number of generations for evolution',...
    'Visible','off');    
handles.fp_ngen=uicontrol('Style','edit','Position',[xpos+150 ypos+155 55 18],...
    'BackgroundColor','W','String',data.fp_ngen,'Visible','off',...
    'Userdata',4,'Callback','goset(''fp_ngen'',gcbo,guidata(gcbo))');
handles.fp_ipop_txt=uicontrol('Style','text','Position',[xpos+15 ypos+128 160 18],...
    'HorizontalAlignment','Left','String','Init. population size',...
    'ToolTipString','Number of individuals in initial population',...
    'Visible','off');    
handles.fp_ipop=uicontrol('Style','edit','Position',[xpos+150 ypos+130 55 18],...
    'BackgroundColor','W','String',data.fp_ipop,'Visible','off',...
    'Userdata',4,'Callback','goset(''fp_ipop'',gcbo,guidata(gcbo))');  
handles.fp_npop_txt=uicontrol('Style','text','Position',[xpos+15 ypos+103 160 18],...
    'HorizontalAlignment','Left','String','Population size',...
    'ToolTipString','Number of individuals in regular population',...
    'Visible','off');    
handles.fp_npop=uicontrol('Style','edit','Position',[xpos+150 ypos+105 55 18],...
    'BackgroundColor','W','String',data.fp_npop,'Visible','off',...
    'Userdata',4,'Callback','goset(''fp_npop'',gcbo,guidata(gcbo))'); 
handles.fp_nobj_txt=uicontrol('Style','text','Position',[xpos+15 ypos+78 160 18],...
    'HorizontalAlignment','Left','String','No. of objective func.',...
    'ToolTipString','Number of objective functions','Visible','off');
handles.fp_nobj=uicontrol('Style','edit','Position',[xpos+150 ypos+80 55 18],...
    'BackgroundColor','W','String',data.fp_nobj,'Visible','off','Userdata',4,...
    'Callback','goset(''fp_nobj'',gcbo,guidata(gcbo))'); 
handles.fp_obj_txt=uicontrol('Style','text','Position',[xpos+15 ypos+53 160 18],...
    'HorizontalAlignment','Left','String','Obj. func. to optimize',...
    'ToolTipString',...
    'Objective func. No. to be used for optimization (0 for multi-obj. optimization)',...
    'Visible','off');    
handles.fp_obj=uicontrol('Style','edit','Position',[xpos+150 ypos+55 55 18],...
    'BackgroundColor','W','String',data.fp_obj,'Visible','off',...
    'Userdata',3,'Callback','goset(''fp_obj'',gcbo,guidata(gcbo))');  

% === Evaluation Option Field =============================================

ypos = fHeight/2-85;

handles.ev_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 170],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.ev_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 170],...
    'Visible','off','BackgroundColor','w');
handles.ev_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 164],...
    'Visible','off');
handles.ev_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+140 206 25],...
    'String','Evaluation Option','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off');
handles.ev_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''ev_inbxapp'',gcbo,guidata(gcbo))');
handles.ev_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''ev_inbxcncl'',gcbo,guidata(gcbo))');    

handles.ev_bev_txt=uicontrol('Style','text','Position',[xpos+15 ypos+110 150 18],...
    'HorizontalAlignment','Left','String','Evaluate per',...
    'Fontweight','Bold','Visible','off','ToolTipString',...
    'Specify whether the fitness is evaluated per an individual or per a population');
handles.ev_bev=uicontrol('Style','popupmenu','Position',[xpos+112 ypos+114 88 18],...
    'BackgroundColor','W','String',{'individual','population'},...
    'Value',data.ev_bev+1,'Visible','off');
handles.ev_are_txt=uicontrol('Style','text','Position',[xpos+15 ypos+80 150 18],...
    'HorizontalAlignment','Left','String','Evaluate',...
    'Fontweight','Bold','Visible','off','ToolTipString',...
    'Evaluate all individuals or only unevaluated individuals');
handles.ev_are=uicontrol('Style','popupmenu','Position',[xpos+70 ypos+84 130 18],...
      'Tag','sl','String',{'only unevaluated','all individuals'},...
      'BackgroundColor','W','Value',data.ev_are+1,'Visible','off');  
handles.ev_ssd_txt=uicontrol('Style','text','Position',[xpos+15 ypos+50 150 18],...
    'HorizontalAlignment','Left','String','Pass supplementary data',...
    'Fontweight','Bold','Visible','off','ToolTipString',...
    'Check to pass the age, previous fitness value and region information to the fitness function');
handles.ev_ssd=uicontrol('Style','checkbox','Position',[xpos+165 ypos+53 20 18],...
    'Value',data.ev_ssd,'Visible','off');
  
      
% === Diversity control ===================================================

ypos = fHeight/2-155;

handles.dc_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 310],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.dc_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 310],...
    'Visible','off','BackgroundColor','w');
handles.dc_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 304],...
    'Visible','off');
handles.dc_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+280 206 25],...
    'String','Diversity Control','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off');
handles.dc_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''dc_inbxapp'',gcbo,guidata(gcbo))');
handles.dc_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''dc_inbxcncl'',gcbo,guidata(gcbo))');

handles.dc_alg_txt=uicontrol('Style','text','Position',[xpos+15 ypos+250 140 18],...
    'String','Diversity control alg.','HorizontalAlignment','Left',...
    'Visible','off','ToolTipString','Diversity control algorithm');  
handles.dc_alg=uicontrol('Style','popupmenu','Position',[xpos+155 ypos+257 50 16],...
      'Tag','sl','String',{'   1','   2','   3','   4'},'BackgroundColor','W',...
      'Value',data.dc_alg,'Visible','off');  
handles.dc_spc_txt=uicontrol('Style','text','Position',[xpos+15 ypos+225 110 18],...
    'String','Apply to','HorizontalAlignment','Left','Visible','off',...
    'ToolTipString','Diversity control space');    
handles.dc_spc=uicontrol('Style','popupmenu','Position',[xpos+70 ypos+231 135 16],...
    'BackgroundColor','W','String',{'Parameter space','Fitness func. space'},...
    'value',1,'Visible','off'); 
handles.dc_mnt_txt=uicontrol('Style','text','Position',[xpos+15 ypos+200 140 18],...
    'String','Minimum threshold','HorizontalAlignment','Left','Visible','off',...
    'ToolTipString','Minimum threshold for algorithm 1');    
handles.dc_mnt=uicontrol('Style','edit','Position',[xpos+155 ypos+202 50 18],...
    'BackgroundColor','W','String',data.dc_mnt,'Visible','off',...
    'Userdata',1,'Callback','goset(''dc_mnt'',gcbo,guidata(gcbo))'); 
handles.dc_mxt_txt=uicontrol('Style','text','Position',[xpos+15 ypos+175 140 18],...
    'String','Maximum threshold','HorizontalAlignment','Left','Visible','off',...
    'ToolTipString','Maximum threshold for algorithm 1');    
handles.dc_mxt=uicontrol('Style','edit','Position',[xpos+155 ypos+177 50 18],...
    'BackgroundColor','W','String',data.dc_mxt,'Visible','off',...
    'Userdata',1,'Callback','goset(''dc_mxt'',gcbo,guidata(gcbo))');  
handles.dc_mnb_txt=uicontrol('Style','text','Position',[xpos+15 ypos+150 140 18],...
    'String','Minimum No. of bins','HorizontalAlignment','Left','ToolTipString',...
    'Minimum number of bins relative to population size for algorithm 2',...
    'Visible','off');    
handles.dc_mnb=uicontrol('Style','edit','Position',[xpos+155 ypos+152 50 18],...
    'BackgroundColor','W','String',data.dc_mnb,'Visible','off',...
    'Userdata',1,'Callback','goset(''dc_mnb'',gcbo,guidata(gcbo))');
handles.dc_mxb_txt=uicontrol('Style','text','Position',[xpos+15 ypos+125 140 18],...
    'String','Maximum No. of Bins','HorizontalAlignment','Left','ToolTipString',...
    'Maximum number of bins relative to population size for algorithm 2',...
    'Visible','off');    
handles.dc_mxb=uicontrol('Style','edit','Position',[xpos+155 ypos+127 50 18],...
    'BackgroundColor','W','String',data.dc_mxb,'Visible','off',...
    'Userdata',1,'Callback','goset(''dc_mxb'',gcbo,guidata(gcbo))');
handles.dc_ntr_txt=uicontrol('Style','text','Position',[xpos+15 ypos+100 140 18],...
    'String','No. of trials for Alg. 2','HorizontalAlignment','Left',...
    'ToolTipString','Number of trials for algorithm 2',...
    'Visible','off');    
handles.dc_ntr=uicontrol('Style','edit','Position',[xpos+155 ypos+102 50 18],...
    'BackgroundColor','W','String',data.dc_ntr,'Visible','off',...
    'Userdata',4,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.dc_dc_txt=uicontrol('Style','text','Position',[xpos+15 ypos+75 145 18],...
    'String','Local population const.','HorizontalAlignment','Left','Visible','off',...
    'ToolTipString','Diversity control local population constant (algorithm 3 and 4)');    
handles.dc_dc=uicontrol('Style','edit','Position',[xpos+155 ypos+77 50 18],...
    'BackgroundColor','W','String',data.dc_dc,'Visible','off',...
    'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.dc_nt_txt=uicontrol('Style','text','Position',[xpos+15 ypos+50 140 18],...
    'String','Test population size','HorizontalAlignment','Left','Visible','off',...
    'ToolTipString','Diversity control test population size for algorithm 4');    
handles.dc_nt=uicontrol('Style','edit','Position',[xpos+155 ypos+52 50 18],...
    'BackgroundColor','W','String',data.dc_nt,'Visible','off',...
    'Userdata',4,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 

% === Scaling Operator Field ==============================================

ypos = fHeight/2-140;

handles.sc_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 280],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.sc_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 280],...
    'Visible','off','BackgroundColor','w');
handles.sc_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 274],...
    'Visible','off');
handles.sc_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+250 206 25],...
    'String','Scaling','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.sc_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''sc_inbxapp'',gcbo,guidata(gcbo))');
handles.sc_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''sc_inbxcncl'',gcbo,guidata(gcbo))');

handles.sc_alg_txt=uicontrol('Style','text','position',[xpos+20 ypos+222 180 18],...
        'HorizontalAlignment','Left','Fontweight','bold','string',...
        'Scaling algorithm','Visible','off','ToolTipString',...
        'Scaling algorithm');
handles.sc_alg=uicontrol('Style','popupmenu','Position',[xpos+20 ypos+202 180 20],...
      'Tag','ca','String',...
      {'No scaling',...
      'Offset (mn : 0)'... 
      'Std Linear (av : av, mx : k x av)'...
      'Mod Linear (md : md, mx : k x md)'...
      'Map Linear (mn : 1, mx : k)'...
      'Sigma truncation'...
      'Quadratic (mn:kn, av:1, mx:kx)'},...
      'BackgroundColor','W','Value',data.sc_alg+1,'Visible','off'); 
handles.sc_lin_txt=uicontrol('Style','text','position',[xpos+20 ypos+170 140 18],...
        'HorizontalAlignment','Left','string','Linear scaling',...
        'Fontweight','Bold','ForegroundColor',[.5 .5 .5],'Visible','off');      
handles.sc_kln_txt=uicontrol('Style','text','position',[xpos+30 ypos+153 150 18],...
        'HorizontalAlignment','Left','string','Scaling factor (k)',...
        'Visible','off','ToolTipString','Scaling factor for linear scaling');   
handles.sc_kln=uicontrol('Style','edit','position',[xpos+150 ypos+155 50 18],...
        'BackgroundColor','W','String',data.sc_kln,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');  
handles.sc_sgt_txt=uicontrol('Style','text','position',[xpos+20 ypos+130 140 18],...
        'HorizontalAlignment','Left','string','Sigma truncation',...
        'Fontweight','Bold','ForegroundColor',[.5 .5 .5],'Visible','off');      
handles.sc_cst_txt=uicontrol('Style','text','position',[xpos+30 ypos+113 150 18],...
        'HorizontalAlignment','Left','string','Scaling constant',...
        'Visible','off','ToolTipString','Scaling constant for sigma truncation');   
handles.sc_cst=uicontrol('Style','edit','position',[xpos+150 ypos+115 50 18],...
        'BackgroundColor','W','String',data.sc_cst,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.sc_sgm_txt=uicontrol('Style','text','position',[xpos+20 ypos+90 140 18],...
        'HorizontalAlignment','Left','string','Quadratic scaling',...
        'Fontweight','Bold','ForegroundColor',[.5 .5 .5],'Visible','off');  
handles.sc_kmxq_txt=uicontrol('Style','text','position',[xpos+30 ypos+73 140 18],...
        'HorizontalAlignment','Left','string','Max. scaling factor (kx)',...
        'ToolTipString','Most fit individual is maximum scaling factor times more likely to be selected than median fit',...
        'Visible','off');   
handles.sc_kmxq=uicontrol('Style','edit','position',[xpos+150 ypos+75 50 18],...
        'BackgroundColor','W','String',data.sc_kmxq,'Visible','off',...
        'Userdata',1,'Callback','goset(''sc_kmxq'',gcbo,guidata(gcbo))'); 
handles.sc_kmnq_txt=uicontrol('Style','text','position',[xpos+30 ypos+53 140 18],...
        'HorizontalAlignment','Left','string','Min. scaling factor (kn)',...
        'ToolTipString','Least fit individual is minimum scaling factor times less likely to be selected than median fit',...
        'Visible','off');   
handles.sc_kmnq=uicontrol('Style','edit','position',[xpos+150 ypos+55 50 18],...
        'BackgroundColor','W','String',data.sc_kmnq,'Visible','off',...
        'Userdata',1,'Callback','goset(''sc_kmnq'',gcbo,guidata(gcbo))');   

% === Selection Operator Field ============================================

ypos = fHeight/2-100;

handles.sl_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 200],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.sl_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 200],...
    'Visible','off','BackgroundColor','w');
handles.sl_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 194],...
    'Visible','off');
handles.sl_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+170 206 25],...
    'String','Selection','Fontsize',14,'ForegroundColor','W',...
    'BackgroundColor','K','Visible','off');
handles.sl_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''sl_inbxapp'',gcbo,guidata(gcbo))');
handles.sl_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''sl_inbxcncl'',gcbo,guidata(gcbo))');

handles.sl_alg_txt=uicontrol('Style','text','position',...
    [xpos+10 ypos+142 170 20],'String','Selection algorithm',...
    'HorizontalAlignment','Left','Fontweight','bold','Visible','off');
handles.sl_alg=uicontrol('Style','popupmenu','Position',...
    [xpos+30 ypos+127 170 20],'Tag','sl','String',...
    {'Roulette wheel selection','Tournament selection','Custom algorithm'},...
    'BackgroundColor','W','Value',data.sl_alg,'Visible','off'); 
  
handles.sl_cah_txt=uicontrol('Style','text','Position',[xpos+30 ypos+96 140 18],...
    'HorizontalAlignment','Left','String','Custom algorithm',...
    'Fontweight','Bold','ToolTipString','Custom selection algorithm',...
    'ForegroundColor',[.5 .5 .5],'Visible','off');
handles.sl_cah_browse=uicontrol('Style','pushbutton','Position',...
      [xpos+150 ypos+100 50 18],'String','Browse',...
      'Callback','goset(''sl_cah_browse'',gcbo,guidata(gcbo))','Visible','off');
if isempty(data.sl_cah)
    slcahdisp = 'none';
    data.sl_cah = [];
else
    slcahdisp = [data.sl_cah,'.m'];
end  
handles.sl_cah=uicontrol('Style','text','Position',[xpos+30 ypos+80 170 15],...
    'BackgroundColor','W','String',slcahdisp,'Visible','off'); 
      
handles.sl_nts_txt=uicontrol('Style','text','position',[xpos+10 ypos+45 170 20],...
    'String','Tournament individual size','HorizontalAlignment','Left',...
    'ToolTipString','Number of individuals in a tournament','Visible','off');
handles.sl_nts=uicontrol('Style','edit','position',[xpos+170 ypos+49 30 18],...
    'BackgroundColor','W','String',data.sl_nts,'Userdata',4,'Visible','off',...
    'Callback','goset(''sl_nts'',gcbo,guidata(gcbo))');

% === Death Operator Field ============================================

ypos = fHeight/2-100;

handles.dt_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 200],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.dt_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 200],...
    'Visible','off','BackgroundColor','w');
handles.dt_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 194],...
    'Visible','off');
handles.dt_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+170 206 25],...
    'String','Death','Fontsize',14,'ForegroundColor','W',...
    'BackgroundColor','K','Visible','off');
handles.dt_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''dt_inbxapp'',gcbo,guidata(gcbo))');
handles.dt_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''dt_inbxcncl'',gcbo,guidata(gcbo))');

handles.dt_alg_txt=uicontrol('Style','text','position',...
    [xpos+10 ypos+142 170 20],'String','Death algorithm',...
    'HorizontalAlignment','Left','Fontweight','bold','Visible','off');
handles.dt_alg=uicontrol('Style','popupmenu','Position',...
    [xpos+30 ypos+127 170 20],'Tag','dt','String',...
    {'Parents replacement','Random replacement','Tournament of fitness',...
    'Tournament on age', 'Custom algorithm', 'Random (select 1-4)'},...
    'BackgroundColor','W','Value',data.dt_alg,'Visible','off'); 
   
handles.dt_cah_txt=uicontrol('Style','text','Position',[xpos+30 ypos+96 140 18],...
    'HorizontalAlignment','Left','String','Custom algorithm',...
    'Fontweight','Bold','ToolTipString','Custom selection algorithm',...
    'ForegroundColor',[.5 .5 .5],'Visible','off');
handles.dt_cah_browse=uicontrol('Style','pushbutton','Position',...
      [xpos+150 ypos+100 50 18],'String','Browse',...
      'Callback','goset(''dt_cah_browse'',gcbo,guidata(gcbo))','Visible','off');
if isempty(data.dt_cah)
    dtcahdisp = 'none';
    data.dt_cah = [];
else
    dtcahdisp = [data.dt_cah,'.m'];
end 
handles.dt_cah=uicontrol('Style','text','Position',[xpos+30 ypos+80 170 15],...
    'BackgroundColor','W','String',dtcahdisp,'Visible','off'); 
      
handles.dt_nts_txt=uicontrol('Style','text','position',[xpos+10 ypos+45 170 20],...
    'String','Tournament individual size','HorizontalAlignment','Left',...
    'ToolTipString','Number of individuals in a tournament','Visible','off');
handles.dt_nts=uicontrol('Style','edit','position',[xpos+170 ypos+49 30 18],...
    'BackgroundColor','W','String',data.dt_nts,'Userdata',4,'Visible','off',...
    'Callback','goset(''dt_nts'',gcbo,guidata(gcbo))');

% === Mating and crossover Operator Field =================================

ypos = fHeight/2-137;

handles.mc_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 275],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.mc_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 275],...
    'Visible','off','BackgroundColor','w');
handles.mc_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 269],...
    'Visible','off');
handles.mc_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+245 206 25],...
    'String','Mating & Crossover','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.mc_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''mc_inbxapp'',gcbo,guidata(gcbo))');
handles.mc_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''mc_inbxcncl'',gcbo,guidata(gcbo))');

handles.mc_pp_txt=uicontrol('Style','text','position',[xpos+15 ypos+217 150 18],...
        'HorizontalAlignment','Left','string','Crossover probability',...
        'ToolTipString','Crossover probability',...
        'Visible','off'); 
handles.mc_pp=uicontrol('Style','edit','position',[xpos+160 ypos+220 40 18],...
        'BackgroundColor','W','String',data.mc_pp,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.mc_fc_txt=uicontrol('Style','text','position',[xpos+15 ypos+188 140 18],...
        'HorizontalAlignment','Left','string','Involved chromosomes ratio',...
        'ToolTipString','Fraction of chromosomes of individual who is selected',...
        'Visible','off');   
handles.mc_fc=uicontrol('Style','edit','position',[xpos+160 ypos+190 40 18],...
        'BackgroundColor','W','String',data.mc_fc,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mc_alg_txt=uicontrol('Style','text','position',[xpos+15 ypos+160 180 18],...
        'HorizontalAlignment','Left','Fontweight','bold',...
        'string','Mating-crossover algorithm','Visible','off');
handles.mc_alg=uicontrol('Style','popupmenu','Position',[xpos+30 ypos+145 170 18],...
      'Tag','ca','String',...
      {'Single point',...
      'Scalar simple blend',...
      'Vector simple blend',...
      'Scalar simulated binary',...
      'Vector simulated binary',...
      'Random algorithm'},...
      'BackgroundColor','W','Value',data.mc_alg,'Visible','off');
handles.mc_simbin_txt=uicontrol('Style','text','position',[xpos+20 ypos+115 140 18],...
        'HorizontalAlignment','Left','string','Simulated binary crossover',...
        'Fontweight','Bold','ForegroundColor',[.5 .5 .5],'Visible','off');    
handles.mc_ec_txt=uicontrol('Style','text','position',[xpos+35 ypos+98 140 18],...
        'HorizontalAlignment','Left','string','Tightness parameter',...
        'ToolTipString','Tightness of distribution parameter for simulated binary crossover',...
        'Visible','off');   
handles.mc_ec=uicontrol('Style','edit','position',[xpos+160 ypos+100 40 18],...
        'BackgroundColor','W','String',data.mc_ec,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');;
handles.mc_rdnxov_txt=uicontrol('Style','text','position',[xpos+20 ypos+75 140 18],...
        'HorizontalAlignment','Left','string','Random crossover',...
        'Fontweight','Bold','ForegroundColor',[.5 .5 .5],'Visible','off'); 
handles.mc_gac_txt=uicontrol('Style','text','position',[xpos+35 ypos+58 140 18],...
        'HorizontalAlignment','Left','string','Changing interval',...
        'ToolTipString','No. of generations between algorithm changes for random crossover',...
        'Visible','off');   
handles.mc_gac=uicontrol('Style','edit','position',[xpos+160 ypos+60 40 18],...
        'BackgroundColor','W','String',data.mc_gac,'Visible','off',...
        'Userdata',4,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');

% === Mutation Operator Field =============================================

ypos = fHeight/2-170;

handles.mt_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 340],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.mt_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 340],...
    'Visible','off','BackgroundColor','w');
handles.mt_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 334],...
    'Visible','off');
handles.mt_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+310 206 25],...
    'String','Mutation','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.mt_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''mt_inbxapp'',gcbo,guidata(gcbo))');
handles.mt_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''mt_inbxcncl'',gcbo,guidata(gcbo))');

handles.mt_label=uicontrol('Style','text','position',[xpos+90 ypos+285 115 18],...
        'HorizontalAlignment','Left','string','Probability   Std. Dev.',...
        'Fontweight','Bold','Visible','off'); 
handles.mt_tgm_txt=uicontrol('Style','text','position',[xpos+15 ypos+262 150 18],...
        'HorizontalAlignment','Left','string','Total mutation',...
        'Visible','off'); 
handles.mt_ptgm=uicontrol('Style','edit','position',[xpos+95 ypos+265 50 18],...
        'ForegroundColor','b','String',data.mt_ptgm,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_rgm_txt=uicontrol('Style','text','position',[xpos+15 ypos+237 190 18],...
        'HorizontalAlignment','Left','string','Relative partial gene mutation',...
        'Visible','off'); 
handles.mt_prgm=uicontrol('Style','edit','position',[xpos+95 ypos+220 50 18],...
        'ForegroundColor','b','String',data.mt_prgm,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_srgm=uicontrol('Style','edit','position',[xpos+150 ypos+220 50 18],...
        'ForegroundColor','r','String',data.mt_srgm,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_agm_txt=uicontrol('Style','text','position',[xpos+15 ypos+192 190 18],...
        'HorizontalAlignment','Left','string','Absolute partial gene mutation',...
        'Visible','off'); 
handles.mt_pagm=uicontrol('Style','edit','position',[xpos+95 ypos+175 50 18],...
        'ForegroundColor','b','String',data.mt_pagm,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_sagm=uicontrol('Style','edit','position',[xpos+150 ypos+175 50 18],...
        'ForegroundColor','r','String',data.mt_sagm,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_rvm_txt=uicontrol('Style','text','position',[xpos+15 ypos+147 180 18],...
        'HorizontalAlignment','Left','string','Relative vector mutation',...
        'Visible','off'); 
handles.mt_prvm=uicontrol('Style','edit','position',[xpos+95 ypos+130 50 18],...
        'ForegroundColor','b','String',data.mt_prvm,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_srvm=uicontrol('Style','edit','position',[xpos+150 ypos+130 50 18],...
        'ForegroundColor','r','String',data.mt_srvm,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_avm_txt=uicontrol('Style','text','position',[xpos+15 ypos+102 180 18],...
        'HorizontalAlignment','Left','string','Absolute vector mutation',...
        'Visible','off'); 
handles.mt_pavm=uicontrol('Style','edit','position',[xpos+95 ypos+85 50 18],...
        'ForegroundColor','b','String',data.mt_pavm,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_savm=uicontrol('Style','edit','position',[xpos+150 ypos+85 50 18],...
        'ForegroundColor','r','String',data.mt_savm,'Visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.mt_igm_txt=uicontrol('Style','text','position',[xpos+15 ypos+52 150 18],...
        'HorizontalAlignment','Left','string','Integer mutation',...
        'Visible','off'); 
handles.mt_pigm=uicontrol('Style','edit','position',[xpos+95 ypos+55 50 18],...
        'ForegroundColor','b','String',data.mt_pigm,'Visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
 
% === Gene Repair Operator Field ==========================================

ypos = fHeight/2-60;

handles.gr_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 140],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.gr_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 140],...
    'Visible','off','BackgroundColor','w');
handles.gr_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 134],...
    'Visible','off');
handles.gr_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+110 206 25],...
    'String','Gene Repair','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off'); 
handles.gr_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''gr_inbxapp'',gcbo,guidata(gcbo))');
handles.gr_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''gr_inbxcncl'',gcbo,guidata(gcbo))');

handles.gr_alg_txt=uicontrol('Style','text','position',[xpos+40 ypos+75 120 18],...
        'HorizontalAlignment','Left','Fontweight','bold','string',...
        'Gene repair method','Visible','off','ToolTipString',...
        'Gene repair method');
handles.gr_alg=uicontrol('Style','popupmenu','Position',[xpos+40 ypos+55 140 20],...
      'Tag','ca','String',{'Hard limiting','Ring mapping'},...
      'BackgroundColor','W','Value',data.gr_alg,'Visible','off'); 
     
% === Migration ===========================================================

ypos = fHeight/2-80;

handles.mg_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 160],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.mg_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 160],...
    'Visible','off','BackgroundColor','w');
handles.mg_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 154],...
    'Visible','off');
handles.mg_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+130 206 25],...
    'String','Migration','Fontsize',14,'ForegroundColor','W',...
    'BackgroundColor','K','Visible','off'); 
handles.mg_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''mg_inbxapp'',gcbo,guidata(gcbo))');
handles.mg_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''mg_inbxcncl'',gcbo,guidata(gcbo))');

handles.mg_nreg_txt=uicontrol('Style','text','Position',[xpos+15 ypos+103 130 18],...
    'HorizontalAlignment','Left','String','Number of regions',...
    'ToolTipString','Number of geographic regions the population is distributed',...
    'Visible','off');    
handles.mg_nreg=uicontrol('Style','edit','Position',[xpos+150 ypos+105 50 18],...
    'BackgroundColor','W','String',data.mg_nreg,'Visible','off',...
    'Userdata',4,'Callback','goset(''mg_nreg'',gcbo,guidata(gcbo))');  
handles.mg_tmig_txt=uicontrol('Style','text','Position',[xpos+15 ypos+78 150 18],...
    'HorizontalAlignment','Left','String','Migration interval',...
    'ToolTipString','Time between migrations in generations',...
    'Visible','off');    
handles.mg_tmig=uicontrol('Style','edit','Position',[xpos+150 ypos+80 50 18],...
    'BackgroundColor','W','String',data.mg_tmig,'Visible','off',...
    'Userdata',3,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');  
handles.mg_pmig_txt=uicontrol('Style','text','Position',[xpos+15 ypos+53 150 18],...
    'HorizontalAlignment','Left','String','Migration probability',...
    'ToolTipString',...
    'Probability of an individual to be selected for migration',...
    'Visible','off');    
handles.mg_pmig=uicontrol('Style','edit','Position',[xpos+150 ypos+55 50 18],...
    'BackgroundColor','W','String',data.mg_pmig,'Visible','off',...
    'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 


% === Elitism Operator ====================================================

ypos = fHeight/2-70;

handles.el_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 140],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.el_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 140],...
    'Visible','off','BackgroundColor','w');
handles.el_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 134],...
    'Visible','off');
handles.el_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+110 206 25],...
    'String','Elitism','Fontsize',14,'ForegroundColor','W',...
    'BackgroundColor','K','Visible','off');  
handles.el_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''el_inbxapp'',gcbo,guidata(gcbo))');
handles.el_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''el_inbxcncl'',gcbo,guidata(gcbo))');

handles.el_fgs_txt=uicontrol('Style','text','position',[xpos+15 ypos+78 100 18],...
        'ToolTipString','fraction of total generations through study to start elitism',...
        'HorizontalAlignment','Left','string','Starting point','visible','off');
handles.el_fgs=uicontrol('Style','edit','position',[xpos+145 ypos+80 40 18],...
        'BackgroundColor','w','string',data.el_fgs,'visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
handles.el_fpe_txt=uicontrol('Style','text','position',[xpos+15 ypos+53 100 18],...
        'HorizontalAlignment','Left','string','Elite ratio','visible','off');   
handles.el_fpe=uicontrol('Style','edit','position',[xpos+145 ypos+55 40 18],...
        'ToolTipString','Fraction of population protected as elite',...
        'BackgroundColor','w','string',data.el_fpe,'visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');

% === Random Search Operator ==============================================

ypos = fHeight/2-117;

handles.rs_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 235],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.rs_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 235],...
    'Visible','off','BackgroundColor','w');
handles.rs_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 229],...
    'Visible','off');
handles.rs_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+205 206 25],...
    'String','Random search','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor','K','Visible','off');  
handles.rs_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+10 50 30],...
    'string','Apply','Visible','off',...
    'Callback','goset(''rs_inbxapp'',gcbo,guidata(gcbo))');   
handles.rs_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+10 50 30],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''rs_inbxcncl'',gcbo,guidata(gcbo))');  
    
handles.rs_fgs_txt=uicontrol('Style','text','position',[xpos+15 ypos+178 100 18],...
        'HorizontalAlignment','Left','string','Starting point',...
        'ToolTipString','Fraction of total generations through study to start random search',...
        'visible','off');
handles.rs_fgs=uicontrol('Style','edit','position',[xpos+160 ypos+180 40 18],...
        'BackgroundColor','w','string',data.rs_fgs,'visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');    
handles.rs_fps_txt=uicontrol('Style','text','position',[xpos+15 ypos+153 180 18],...
        'HorizontalAlignment','Left','string','Involved Pop. portion',...
        'ToolTipString','Fraction of total population size used in random search',...
        'visible','off');
handles.rs_fps=uicontrol('Style','edit','position',[xpos+160 ypos+155 40 18],...
        'BackgroundColor','w','string',data.rs_fps,'visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.rs_srp_txt=uicontrol('Style','text','position',[xpos+15 ypos+128 150 18],...
        'HorizontalAlignment','Left','string','Rel. Pertb. Std. Dev.',...
        'ToolTipString','Standard deviation used in relative perturbation',...
        'visible','off');
handles.rs_srp=uicontrol('Style','edit','position',[xpos+160 ypos+130 40 18],...
        'BackgroundColor','w','string',data.rs_srp,'visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.rs_sap_txt=uicontrol('Style','text','position',[xpos+15 ypos+103 150 18],...
        'HorizontalAlignment','Left','string','Abs. Pertb. Std. Dev.',...
        'ToolTipString','Standard deviation used in absolute perturbation',...
        'visible','off');
handles.rs_sap=uicontrol('Style','edit','position',[xpos+160 ypos+105 40 18],...
        'BackgroundColor','w','string',data.rs_sap,'visible','off',...
        'Userdata',1,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.rs_frp_txt=uicontrol('Style','text','position',[xpos+15 ypos+78 180 18],...
        'HorizontalAlignment','Left','string','Duty cycle of Rel. Pertb.',...
        'ToolTipString','Duty cycle for using relative random perturbations',...
        'visible','off');
handles.rs_frp=uicontrol('Style','edit','position',[xpos+160 ypos+80 40 18],...
        'BackgroundColor','w','string',data.rs_frp,'visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.rs_fea_txt=uicontrol('Style','text','position',[xpos+15 ypos+53 180 18],...
        'HorizontalAlignment','Left','string','Involved Gen. portion',...
        'ToolTipString','Fraction of geneations on which to execute the algorithm',...
        'visible','off');
handles.rs_fea=uicontrol('Style','edit','position',[xpos+160 ypos+55 40 18],...
        'BackgroundColor','w','string',data.rs_fea,'visible','off',...
        'Userdata',2,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
    
% === Output Report parameters ============================================

ypos = fHeight/2-208;

handles.or_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 416],...
        'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.or_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 416],...
        'Visible','off','BackgroundColor','w');
handles.or_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 410],...
        'Visible','off');
handles.or_inbxapp=uicontrol('Style','pushbutton','position',[xpos+52 ypos+6 50 30],...
        'string','Apply','Visible','off',...
        'Callback','goset(''or_inbxapp'',gcbo,guidata(gcbo))');   
handles.or_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+112 ypos+6 50 30],...
        'string','Cancel','Visible','off',...
        'Callback','goset(''or_inbxcncl'',gcbo,guidata(gcbo))');  
    
handles.or_txt=uicontrol('Style','text','position',[xpos+5 ypos+387 206 24],...
        'String','Plotting parameters','Fontsize',14,...
        'ForegroundColor','W','BackgroundColor','k','Visible','off');
        
handles.op_txt=uicontrol('Style','text','position',[xpos+5 ypos+368 206 18],...
        'String','Gene dist. & history plot','Fontsize',10,'Fontweight','bold',...
        'ForegroundColor','W','BackgroundColor',[.4 .4 .4],'Visible','off');  
handles.op_list_txt=uicontrol('Style','text','position',[xpos+15 ypos+342 180 18],...
        'HorizontalAlignment','Left','string','Obj. for plot',...
        'TooltipString','List of objectives for objective plot',...
        'visible','off');
handles.op_list=uicontrol('Style','edit','position',[xpos+105 ypos+345 100 18],...
        'BackgroundColor','w','string',['[',num2str(data.op_list),']'],...
        'visible','off','Callback','goset(''op_list'',gcbo,guidata(gcbo))'); 
handles.op_style_txt=uicontrol('Style','text','position',[xpos+15 ypos+323 180 18],...
        'HorizontalAlignment','Left','string','Plot scale',...
        'TooltipString','Style for each objective (0: logarithmic, 1: linear)',...
        'visible','off');
handles.op_style=uicontrol('Style','edit','position',[xpos+95 ypos+325 110 18],...
        'BackgroundColor','w','string',['[',num2str(data.op_style),']'],...
        'visible','off','Callback','goset(''op_style'',gcbo,guidata(gcbo))'); 
handles.op_sign_txt=uicontrol('Style','text','position',[xpos+15 ypos+303 180 18],...
        'HorizontalAlignment','Left','string','Sign of fit.',...
        'TooltipString','Sign of fitness for each objecitve (1: positive, -1: nagative)',...
        'visible','off');
handles.op_sign=uicontrol('Style','edit','position',[xpos+95 ypos+305 110 18],...
        'BackgroundColor','w','string',['[',num2str(data.op_sign),']'],...
        'visible','off','Callback','goset(''op_sign'',gcbo,guidata(gcbo))'); 
handles.dp_type_txt=uicontrol('Style','text','position',[xpos+15 ypos+278 100 18],...
        'TooltipString','Distribution plot type',...
        'HorizontalAlignment','Left','string','Distribution plot type',...
        'visible','off'); 
handles.dp_type=uicontrol('Style','popupmenu','position',[xpos+125 ypos+284 80 18],...
        'BackgroundColor','w','string',{'Gene value','Histogram'},...
        'Fontsize',8,'Value',data.dp_type,'visible','off');
handles.dp_np_txt=uicontrol('Style','text','position',[xpos+15 ypos+258 160 18],...
        'TooltipString','Number of individuals that are randomly chosen for gene value type plot',...
        'HorizontalAlignment','Left','string','No. of ind. to plot (Type 1)',...
        'visible','off'); 
handles.dp_np=uicontrol('Style','edit','position',[xpos+160 ypos+260 45 18],...
        'BackgroundColor','w','string',data.dp_np,'visible','off',...
        'Userdata',3,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))'); 
handles.dp_res_txt=uicontrol('Style','text','position',[xpos+15 ypos+237 160 18],...
        'TooltipString','Number of bins for the histogram type plot',...
        'HorizontalAlignment','Left','string','No. of bins (Type 2)',...
        'visible','off'); 
handles.dp_res=uicontrol('Style','edit','position',[xpos+160 ypos+240 45 18],...
        'BackgroundColor','w','string',data.dp_res,'visible','off',...
        'Userdata',4,'Callback','goset(''numericinputtest'',gcbo,guidata(gcbo))');
        
        
handles.pp_txt=uicontrol('Style','text','position',[xpos+5 ypos+212 206 18],...
        'String','Pareto plot parameters','Fontsize',10,'FontWeight','Bold',....
        'ForegroundColor','W','BackgroundColor',[.4 .4 .4],'Visible','off');  
handles.pp_list_txt=uicontrol('Style','text','position',[xpos+15 ypos+187 180 18],...
        'HorizontalAlignment','Left','string','Obj. for plot',...
        'TooltipString','List of 2 or 3 objectives for Pareto plot',...
        'visible','off');
handles.pp_list=uicontrol('Style','edit','position',[xpos+105 ypos+190 100 18],...
        'BackgroundColor','w','string',['[',num2str(data.pp_list),']'],...
        'visible','off','Callback','goset(''pp_list'',gcbo,guidata(gcbo))'); 
handles.pp_sign_txt=uicontrol('Style','text','position',[xpos+15 ypos+168 180 18],...
        'HorizontalAlignment','Left','string','Sign of fit.',...
        'ToolTipString','Sign of fitness for each objective (1: positive, -1: nagative)',...
        'visible','off');
handles.pp_sign=uicontrol('Style','edit','position',[xpos+95 ypos+170 110 18],...
        'BackgroundColor','w','string',['[',num2str(data.pp_sign),']'],...
        'visible','off','Callback','goset(''pp_sign'',gcbo,guidata(gcbo))');
handles.pp_style_txt=uicontrol('Style','text','position',[xpos+15 ypos+147 180 18],...
        'HorizontalAlignment','Left','string','Plot scale',...
        'ToolTipString','Style for reach objective (0: logarithmic, 1: linear)',...
        'visible','off');
handles.pp_style=uicontrol('Style','edit','position',[xpos+95 ypos+150 110 18],...
        'BackgroundColor','w','string',['[',num2str(data.pp_style),']'],...
        'visible','off','Callback','goset(''pp_style'',gcbo,guidata(gcbo))');  
handles.pp_xl_txt=uicontrol('Style','text','position',[xpos+15 ypos+127 180 18],...
        'HorizontalAlignment','Left','string','X label',...
        'ToolTipString','Label for x-axis','visible','off');
handles.pp_xl=uicontrol('Style','edit','position',[xpos+80 ypos+130 125 18],...
        'BackgroundColor','w','string',data.pp_xl,'visible','off'); 
handles.pp_yl_txt=uicontrol('Style','text','position',[xpos+15 ypos+107 180 18],...
        'HorizontalAlignment','Left','string','Y label',...
        'ToolTipString','Label for y-axis','visible','off');
handles.pp_yl=uicontrol('Style','edit','position',[xpos+80 ypos+110 125 18],...
        'BackgroundColor','w','string',data.pp_yl,'visible','off'); 
handles.pp_zl_txt=uicontrol('Style','text','position',[xpos+15 ypos+87 180 18],...
        'HorizontalAlignment','Left','string','Z label',...
        'ToolTipString','Label for y-axis','visible','off');
handles.pp_zl=uicontrol('Style','edit','position',[xpos+80 ypos+90 125 18],...
        'BackgroundColor','w','string',data.pp_zl,'visible','off'); 
handles.pp_title_txt=uicontrol('Style','text','position',[xpos+15 ypos+67 50 18],...
        'HorizontalAlignment','Left','string','Title',...
        'ToolTipString','Title for Pareto plot','visible','off');
handles.pp_title=uicontrol('Style','edit','position',[xpos+45 ypos+70 160 18],...
        'BackgroundColor','w','string',data.pp_title,'visible','off'); 
handles.pp_axis_txt=uicontrol('Style','text','position',[xpos+15 ypos+47 40 18],...
        'HorizontalAlignment','Left','string','Axis',...
        'ToolTipString','Axis limits for Pareto plot','visible','off');
ppaxis = num2str(data.pp_axis);
if isempty(ppaxis)
    ppaxis = 'Auto';
else
    ppaxis = ['[' ppaxis ']'];
end
handles.pp_axis=uicontrol('Style','edit','position',[xpos+45 ypos+50 160 18],...
        'BackgroundColor','w','string',ppaxis,...
        'visible','off','Callback','goset(''pp_axis'',gcbo,guidata(gcbo))'); 
 
% === Trim GA =============================================================
xpos = 190;
ypos = fHeight/2-90;
    
handles.tg_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 180],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.tg_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 180],...
    'Visible','off','BackgroundColor','w');
handles.tg_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 174],...
    'Visible','off');
handles.tg_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+150 206 25],...
    'String','Trim GA','Fontsize',14,'ForegroundColor','W',...
    'BackgroundColor',[1 .5 .5],'Visible','off');  
handles.tg_inbxstart=uicontrol('Style','pushbutton','position',[xpos+17 ypos+10 50 30],...
    'string','Start','Visible','off',...
    'ToolTipString','Initiate TRIMGA for the deterministic optimization.',...
    'Callback','goset(''tg_inbxstart'',gcbo,guidata(gcbo))');
handles.tg_inbxadopt=uicontrol('Style','pushbutton','position',[xpos+77 ypos+10 50 30],...
    'string','Adopt','Visible','off',...
    'ToolTipString','Include the new solution in the current population',...
    'Callback','goset(''tg_inbxadopt'',gcbo,guidata(gcbo))');
handles.tg_inbxclose=uicontrol('Style','pushbutton','position',[xpos+137 ypos+10 50 30],...
    'string','Close','Visible','off',...
    'Callback','goset(''tg_inbxclose'',gcbo,guidata(gcbo))');

handles.tg_txt=uicontrol('Style','text','position',[xpos+15 ypos+94 180 45],...
        'HorizontalAlignment','Center','string','','visible','off');    
handles.tg_orifit_txt=uicontrol('Style','text','position',[xpos+15 ypos+70 100 16],...
        'HorizontalAlignment','left','string','Current fitness','visible','off');   
handles.tg_orifit=uicontrol('Style','text','position',[xpos+110 ypos+70 90 16],...
        'HorizontalAlignment','left','string','1324','visible','off'); 
handles.tg_newfit_txt=uicontrol('Style','text','position',[xpos+15 ypos+46 180 16],...
        'HorizontalAlignment','left','string','Resultant fitness','visible','off');  
handles.tg_newfit=uicontrol('Style','text','position',[xpos+110 ypos+46 90 16],...
        'HorizontalAlignment','left','string','1234','visible','off'); 

% === User routine ========================================================
xpos = 190;
ypos = fHeight/2-85;

handles.ur_inbxsdw=uicontrol('Style','frame','position',[xpos+3 ypos-3 216 170],...
    'Visible','off','ForegroundColor',[.5 .5 .5],'BackgroundColor',[.4 .4 .4]);
handles.ur_inbx1=uicontrol('Style','frame','position',[xpos ypos 216 170],...
    'Visible','off','BackgroundColor','w');
handles.ur_inbx2=uicontrol('Style','frame','position',[xpos+3 ypos+3 210 164],...
    'Visible','off');
handles.ur_inbxtitle=uicontrol('Style','text','position',[xpos+5 ypos+140 206 25],...
    'String','User routines','Fontsize',14,...
    'ForegroundColor','W','BackgroundColor',[1 .5 .5],'Visible','off'); 
handles.ur_inbxapp=uicontrol('Style','pushbutton','position',[xpos+18 ypos+10 50 20],...
    'string','Apply','Visible','off',...
    'Callback','goset(''ur_inbxapp'',gcbo,guidata(gcbo))');
handles.ur_inbxcncl=uicontrol('Style','pushbutton','position',[xpos+138 ypos+10 50 20],...
    'string','Cancel','Visible','off',...
    'Callback','goset(''ur_inbxcncl'',gcbo,guidata(gcbo))'); 
handles.ur_reset=uicontrol('Style','pushbutton','position',[xpos+78 ypos+10 50 20],...
    'string','Reset','Visible','off','ToolTipString','Reset the user routine selections',...
    'Callback','goset(''ur_reset'',gcbo,guidata(gcbo))');
handles.ur_pre_txt=uicontrol('Style','text','Position',[xpos+15 ypos+112 160 18],...
    'HorizontalAlignment','Left','String','M-file to excute before GA',...
    'Fontweight','Bold','ToolTipString','Name of the M-file to execute before starting GA',...
    'Visible','off');
handles.ur_pre_browse = uicontrol('Style','pushbutton','Position',...
      [xpos+150 ypos+97 50 18],'String','Browse',...
      'Callback','goset(''ur_pre_browse'',gcbo,guidata(gcbo))','Visible','off');
if isempty(data.ur_pre)
    urpredisp = 'none';
    data.ur_pre = [];
else
    urpredisp = data.ur_pre;
end  
handles.ur_pre = uicontrol('Style','text','Position',[xpos+15 ypos+98 125 15],...
    'BackgroundColor','W','String',urpredisp,'Visible','off'); 

handles.ur_post_txt = uicontrol('Style','text','Position',[xpos+15 ypos+63 160 18],...
    'HorizontalAlignment','Left','String','M-file to excute after GA',...
    'Fontweight','Bold','ToolTipString','Name of the M-file to execute after GA',...
    'Visible','off');
handles.ur_post_browse = uicontrol('Style','pushbutton','Position',...
      [xpos+150 ypos+48 50 18],'String','Browse',...
      'Callback','goset(''ur_post_browse'',gcbo,guidata(gcbo))','Visible','off');
if isempty(data.ur_post)
    urpostdisp = 'none';
    data.ur_post = [];
else
    urpostdisp = data.ur_post;
end  
handles.ur_post=uicontrol('Style','text','Position',[xpos+15 ypos+49 125 15],...
    'BackgroundColor','W','String',urpostdisp,'Visible','off'); 


if nofitfun
    % Mask some handles 
    set([handles.optionmenu handles.rp_lvl handles.rp_gbr...
        handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset handles.plotdata...
        handles.dispbst handles.gp_btn handles.fp_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn... 
        handles.mt_btn handles.gr_btn handles.mg_btn handles.ev_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','off')
end

setappdata(figH, 'Userdata', data);                 % store parameter 
setappdata(figH, 'GAS', GAS);                       
setappdata(figH, 'Recentfiles', recentfiles);       % store recentfiles vector
guidata(figH,handles);                              % store handles in the main window

% protect GUI window
set(figH,'Handlevisibility','off');

% =========================================================================
  % 
    % 
      %
        %    END OF GOSET INITIALIZATION
        % 
        %
        % =================================================================

        updaterecentfiles(recentfiles, handles);        % update recent files 
        
    end

elseif nargin & ischar(varargin{1})     % if the first argument is string, 
    feval(str2func(varargin{1}),varargin{2},varargin{3});  % run corresponding func.
end


% -------------------------------------------------------------------------
%   MENU    [File] [Setting] [Tools] [Help]
% -------------------------------------------------------------------------

% === SAVE DATA ========================================================
function savedata(hObject, handles)
GAP = getappdata(gcbf, 'Userdata');
P = getappdata(gcbf, 'P');
GAS = getappdata(gcbf, 'GAS');
 
if isempty(P) | isempty(GAS)
    uiwait(errordlg('There is no data for saving','Error','modal'));
else
    datetime = datestr(now,30);                     % default filename
    filename = strcat(GAP.ff_path,GAP.ff_name,'_data_',datetime(5:15));

    [filename,filepath] = uiputfile([filename '.mat'],'Save as');   % choose save path

    if isnumeric(filename) | isnumeric(filepath)    % if the filename or path is empty
        return;                                     % do nothing
    else
        save([filepath filename],'P','GAS','GAP');  % otherwise, save P, GAP, and GAS
    end
end

% === LOAD DATA ========================================================
function loaddata(hObject, handles)
data = getappdata(gcbf, 'Userdata');

[filename,pathname] = uigetfile('*.mat','Select a saved data file');

if filename                                     % if filename is nonempty
    
    dat = load('-mat',[pathname filename]);     % load P,GAS,GAP
    data = dat.GAP;
    P = dat.P;
    GAS = dat.GAS;
    
    if strmatch('bI',fieldnames(dat))           % check if bI field & load
        bI = dat.bI;
    else 
        bI = [];
    end
    
    setappdata(gcbf, 'Userdata', data);         % store the loaded P,GAS,GAP,bI
    setappdata(gcbf, 'P', P);
    setappdata(gcbf, 'GAS', GAS);
    setappdata(gcbf, 'bI', bI);
    data = checksetting(data);                  % check and fix setting
    setappdata(gcbf, 'Userdata', data);         % store parameter
    applysetting(hObject, handles);             % apply loaded settings
    
    set(handles.cg,'String',GAS.cg);            % update evolution Status
    set(handles.bestfit,'String',GAS.bestfit(GAS.cg));
    set(handles.meanfit,'String',GAS.meanfit(GAS.cg));
    pos = get(handles.pbar,'Position');
    pos(3) = 170*GAS.cg/data.fp_ngen;
    set(handles.pbar,'Position',pos);
    set(handles.pbar,'String',[num2str(round(pos(3)*0.5882)) '%']);
    
    % Restore 'Start' 'Continue' button status 
    if (data.fp_ngen > GAS.cg) & (GAS.cg > 1)   % start/continue case
        set(handles.startbtn,'visible','on');
        set(handles.startbtnoff,'visible','off');
        set(handles.stopbtn,'visible','off');
        set(handles.stopbtnoff,'visible','off');
        set(handles.contbtn,'visible','on');
        set(handles.contbtnoff,'visible','off');
    else                                        % start case
        set(handles.startbtn,'visible','on');
        set(handles.startbtnoff,'visible','off');
        set(handles.stopbtn,'visible','off');
        set(handles.stopbtnoff,'visible','on');
        set(handles.contbtn,'visible','off');
        set(handles.contbtnoff,'visible','off');
    end
   
end       

% === LOAD DEFAULT SETTING OPTION =========================================
function defaultsetting(hObject, handles)

if strcmp(questdlg(...              % reconfirm loading the default setting
    'Loading the default setting will erase current setting, Proceed?',...
    '','Yes','No','No'),'No')
    return;
end 

olddata = getappdata(gcbf,'Userdata');      % store settings

data = gapdefault(olddata.fp_nobj);         % load default parameters
                                          
data.ff_data = [];                          % define other parameter value
data.ff_data_store = [];
data.fp_nobj = 1;
data.ngenes = 3;
data.dspgene = 1;
data.descgene = {'gene #1'  'gene #2'  'gene #3'};
data.gd_min = [0 0 0];
data.gd_max = [1 1 1];
data.gd_type = [2 2 2];
data.gd_cid = [1 1 1];  
data.ur_pre = [];
data.ur_post = []; 


data.ff_name = olddata.ff_name;             % restore orginal filename and path
data.ff_path = olddata.ff_path;

setappdata(gcbf, 'Userdata', data);         % refresh parameter data
applysetting(hObject, handles);             % refresh handles

% === SAVE CURRENT SETTING OPTION =========================================
function savesetting(hObject, handles, file, data)
if exist([file '.m'])      % exist current fitfun?
    save([file '.set'],'data');    % save settings 
end

% === Trim GA ========================================================
function trim_ga(hObject, handles)
data = getappdata(gcbf, 'Userdata');
P = getappdata(gcbf, 'P');

if data.fp_nobj == 1
    if isempty(P) 
        uiwait(warndlg('There is no population to process.','TRIM GA: Warning','modal'));
    else
        disablesomeinput(hObject, handles);
        set([handles.tg_inbxsdw handles.tg_inbx1 handles.tg_inbx2...
            handles.tg_inbxtitle handles.tg_inbxstart handles.tg_inbxadopt...
            handles.tg_inbxclose handles.tg_txt handles.tg_orifit_txt...
            handles.tg_orifit handles.tg_newfit_txt handles.tg_newfit],...
            'visible','on');
        
        set(handles.tg_inbxadopt,'Enable','off');
        set([handles.tg_inbxstart handles.tg_inbxclose],'Enable','on');
        set(handles.tg_newfit,'String','');       
        set(handles.tg_txt,'String','Click ''Start'' to initiate TRIMGA.');

        % display current best fit
        set(handles.tg_orifit,'String',get(handles.bestfit,'String'));

    end
else
    uiwait(warndlg('Trim GA works for the single objective optimization only.',...
            'TRIM GA: Warning','modal'));   
end


% === Start button ========================================================
function tg_inbxstart(hObject, handles)
data = getappdata(gcbf, 'Userdata');


% Check optinal data for fitness function 
if isstr(data.ff_data)
    if exist([data.ff_path data.ff_data],'file') == 2;  % Exist as a MAT-file in fit func directory                        
        temp = load(data.ff_data);                 % as a valid data file name
        fldname = fieldnames(temp);
        optdata = getfield(temp,fldname{1});
    elseif evalin('base',['exist(''',data.ff_data,''',''var'')']);
        optdata = evalin('base',data.ff_data);
    else 
        uiwait(msgbox('Invalid optional data for the fitness function.','Error','Error','modal'));
        return
    end 
else
    if isempty(data.ff_data);
        optdata = [];
    else
        optdata = data.ff_data;
    end
end


set(handles.tg_txt,'string','Trim GA running. Please Wait...');
set([ handles.tg_inbxstart handles.tg_inbxadopt handles.tg_inbxclose ],'Enable','off');


P = getappdata(gcbf, 'P');

if isempty(optdata)
    [tgx,tgfit]=trimga(data,P);
else
	[tgx,tgfit]=trimga(data,P,optdata);
end

% Display the resultant fitness
set(handles.tg_newfit,'String',num2str(tgfit));
    
% Store current solution
set(handles.tg_newfit,'Userdata',tgx)
           
set(handles.tg_txt,'string',{'TRIMGA finished.';...
    'Click ''Adopt'' to inlclude the resultant solution in the current population.'});
set([ handles.tg_inbxstart handles.tg_inbxadopt handles.tg_inbxclose ],...
	'Enable','on');


% === Adopt button =======================================================
function tg_inbxadopt(hObject, handles)
data = getappdata(gcbf, 'Userdata');
P = getappdata(gcbf, 'P');

% Find the worst solution
[worstfit worstIdx] = min(P.mfit(data.fp_obj,:));

% Replace the worst solution with the new solution
newfit = str2double(get(handles.tg_newfit,'String'));
P.mfit(data.fp_obj,worstIdx) = newfit;
P.gene(:,worstIdx) = get(handles.tg_newfit,'Userdata');
P.eval(worstIdx) = 0;
P = normgene(P);
% Store updated P
setappdata(gcbf, 'P', P);

% Update best fitness
set(handles.bestfit,'String',num2str(newfit));
set(handles.tg_orifit,'String',num2str(newfit));

% Lease 'Close' option only
set([ handles.tg_inbxstart handles.tg_inbxadopt ],'Enable','off');

set(handles.tg_txt,'string','New fitness has been included in the current population.');

% === Close button =======================================================
function tg_inbxclose(hObject, handles)
set([ handles.tg_inbxsdw handles.tg_inbx1 handles.tg_inbx2...
	handles.tg_inbxtitle handles.tg_inbxstart handles.tg_inbxadopt...
    handles.tg_inbxclose handles.tg_txt handles.tg_orifit_txt...
    handles.tg_orifit handles.tg_newfit_txt handles.tg_newfit],'visible','off');

%data = getappdata(gcbf, 'Userdata');
%set(handles.gr_alg, 'Value', data.gr_alg);
enablesomeinput(hObject, handles);
 
 
% === User routine ========================================================
function userroutine(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.ur_inbxsdw handles.ur_inbx1 handles.ur_inbx2...
     handles.ur_inbxtitle handles.ur_inbxapp handles.ur_reset handles.ur_inbxcncl...
     handles.ur_pre_txt handles.ur_pre_browse handles.ur_pre...
     handles.ur_post_txt handles.ur_post_browse handles.ur_post],'visible','on');

% === Apply button ========================================================
function ur_inbxapp(hObject, handles)
enablesomeinput(hObject, handles);
set([handles.ur_inbxsdw handles.ur_inbx1 handles.ur_inbx2...
     handles.ur_inbxtitle handles.ur_inbxapp handles.ur_reset handles.ur_inbxcncl...
     handles.ur_pre_txt handles.ur_pre_browse handles.ur_pre...
     handles.ur_post_txt handles.ur_post_browse handles.ur_post],'visible','off');

% Update filenames
data = getappdata(gcbf,'Userdata');
data.ur_pre = get(handles.ur_pre,'String');
if strcmp(data.ur_pre,'none')
    data.ur_pre = '';
end
data.ur_post = get(handles.ur_post,'String');
if strcmp(data.ur_post,'none')
    data.ur_post = '';
end
setappdata(gcbf, 'Userdata', data);  

% === Cancel button =======================================================
function ur_inbxcncl(hObject, handles)
enablesomeinput(hObject, handles);
set([handles.ur_inbxsdw handles.ur_inbx1 handles.ur_inbx2...
     handles.ur_inbxtitle handles.ur_inbxapp handles.ur_reset handles.ur_inbxcncl...
     handles.ur_pre_txt handles.ur_pre_browse handles.ur_pre...
     handles.ur_post_txt handles.ur_post_browse handles.ur_post],'visible','off');

% Restore the old filename
data = getappdata(gcbf,'Userdata');
if isempty(data.ur_pre)
    urpredisp = 'none';
else
    urpredisp = data.ur_pre;
end 
set(handles.ur_pre,'String',urpredisp);

if isempty(data.ur_post)
    urpostdisp = 'none';
else
    urpostdisp = data.ur_post;
end 
set(handles.ur_post,'String',urpostdisp);

% === Reset user routine files ============================================
function ur_reset(hObject, handles)
data = getappdata(gcbf, 'Userdata');
data.ur_pre = [];
data.ur_post = [];
setappdata(gcbf, 'Userdata', data);
set(handles.ur_pre,'String','none');
set(handles.ur_post,'String','none');

% === Pre-execution file name browse button =============================================
function ur_pre_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

% get the fitness function file
[filename,pathname] = uigetfile('*.m','Select the M-file to execute before starting GA');

if filename     % filename is nonempty
    if strcmp(data.ff_path,pathname) % paths are same
        if ~strcmp(data.ur_pre, filename) % if the file is different from present one
            set(handles.ur_pre,'String',filename);     % update infos and change directory  
        end 
    else
        uiwait(errordlg('File must be in the same folder as the fitness function file','Error','modal'));
        if isempty(data.ur_pre)
            urpredisp = 'none';
        else
            urpredisp = data.ur_pre;
        end  
        set(handles.ur_pre,'String',urpredisp);
    end
end

% === Post-execution file name browse button =============================================
function ur_post_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

% get the fitness function file
[filename,pathname] = uigetfile('*.m','Select the M-file to execute after finising GA');

if filename     % filename is nonempty
    if strcmp(data.ff_path,pathname) % paths are same
        if ~strcmp(data.ur_post, filename) % if the file is different from present one
            set(handles.ur_post,'String',filename);     % update infos
        end 
    else
        uiwait(errordlg('File must be in the same folder as the fitness function file','Error','modal'));
        if isempty(data.ur_post)
            urpostdisp = 'none';
        else
            urpostdisp = data.ur_post;
        end  
        set(handles.ur_post,'String',urpostdisp);
    end
end

% === About GOSET  ========================================================
function aboutgoset(hObject, handles)

figHandles = allchild(0);
figH = findobj(figHandles, 'flat', 'Name', 'About GOSET');

if ~isempty(figH)                   % if the GUI already exist,
        figure(figH);                   % activate it
    handles = guihandles(figH);     % get handles of the GUI 
else
    pos = get(handles.figH,'Position');
    pos = [pos(1)+50 pos(2)+pos(4)-350 300 300];
    figH = figure('Position',pos,'Resize','off','NumberTitle','off',...
    'Name','About GOSET','Interruptible','on','Menubar','none',...
    'Color','w');
    uicontrol('Style','text','position',[10 50 280 250],'String',{'','GOSET'},...
        'Fontweight','Bold','Fontname','Century Gothic','Fontsize',24);
    gosetver = get(handles.figH,'Name');
    ver = gosetver(length(gosetver)-3:length(gosetver));
    gosetdesc = {'','Genetic Optimization System Engineering Tool',''...
            ['Version ',ver],'','','',...
            '--------------------------------------'};
    uicontrol('Style','text','position',[10 40 280 180],'String',gosetdesc);
    uicontrol('Style','pushbutton','position',[110 8 80 24],'String','OK',...
            'Callback','close(gcbf)')
end

% === Forced exit GOSET ===================================================
function forcedexit(hObject, handles)
answer = questdlg('This will close GOSET without saving information. Proceed?','Forced exit','Yes','No','No');
if strcmp(answer,'Yes')

    %close all figures
    figHandles = allchild(0);
    figH = findobj(figHandles, 'flat', 'Tag', 'reportplot');
    if ~isempty(figH)
        delete(figH);    
    end
   
    closereq;   % close GOSET
end 
% -------------------------------------------------------------------------
%   Report
% -------------------------------------------------------------------------
% === REPORTING LEVEL =====================================================
function rp_lvl(hObject, handles)           
rplevel = get(hObject,'Value');
data = getappdata(gcbf, 'Userdata');
data.rp_lvl = rplevel-2;
if rplevel == 1
    set(handles.rp_gbr,'Enable','off')
else  
    set(handles.rp_gbr,'Enable','on')
end
setappdata(gcbf, 'Userdata', data);

% === GENERATION BETWEEN REPORTS ==========================================
function rp_gbr(hObject, handles)     
goset('numericinputtest',gcbo,guidata(gcbo))

rpgbr = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');
data.rp_gbr = rpgbr;
setappdata(gcbf, 'Userdata', data);

% === Custom report file name browse button ===============================
function rp_crh_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

% get the fitness function file
[filename,pathname] = uigetfile({'*.m'},'Select the M-file for the custom selection operator');

if filename     % filename is nonempty
    if strcmp(data.ff_path,pathname) | strcmp(data.gosetpath,pathname) % Is the path valid?
        if ~strcmp(data.rp_crh, filename)   % if the file is different from present one
            set(handles.rp_crh,'String',filename);     % update infos  
            data.rp_crh = [filename(1:(length(filename)-2))];
            setappdata(gcbf, 'Userdata', data);
        end 
    else
        uiwait(errordlg('Custom algorithm must be in the same folder as the fitness function file or in the GOSET folder','Error','modal'));
        if isempty(data.rp_crh)
            set(handles.rp_crh,'String','none');
        else
            set(handles.rp_crh,'String',[data.rp_crh,'.m']);
        end
    end
end

% === RESET CUSTOM REPORT FILE NAME =======================================
function rp_crh_reset(hObject, handles)
if strcmp(questdlg(...              % reconfirm loading the default setting
    'This will reset the custom report file to ''none'', Proceed?',...
    'Resetting custom report','Yes','No','No'),'No')
    return;
end 

data = getappdata(gcbf, 'Userdata');
data.rp_crh = [];
set(handles.rp_crh,'String','none');
setappdata(gcbf, 'Userdata', data);

% === PLOT CURRENT DATA ===================================================
function plotdata(hObject, handles)         
data = getappdata(gcbf,'Userdata');
P = getappdata(gcbf,'P');
GAS = getappdata(gcbf,'GAS');
if isempty(P) | isempty(GAS)
    uiwait(errordlg('There is no data for plotting','Error','modal'));
else
    data.rp_lvl = 1;            % temporarily set reporting level for text and plot
    data.rp_gbr = 1;            % temporarily set the reporting interval to '1' : 
    data.fp_ngen = GAS.cg;      % number of generation to plot = current generation
    reportplot(data,GAS,P,[]);  % plot
end

% === DISPLAY THE BEST INDIVIDUAL VALUES =================================
function dispbst(hObject, handles)        
data = getappdata(gcbf,'Userdata');
P = getappdata(gcbf,'P');
GAS = getappdata(gcbf,'GAS');

if isempty(P) | isempty(GAS)            % check the existence 
    uiwait(errordlg('There is no individual to display','Error','modal'));
else   
    figH = findobj('Name','Gene values of the best individual');        
    if ~isempty(figH)                   % if the figure already exist,
        Hdl = guidata(figH);            % get the stored handles
        for i=1:data.ngenes             % and update only values
            eval(['set(Hdl.h' num2str(i) ',''String'','''...
                   num2str(GAS.bestgenes(i,GAS.cg)) ''');']);
            set(Hdl.cg,'String',num2str(GAS.cg));
        end                       
    else  
        fWd = 390;
        fHt = data.ngenes*15 + 45;
    
        screen_s = get(0,'ScreenSize');
        pos = [screen_s(3)/2-fWd/2, screen_s(4)/2-fHt/2, fWd, fHt];
  
        figH = figure('Position',pos,'Resize','off','NumberTitle','off',...
               'Name','Gene values of the best individual','Menubar',...
               'none','Tag','reportplot',...
               'Color',get(0,'DefaultUIControlBackgroundColor'));
        Hdl = guihandles(figH);
        uicontrol('Position',[1 data.ngenes*15+29 390 16],...
                'Style','text','HorizontalAlignment','Left','String',...
                '     Generation Number:  ','Backgroundcolor','k',...
                'Foregroundcolor','w','FontSize',10,'FontWeight','Bold');
        Hdl.cg = uicontrol('Position',[160 data.ngenes*15+29 60 16],...
                'Style','text','String',num2str(GAS.cg),'FontSize',10,...
                'Backgroundcolor','k','Foregroundcolor','w',...
                'HorizontalAlignment','Left','FontWeight','Bold');
        uicontrol('Position',[20 data.ngenes*15+10 80 15],...
                'Style','text','HorizontalAlignment','Left',...
                'String','Gene No.','FontWeight','Bold');
        uicontrol('Position',[130 data.ngenes*15+10 150 15],...
                'Style','text','HorizontalAlignment','Left',...
                'String','Description','FontWeight','Bold');
        uicontrol('Position',[300 data.ngenes*15+10 150 15],...
                'Style','text','HorizontalAlignment','Left',...
                'String','Value','FontWeight','Bold');
        
  
        clr={get(0,'DefaultUIControlBackgroundColor'),[0.753 0.753 0.753]};
    
        for i=1:data.ngenes
            c = mod(i,2)+1;     % change backgroundcolor every other line
            uicontrol('Position',[0 (data.ngenes-i)*15+5 90 15],...
                    'Style','text','BackgroundColor',clr{c},...
                    'String',num2str(i));
            uicontrol('Position',[90 (data.ngenes-i)*15+5 150 15],...
                    'Style','text','BackgroundColor',clr{c},...
                    'String',data.descgene(i));
            uicontrol('Position',[240 (data.ngenes-i)*15+5 150 15],...
                    'Style','text','BackgroundColor',clr{c},...
                    'String', num2str(GAS.bestgenes(i,GAS.cg)));
            eval(['Hdl.h' num2str(i) '=uicontrol(figH,''Style'','...
                '''text'',''Position'',[240 (data.ngenes-' num2str(i) ...
                ')*15+5 150 15],''Backgroundcolor'',clr{' num2str(c) '}'...
                ',''String'',''' num2str(GAS.bestgenes(i,GAS.cg)) ''');']);
        end
        guidata(figH,Hdl);      % Store handles 
    end
end
  
% -------------------------------------------------------------------------
%   BUTTONS
% -------------------------------------------------------------------------
% === START BUTTON ========================================================
function startbtn(hObject, handles)
global simflag                          % define status flag
data = getappdata(gcbf, 'Userdata');    

% Fitness function existence check
if exist([data.ff_path data.ff_name '.m'],'file') == 2
    cd(data.ff_path);                   % if exist, change directory 
else                                    % else, show error message and return
    uiwait(msgbox('Fitness function does not exist','Error','Error','modal'));
    return
end

evalin('base','clear P GAS GAP bI Data');       % delete existing P,GAS,GAP,bI


% Check optinal data for fitness function 
if isstr(data.ff_data)
    if exist([data.ff_path data.ff_data],'file') == 2;  % Exist as a MAT-file in fit func directory                        
        temp = load(data.ff_data);                 % as a valid data file name
        fldname = fieldnames(temp);
        optdata = getfield(temp,fldname{1});
    elseif evalin('base',['exist(''',data.ff_data,''',''var'')']);
        optdata = evalin('base',data.ff_data);
    else 
        uiwait(msgbox('Invalid optional data for the fitness function.','Error','Error','modal'));
        return
    end 
else
    if isempty(data.ff_data);
        optdata = [];
    else
        optdata = data.ff_data;
    end
end


% User routine existence check
if ~isempty(data.ur_pre)
    if exist([data.ff_path data.ur_pre],'file') == 2
        urprename=data.ur_pre(1:length(data.ur_pre)-2);
        evalin('base',urprename);       % if exist, execute in the BASE workspace
                                        % and load appropriate data to workspace           
        if evalin('base','exist(''Data'',''var'')')
            optdata = evalin('base','Data');
            set(handles.ff_data,'String','[ Defined in the user routine ]');
        end
        disp(sprintf('User routine mfile ''%s'' executed sucessfully\n',data.ur_pre));
    else                            % else, show error message and return
        uiwait(msgbox(['User routine mfile ''' data.ur_pre ''' does not exist'],'Error','Error','modal'));
        return
    end
end

if isempty(data.sl_cah) & (data.sl_alg==3)
    uiwait(msgbox('Custom selection algorithm is not defined.','Error','Error','modal'));
    return
end

if isempty(data.dt_cah) & (data.dt_alg==5)
    uiwait(msgbox('Custom death algorithm is not defined.','Error','Error','modal'));
    return
end

simflag = 1;                            % set status flag for 'START mode'

set(handles.cg,'String',1);             % set the current generation as 1           

% Display only the STOP button 
set(handles.startbtn,'visible','off');
set(handles.startbtnoff,'visible','on');
set(handles.stopbtn,'visible','on');
set(handles.stopbtnoff,'visible','off');
set(handles.contbtn,'visible','off');
set(handles.contbtnoff,'visible','off');

% Mask some handles during the simunation run
set([handles.setmenu handles.filemenu handles.optionmenu handles.helpmenu...
     handles.rp_lvl handles.rp_gbr handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
     handles.plotdata handles.dispbst handles.ff_btn handles.gp_btn...
     handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
     handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
     handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
     handles.rs_btn handles.or_btn],'Enable','off')
set([handles.dc_act handles.el_act],'BackgroundColor',.7*ones(1,3));

% Start the simulation
[P,GAS,bI]= gaoptimize(data.ff_name,data,optdata,[],[],handles);

setappdata(gcbf,'P',P);
setappdata(gcbf,'GAS',GAS);
setappdata(gcbf,'bI',bI);

% Export P,GAS,GAP to workspace
assignin('base','P',P);
assignin('base','GAS',GAS);
assignin('base','bI',bI);

GAPfldlist = { 'fp_ngen' 'fp_ipop' 'fp_npop' 'fp_nobj' 'fp_obj' 'dc_act'...
            'dc_alg' 'dc_spc' 'dc_mnt' 'dc_mxt' 'dc_ntr' 'dc_mnb'...
            'dc_mxb' 'dc_dc' 'dc_nt' 'sl_alg' 'sl_nts' 'sl_cah' 'dt_alg'...
            'dt_nts' 'dt_cah' 'mc_pp' 'mc_fc' 'mc_alg' 'mc_gac' 'mc_ec'...
            'mt_ptgm' 'mt_prgm' 'mt_srgm' 'mt_pagm' 'mt_sagm' 'mt_prvm'...
            'mt_srvm' 'mt_pavm' 'mt_savm' 'mt_pigm' 'gr_alg' 'mg_nreg' 'mg_tmig'...
            'mg_pmig' 'ev_bev' 'ev_are' 'ev_ssd' 'sc_alg' 'sc_kln'...
            'sc_cst' 'sc_kmxq' 'sc_kmnq' 'el_act' 'el_fgs' 'el_fpe'...
            'rs_fgs' 'rs_fps' 'rs_srp' 'rs_sap' 'rs_frp' 'rs_fea'...
            'rp_lvl' 'rp_gbr' 'rp_crh' 'op_list' 'op_style' 'op_sign'...
            'pp_list' 'pp_xl' 'pp_yl' 'pp_zl' 'pp_title' 'pp_style' 'pp_sign'...
            'pp_axis' 'dp_type' 'dp_np' 'dp_res' 'gd_min' 'gd_max'...
            'gd_type' 'gd_cid'};
        
for i=1:length(GAPfldlist)
    eval(['gapara.' GAPfldlist{i} '=data.' GAPfldlist{i} ';' ]);
end   
assignin('base','GAP',gapara);

if simflag > 0                             % if simulation terminated normally
    % User routine existence check
    if ~isempty(data.ur_post)
        if exist([data.ff_path data.ur_post],'file') == 2
            urpostname=data.ur_post(1:length(data.ur_post)-2);
            evalin('base',urpostname);  % if exist, execute 
            disp(sprintf('User routine mfile ''%s'' executed sucessfully\n',data.ur_post));
        else                            
            uiwait(msgbox(['User routine mfile ''' data.ur_post ''' does not exist'],'Error','Error','modal'));
            return
        end
    end
    
    set(handles.startbtn,'visible','on');          % show only START button 
    set(handles.startbtnoff,'visible','off');
    set(handles.stopbtn,'visible','off');
    set(handles.stopbtnoff,'visible','on');
    set(handles.contbtn,'visible','off');
    set(handles.contbtnoff,'visible','off');
    
    % Unmask handles 
    set([handles.setmenu handles.filemenu handles.optionmenu...
        handles.helpmenu handles.rp_lvl handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
        handles.plotdata handles.dispbst handles.ff_btn handles.gp_btn...
        handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
        handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','on')
    if get(handles.rp_lvl,'value') > 1
        set(handles.rp_gbr,'Enable','on');
    end 
    if get(handles.dc_act,'value')
        set(handles.dc_act,'BackgroundColor','w');
    else 
        set(handles.dc_act,'BackgroundColor',.7*ones(1,3));
    end
    if get(handles.el_act,'value')
        set(handles.el_act,'BackgroundColor','w');
    else 
        set(handles.el_act,'BackgroundColor',.7*ones(1,3));
    end
end

% === STOP BUTTON =========================================================
function stopbtn(hObject, handles)
global simflag                          % define status flag
simflag  = 0;                           % set status flag for 'STOP mode'
               
set(handles.startbtn,'visible','on');   % show 'START' & 'CONTINUE' button
set(handles.startbtnoff,'visible','off');
set(handles.stopbtn,'visible','off');
set(handles.stopbtnoff,'visible','off');
set(handles.contbtn,'visible','on');
set(handles.contbtnoff,'visible','off');

% Unmask handles
    set([handles.setmenu handles.filemenu handles.optionmenu...
        handles.helpmenu handles.rp_lvl handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
        handles.plotdata handles.dispbst handles.ff_btn handles.gp_btn...
        handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
        handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','on')
if get(handles.rp_lvl,'value') > 1
    set(handles.rp_gbr,'Enable','on');
end 
if get(handles.dc_act,'value')
    set(handles.dc_act,'BackgroundColor','w');
else 
    set(handles.dc_act,'BackgroundColor',.7*ones(1,3));
end
if get(handles.el_act,'value')
    set(handles.el_act,'BackgroundColor','w');
else 
    set(handles.el_act,'BackgroundColor',.7*ones(1,3));
end

% === CONTINUE BUTTON =====================================================
function contbtn(hObject, handles)
global simflag                          % define status flag
data = getappdata(gcbf,'Userdata');     

% Fitness function existence check
if exist([data.ff_path data.ff_name '.m'],'file') == 2
    cd(data.ff_path);
else    
    uiwait(msgbox('Fitness function does not exist','Error','Error','modal'));
    return;
end

simflag = 2;                            % set status flag for 'CONTINUE mode'
P = getappdata(gcbf,'P');
GAS = getappdata(gcbf,'GAS');

set(handles.startbtn,'visible','off');  % show only 'STOP' button
set(handles.startbtnoff,'visible','on');
set(handles.stopbtn,'visible','on');
set(handles.stopbtnoff,'visible','off');
set(handles.contbtn,'visible','off');
set(handles.contbtnoff,'visible','off');

% Mask some handles during the simulation run
    set([handles.setmenu handles.filemenu handles.optionmenu...
        handles.helpmenu handles.rp_lvl handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
        handles.plotdata handles.dispbst handles.ff_btn handles.gp_btn...
        handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
        handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','off')
set([handles.dc_act handles.el_act],'BackgroundColor',.7*ones(1,3));

% If the generation # has been increased, change the size of GAS.best
old_ngen = size(GAS.bestfit,2);
if data.fp_ngen > old_ngen     
    GAS.best(:,old_ngen+1:data.fp_ngen) = NaN; 
end

% Check optinal data for fitness function 
if isstr(data.ff_data)
    if exist([data.ff_path data.ff_data],'file') == 2;  % Exist as a MAT-file in fit func directory                        
        temp = load(data.ff_data);                 % as a valid data file name
        fldname = fieldnames(temp);
        optdata = getfield(temp,fldname{1});
    elseif evalin('base',['exist(''',data.ff_data,''',''var'')']);
        optdata = evalin('base',data.ff_data);
    else 
        uiwait(msgbox('Invalid optional data for the fitness function.',...
               'Error','Error','modal'));
        return
    end 
else
    if isempty(data.ff_data);
        optdata = [];
    else
        optdata = data.ff_data;
    end
end

% Start the simulation
[P,GAS,bI]= gaoptimize(data.ff_name,data,optdata,GAS,P,handles);

% refresh P, GAS, data
setappdata(gcbf,'P',P);
setappdata(gcbf,'GAS',GAS);
setappdata(gcbf,'Userdata',data); 
setappdata(gcbf,'bI',bI);

% Export P,GAS,GAP to workspace
assignin('base','P',P);
assignin('base','GAS',GAS);
assignin('base','bI',bI);

GAPfldlist = { 'fp_ngen' 'fp_ipop' 'fp_npop' 'fp_nobj' 'fp_obj' 'dc_act'...
            'dc_alg' 'dc_spc' 'dc_mnt' 'dc_mxt' 'dc_ntr' 'dc_mnb'...
            'dc_mxb' 'dc_dc' 'dc_nt' 'sl_alg' 'sl_nts' 'sl_cah' 'dt_alg'...
            'dt_nts' 'dt_cah' 'mc_pp' 'mc_fc' 'mc_alg' 'mc_gac' 'mc_ec'...
            'mt_ptgm' 'mt_prgm' 'mt_srgm' 'mt_pagm' 'mt_sagm' 'mt_prvm'...
            'mt_srvm' 'mt_pavm' 'mt_savm' 'mt_pigm' 'mg_nreg' 'mg_tmig'...
            'mg_pmig' 'ev_bev' 'ev_are' 'ev_ssd' 'sc_alg' 'sc_kln'...
            'sc_cst' 'sc_kmxq' 'sc_kmnq' 'el_act' 'el_fgs' 'el_fpe'...
            'rs_fgs' 'rs_fps' 'rs_srp' 'rs_sap' 'rs_frp' 'rs_fea'...
            'rp_lvl' 'rp_gbr' 'rp_crh' 'op_list' 'op_style' 'op_sign'...
            'pp_list' 'pp_xl' 'pp_yl' 'pp_zl' 'pp_title' 'pp_style' 'pp_sign'...
            'pp_axis' 'dp_type' 'dp_np' 'dp_res' 'gd_min' 'gd_max'...
            'gd_type' 'gd_cid'};
        
for i=1:length(GAPfldlist)
    eval(['gapara.' GAPfldlist{i} '=data.' GAPfldlist{i} ';' ]);
end   
assignin('base','GAP',gapara);

    if simflag > 0                  % if simulation terminated without stopping  
    % User routine existence check
    if ~isempty(data.ur_post)
        if exist([data.ff_path data.ur_post],'file') == 2
            urpostname=data.ur_post(1:length(data.ur_post)-2);
            evalin('base',urpostname);  % if exist, execute 
            disp(sprintf('User routine mfile ''%s'' executed sucessfully\n',data.ur_post));
        else                            % else, show error message and return
            uiwait(msgbox(['User routine mfile ''' data.ur_post ''' does not exist'],'Error','Error','modal'));
            return
        end
    end

    set(handles.startbtn,'visible','on');   % show only 'START' button
    set(handles.startbtnoff,'visible','off');
    set(handles.stopbtn,'visible','off');
    set(handles.stopbtnoff,'visible','on');
    set(handles.contbtn,'visible','off');
    set(handles.contbtnoff,'visible','off');
    
    % Unmask handles
    set([handles.setmenu handles.filemenu handles.optionmenu...
        handles.helpmenu handles.rp_lvl handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
        handles.plotdata handles.dispbst handles.ff_btn handles.gp_btn...
        handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
        handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','on')
    if get(handles.rp_lvl,'value') > 1  
        set(handles.rp_gbr,'Enable','on');
    end 
    if get(handles.dc_act,'value')
        set(handles.dc_act,'BackgroundColor','w');
    else 
        set(handles.dc_act,'BackgroundColor',.7*ones(1,3));
    end
    if get(handles.el_act,'value')
        set(handles.el_act,'BackgroundColor','w');
    else 
        set(handles.el_act,'BackgroundColor',.7*ones(1,3));
    end
end


% =========================================================================
%   Main windows 
% =========================================================================
%
% -------------------------------------------------------------------------
%   Fitness Function
% -------------------------------------------------------------------------
% === Fitness function button =============================================
function ff_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.ff_inbxsdw handles.ff_inbx1 handles.ff_inbx2...
     handles.ff_inbxtitle handles.ff_inbxapp handles.ff_inbxcncl...
     handles.ff_name_txt handles.ff_name_browse handles.ff_name...
     handles.ff_data_txt...
     handles.ff_data_browse handles.ff_data],...
     'visible','on');

% Store the old path name and the old optional data
data = getappdata(gcbf,'Userdata');
set(handles.ff_btn,'Userdata',data);

% === Apply button ========================================================
function ff_inbxapp(hObject, handles)

data = getappdata(gcbf,'Userdata');
olddata = get(handles.ff_btn,'Userdata');
recentfiles = getappdata(gcbf, 'Recentfiles');

% old file [ olddata.ff_path olddata.ff_name '.m']
% new file [ data.ff_path data.ff_name '.m' ]

if strcmp(data.ff_name,'Choose fitness function');  % file is not defined
    set([handles.ff_inbxsdw handles.ff_inbx1 handles.ff_inbx2...
        handles.ff_inbxtitle handles.ff_inbxapp handles.ff_inbxcncl...
        handles.ff_name_txt handles.ff_name_browse handles.ff_name...
        handles.ff_data_txt...
        handles.ff_data_browse handles.ff_data],...
        'visible','off');
    enablesomeinput(hObject, handles);
    set([handles.optionmenu handles.rp_lvl handles.rp_gbr...
        handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
        handles.plotdata handles.dispbst handles.gp_btn...
        handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
        handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','off');
    return
    
% if the file has been changed
elseif ~strcmp([olddata.ff_path olddata.ff_name],[data.ff_path data.ff_name]) 
    if ~strcmp(olddata.ff_name,'Choose fitness function') &... % old file name is not 'Choose fitness...'
        strcmp(questdlg(...              % reconfirm loading the default setting
        {['Do you want to save current settings for ''', olddata.ff_name, '.m'' ?'],'',...
        'Any unsaved changes will be lost.',''},'Save current setting','Yes','No','No'),'Yes')
        savesetting(hObject,handles,[olddata.ff_path, olddata.ff_name],olddata);       
    end 

    set(handles.ff_dsp,'String',[data.ff_name '.m'],'ForegroundColor','K');
    
    figHandles = allchild(0);       % close figures
    figH = findobj(figHandles, 'flat', 'Tag', 'reportplot');
    if ~isempty(figH)
        delete(figH);
    end
    
    GAS = getappdata(gcbf, 'GAS');          % reset current generation No.
    GAS.cg = 1;
    setappdata(gcbf,'GAS',GAS);
    set(handles.cg,'String','');            % update 'Evolution Status'
    set(handles.bestfit,'String','');
    set(handles.meanfit,'String','');
    pos=get(handles.pbar,'Position');
    pos(3)=170;
    set(handles.pbar,'Position',pos);
    set(handles.pbar,'String','Progress bar'); 
    setappdata(gcbf, 'P', []);              % reset the population information
 
    % Reorder recent file list and update
    idx = find(strcmp([data.ff_path data.ff_name '.m'],recentfiles));
    if isempty(idx)     % CASE 1 : the file is NOT one of the recent files
        for i = 1:5
            recentfiles{7-i} = recentfiles{6-i};
        end  
    elseif idx ~=1      % CASE 2 : the file is not the first recent file
        for i=1:idx-1
            recentfiles{idx+1-i} = recentfiles{idx-i};
        end        
    end
    recentfiles{1} = [data.ff_path data.ff_name '.m'];
    updaterecentfiles(recentfiles, handles);

else % fitness function is same
    
    % Optional data file 
    datainput = get(handles.ff_data,'String');
    D = str2num(datainput);

    if ~isempty(D)           % input is numerical data vector 
        data.ff_data = D; 
    elseif exist([data.ff_path datainput],'file')==2;  % Exist as a MAT-file in fit func directory
        data.ff_data = datainput;                      % as a valid data file name   
        data.ff_data_store = [];
    elseif strcmp(datainput,'none')      % none
        data.ff_data = [];
        data.ff_data_store = [];
    else            % exist as a variable in workspace
        data.ff_data = datainput;
        data.ff_data_store = evalin('base',datainput);
    end 
end

set(handles.ff_btn,'Userdata',[]');     % Remove the stored data

setappdata(gcbf, 'Userdata', data);
setappdata(gcbf, 'Recentfiles', recentfiles);

set([handles.ff_inbxsdw handles.ff_inbx1 handles.ff_inbx2...
     handles.ff_inbxtitle handles.ff_inbxapp handles.ff_inbxcncl...
     handles.ff_name_txt handles.ff_name_browse handles.ff_name...
     handles.ff_data_txt...
     handles.ff_data_browse handles.ff_data],'visible','off');
enablesomeinput(hObject, handles);
set([handles.rp_lvl handles.rp_gbr handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
    handles.plotdata handles.dispbst handles.gp_btn...
    handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
    handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
    handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
    handles.rs_btn handles.or_btn],'Enable','on');
    
% === Cancel button =======================================================
function ff_inbxcncl(hObject, handles)
set([handles.ff_inbxsdw handles.ff_inbx1 handles.ff_inbx2...
     handles.ff_inbxtitle handles.ff_inbxapp handles.ff_inbxcncl...
     handles.ff_name_txt handles.ff_name_browse handles.ff_name...
     handles.ff_data_txt...
     handles.ff_data_browse handles.ff_data],'visible','off');
set(handles.ff_btn,'Enable','on');

% Revert setting
data = get(handles.ff_btn,'Userdata');  % Load original setting
set(handles.ff_btn,'Userdata',[]');     % Remove the stored data
setappdata(gcbf, 'Userdata', data);     % Apply setting
applysetting(hObject,handles);

% go back to old path if the fitness func exist
if exist([data.ff_path data.ff_name '.m'],'file')
    cd(data.ff_path);       
end

enablesomeinput(hObject, handles);
if strcmp(data.ff_name,'Choose fitness function') % fit func has not been defined
    set([handles.optionmenu handles.rp_lvl handles.rp_gbr...
        handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset...
        handles.plotdata handles.dispbst handles.gp_btn...
        handles.fp_btn handles.ev_btn handles.dc_btn handles.dc_act...
        handles.sc_btn handles.sl_btn handles.dt_btn handles.mc_btn...
        handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn handles.el_act...
        handles.rs_btn handles.or_btn],'Enable','off');
end;

% === File name browse button =============================================
function ff_name_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

% get the fitness function file
[filename,pathname] = uigetfile({'*.m'},'Select the fitness function M-file');

if filename     % filename is nonempty
   if strcmp([data.ff_path data.ff_name '.m'],[pathname filename]) % if the file is same as the current one     
       return;
   else                                    % if the file is different than the current one
        set(handles.ff_name,'String',filename,'ForegroundColor','K');     % update infos and change directory
        cd(pathname);       % go to new path
        if exist([pathname filename(1:length(filename)-2) '.set'],'file')  % if the setting file exists
            load('-mat',[filename(1:length(filename)-2) '.set']);
            data = checksetting(data); 
            data.ff_path = pathname;  
            data.ff_name = filename(1:length(filename)-2);
            setappdata(gcbf, 'Userdata', data);
            applysetting(hObject,handles);
        else        % if the setting file does not exist 
            data.ff_dsp = filename;
            data.ff_name = filename(1:length(filename)-2);
            data.ff_path = pathname;
            setappdata(gcbf, 'Userdata', data);
            defaultsetting(hObject,handles);
        end
   end 
end

% === Optional data file browse ===========================================
function ff_data_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

[filename,pathname] = uigetfile('*.mat','Select the optional data for the fitness function');

if filename     % filename is nonempty   
    if strcmp([data.ff_path],[pathname]) % if the data file is in the path as the fitness function
        set(handles.ff_data,'String',filename);
    else                        % if the data file is in a different path, copy the file or cancel 
        ans = questdlg('Copy the data file in the directory of fitness function?','Illigal data file location','Yes','No','Yes');
        if strcmp(ans,'Yes')    
            copyfile([pathname filename],[data.ff_path filename]);
            set(handles.ff_data,'String',filename);
        else
            uiwait(errordlg('Data file is not properly defined','Error','modal'));
        end
    end
end

% === Optional data input =================================================
function ff_data_input(hObject, handles)
data = getappdata(gcbf,'Userdata');
datainput = get(hObject,'String');
D = str2num(datainput);

validinput1 = ~isempty(D);                                  % Numeric input
varlist = evalin('base','who');
validinput2 = max(strcmp(datainput,evalin('base','who')));  % Exist as a vairable in workspace
validinput3 = exist([data.ff_path datainput],'file')==2;    % Exist as a file in current directory

if validinput1 | validinput2 | validinput3
    return
else
    if ~strcmp(lower(datainput),'none');
        uiwait(errordlg('Invalid optional fitness function data','Error','modal'));
    end
    set(handles.ff_data,'String','none');
end 


% -------------------------------------------------------------------------
%   Gene parameters 
% -------------------------------------------------------------------------

% === Gene parameters button ==============================================
function gp_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.gp_inbxsdw handles.gp_inbx1 handles.gp_inbx2...
     handles.gp_inbxtitle handles.gp_inbxapp handles.gp_inbxcncl ...
     handles.gp_editframe handles.selectgene handles.selectgene_txt...
     handles.ngenes_txt handles.ngenes handles.gp_paraframe...    
     handles.type_txt handles.type handles.cid_txt handles.cid...
     handles.min_txt handles.min handles.max_txt handles.max...
     handles.descgene_txt handles.descgene handles.dspgene_txt handles.dspgene...
     ],'visible','on');

data = getappdata(gcbf, 'Userdata');

% backup some parameters for restoring
buffer.ngenes = data.ngenes;
buffer.dspgene = data.dspgene;
buffer.descgene = data.descgene; 
buffer.gd_min = data.gd_min;
buffer.gd_max = data.gd_max;
buffer.gd_type = data.gd_type;
buffer.gd_cid = data.gd_cid;
set(handles.gp_inbxtitle, 'Userdata', buffer);

% === Apply button ========================================================
function gp_inbxapp(hObject, handles)
set([handles.gp_inbxsdw handles.gp_inbx1 handles.gp_inbx2...
     handles.gp_inbxtitle handles.gp_inbxapp handles.gp_inbxcncl ...
     handles.gp_editframe handles.selectgene handles.selectgene_txt...
     handles.ngenes_txt handles.ngenes handles.gp_paraframe...    
     handles.type_txt handles.type handles.cid_txt handles.cid...
     handles.min_txt handles.min handles.max_txt handles.max...
     handles.descgene_txt handles.descgene handles.dspgene_txt handles.dspgene...
     ],'visible','off');
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function gp_inbxcncl(hObject, handles)
set([handles.gp_inbxsdw handles.gp_inbx1 handles.gp_inbx2...
     handles.gp_inbxtitle handles.gp_inbxapp handles.gp_inbxcncl ...
     handles.gp_editframe handles.selectgene handles.selectgene_txt...
     handles.ngenes_txt handles.ngenes handles.gp_paraframe...    
     handles.type_txt handles.type handles.cid_txt handles.cid...
     handles.min_txt handles.min handles.max_txt handles.max...
     handles.descgene_txt handles.descgene handles.dspgene_txt handles.dspgene...
     ],'visible','off');

% revert parameters
data = getappdata(gcbf, 'Userdata');
buffer = get(handles.gp_inbxtitle, 'Userdata');

data.ngenes = buffer.ngenes;
data.dspgene = buffer.dspgene;
data.descgene = buffer.descgene;
data.gd_min = buffer.gd_min;
data.gd_max = buffer.gd_max;
data.gd_type = buffer.gd_type;
data.gd_cid = buffer.gd_cid;

if data.ngenes == 1;
    slidermx = 2;
    sliderenable = 'off';
else
    slidermx = data.ngenes;
    sliderenable = 'on';
end
set(handles.selectgene_txt,'Enable',sliderenable);
set(handles.selectgene,'value',data.dspgene,'Max',slidermx,'Min',1,'SliderStep',...
     [1 ceil((data.ngenes-1)*0.2)]/(slidermx-1),'Enable',sliderenable);

set(handles.ngenes,'String',data.ngenes);
set(handles.dspgene,'String',data.dspgene);
set(handles.descgene,'String',data.descgene{data.dspgene});
set(handles.min,'String',data.gd_min(data.dspgene));
set(handles.max,'String',data.gd_max(data.dspgene));
set(handles.type,'Value',data.gd_type(data.dspgene));
set(handles.cid,'String',data.gd_cid(data.dspgene));

setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);


% === Total number of gene ================================================
function ngenes_CB(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 

    ngenes = str2num(get(hObject,'String'));
    data = getappdata(gcbf, 'Userdata');

    if (data.ngenes > ngenes)   % if new genes number is smaller than current
    	answer = questdlg('Continue reducing the number of gene?','Caution','Yes','No','No');
        if strcmp(answer,'No') 
            set(handles.ngenes,'String',data.ngenes);
            return;
        elseif (data.dspgene > ngenes)
            dspgene = ngenes;
            set(handles.dspgene,'String',dspgene);
            set(handles.descgene,'String',data.descgene{dspgene});
            set(handles.min,'String',data.gd_min(dspgene));
            set(handles.max,'String',data.gd_max(dspgene));
            set(handles.type,'Value',data.gd_type(dspgene));
            set(handles.cid,'String',data.gd_cid(dspgene));
            data.dspgene = dspgene;
        end
    end

    descgene = data.descgene;
    gd_min = data.gd_min;
    gd_max = data.gd_max;
    gd_type = data.gd_type;
    gd_cid = data.gd_cid;

    names ={'descgene', 'gd_min', 'gd_max', 'gd_type', 'gd_cid'};
    vlength = length(gd_min);

    for i = 1:5
    nd = ngenes - vlength;
        if nd > 0
            if i == 1
                for j = vlength+1:ngenes
                    descgene{j}=['gene #',num2str(j)];
                end
            else
                eval([names{i} '=[' names{i} ' '  num2str(1+(i==4)-2*(i==2)) '* ones(1,' num2str(nd) ')];'])
            end  
        else
            eval([names{i} '=' names{i} '(1:' num2str(ngenes) ');']);
        end;
        eval(['data.' names{i} '=' names{i} ';']);
    end
    
    data.ngenes = ngenes;
    if data.ngenes == 1;
        slidermx = 2;
        sliderenable = 'off';
    else
        slidermx = data.ngenes;
        sliderenable = 'on';
    end
    set(handles.selectgene_txt,'Enable',sliderenable);
    set(handles.selectgene,'value',data.dspgene,'Max',slidermx,'Min',1,'SliderStep',...
    [1 ceil((data.ngenes-1)*0.2)]/(slidermx-1),'Enable',sliderenable); 

    setappdata(gcbf, 'Userdata', data);
    
end

% === Display gene for editing ============================================
function dspgene_CB(hObject, handles)
dspgene = round(get(hObject,'value'));
set(handles.dspgene,'String',dspgene);    % display selected gene number
set(handles.selectgene,'Value',dspgene);  % intergerize the slider value

data = getappdata(gcbf, 'Userdata');        % load data

set(handles.descgene,'String',data.descgene{dspgene});  % gene description
set(handles.min,'String',data.gd_min(dspgene));         % minimum value
set(handles.max,'String',data.gd_max(dspgene));         % maximum value
set(handles.type,'Value',data.gd_type(dspgene));        % gene type
set(handles.cid,'String',data.gd_cid(dspgene));         % chromosome ID

data.dspgene = dspgene;                                 % update data
setappdata(gcbf, 'Userdata', data);                     % store data

% === Gene description ====================================================
function descgene_CB(hObject, handles)
genedescription=get(hObject,'String');
data = getappdata(gcbf, 'Userdata');
data.descgene{data.dspgene}=genedescription;
setappdata(gcbf, 'Userdata', data);

% === Minimum value of the gene ===========================================
function min_CB(hObject, handles)
value = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');
if isempty(value) 
    uiwait(errordlg('Input must be a real number','Error','modal'));
    set(hObject, 'String',data.gd_min(data.dspgene));
else
    if value > data.gd_max(data.dspgene)
        uiwait(errordlg('Min value of a gene cannot be greater than its max value',...
            'Error','modal'));
        set(hObject, 'String',data.gd_min(data.dspgene));
    else      
        data.gd_min(data.dspgene) = value;
        setappdata(gcbf, 'Userdata', data);
    end
end

% === Maximum value of the gene ===========================================
function max_CB(hObject, handles)
value = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');
if isempty(value) 
    uiwait(errordlg('Input must be a real number','Error','modal'));
    set(hObject, 'String',data.gd_max(data.dspgene));
else
    if value < data.gd_min(data.dspgene)
        uiwait(errordlg('Max value of a gene cannot be smaller than its min value',...
            'Error','modal'));
        set(hObject, 'String',data.gd_max(data.dspgene));
    else      
        data.gd_max(data.dspgene) = value;
        setappdata(gcbf, 'Userdata', data);
    end
end

% === Type of the gene ====================================================
function type_CB(hObject, handles)
genetype = get(hObject,'Value');
data = getappdata(gcbf, 'Userdata');
data.gd_type(data.dspgene) = genetype;
setappdata(gcbf, 'Userdata', data);

% === Chromosome ID for multiple chromosome setting =======================
function cid_CB(hObject, handles)
value = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');
if isempty(value) | value <= 0 | abs(round(value)-value) > 0
    uiwait(errordlg('Input must be a positive integer','Error','modal'));            
    set(hObject, 'String', data.gd_cid(data.dspgene));
else
    data.gd_cid(data.dspgene) = value;
    setappdata(gcbf, 'Userdata', data);
end

% -------------------------------------------------------------------------
%   Fundamental parameters
% -------------------------------------------------------------------------

% === Fundamental parameter button ========================================
function fp_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.fp_inbxsdw handles.fp_inbx1 handles.fp_inbx2...
      handles.fp_inbxtitle handles.fp_inbxapp handles.fp_inbxcncl...
      handles.fp_ngen_txt handles.fp_ngen handles.fp_ipop_txt...
      handles.fp_ipop handles.fp_npop_txt handles.fp_npop...
      handles.fp_nobj_txt handles.fp_nobj handles.fp_obj_txt...
      handles.fp_obj],'visible','on');
 
% === Apply button ========================================================
function fp_inbxapp(hObject, handles)
set([ handles.fp_inbxsdw handles.fp_inbx1 handles.fp_inbx2...
      handles.fp_inbxtitle handles.fp_inbxapp handles.fp_inbxcncl...
      handles.fp_ngen_txt handles.fp_ngen handles.fp_ipop_txt...
      handles.fp_ipop handles.fp_npop_txt handles.fp_npop...
      handles.fp_nobj_txt handles.fp_nobj handles.fp_obj_txt...
      handles.fp_obj],'visible','off');

data = getappdata(gcbf,'Userdata');
GAS = getappdata(gcbf,'GAS');

new_ngen = str2num(get(handles.fp_ngen,'String'));
if data.fp_ngen ~= new_ngen     % if total No. of generation is differnt
    if GAS.cg > new_ngen            % if new generation is smaller than
        GAS.cg = new_ngen;          % current generation
        set(handles.cg,'String',GAS.cg);    % currtnet gen # = new gen #
    end   
    data.fp_ngen = new_ngen;        % evolution status update
    barlength = 170*GAS.cg/data.fp_ngen;
    pos = get(handles.pbar,'Position');
    pos(3) = 170*GAS.cg/data.fp_ngen;
    set(handles.pbar,'Position',pos);
    set(handles.pbar,'String',[num2str(round(pos(3)*0.5882)) '%']);
end

data.fp_ipop = str2num(get(handles.fp_ipop,'String'));
data.fp_npop = str2num(get(handles.fp_npop,'String'));
data.fp_obj  = str2num(get(handles.fp_obj,'String'));
setappdata(gcbf, 'Userdata', data);
setappdata(gcbf, 'GAS', GAS);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function fp_inbxcncl(hObject, handles)
set([ handles.fp_inbxsdw handles.fp_inbx1 handles.fp_inbx2...
      handles.fp_inbxtitle handles.fp_inbxapp handles.fp_inbxcncl...
      handles.fp_ngen_txt handles.fp_ngen handles.fp_ipop_txt...
      handles.fp_ipop handles.fp_npop_txt handles.fp_npop...
      handles.fp_nobj_txt handles.fp_nobj handles.fp_obj_txt...
      handles.fp_obj],'visible','off');

% revert parameters
data = getappdata(gcbf, 'Userdata');
set(handles.fp_ngen, 'String', data.fp_ngen);
set(handles.fp_ipop, 'String', data.fp_ipop);
set(handles.fp_npop, 'String', data.fp_npop);
set(handles.fp_obj, 'String', data.fp_obj);
enablesomeinput(hObject, handles);

% === Total number of generations =========================================
function fp_ngen(hObject, handles)
new_ngen = str2num(get(hObject,'String'));

goset('numericinputtest',gcbo,guidata(gcbo))  % input check

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    data = getappdata(gcbf, 'Userdata');
    GAS = getappdata(gcbf, 'GAS');
    
    if GAS.cg > new_ngen    % confirm reducing the total no. of generations
        answer = questdlg({'New generation is smaller than the current generation number.',...
                'This will cause loss of data from the new generation number.',...
                'Do you want to proceed?'},'Warning','Yes','No','No');
        if strcmp(answer,'No');
            set(handles.fp_ngen,'String',data.fp_ngen);
        end
    end 
end

% === Initial population ==================================================
function fp_ipop(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if fp_ipop < fp_npop
    if str2num(get(hObject,'String')) < str2num(get(handles.fp_npop,'String')) 
        data = getappdata(gcbf, 'Userdata');
        uiwait(errordlg('Initial population size cannot be smaller than regular population size',...
            'Error','modal'));
        set(hObject, 'String', data.fp_ipop);
    end
end

% === Number of population ================================================
function fp_npop(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if fp_npop > fp_ipop
    if str2num(get(hObject,'String')) > str2num(get(handles.fp_ipop,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.fp_npop);
        uiwait(errordlg('Population size cannot be bigger than initial population size',...
            'Error','modal'));
    end
end

% === Number of objectives ================================================
function fp_nobj(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn,'Userdata')     % if numericinputtest passed 

    new_nobj = str2num(get(hObject,'String'));
    data = getappdata(gcbf, 'Userdata');
    if new_nobj ~= data.fp_nobj     % if the number of objectives has been changed
    
        answer = questdlg('Are you sure of changing the number of objective functions?','','Yes','No','No');
        if strcmp(answer,'No')
            set(handles.fp_nobj,'String',data.fp_nobj);
            return;
        else                        % For the answer 'YES'
            data.fp_nobj = new_nobj;    % adjust the plotting parameters accordingly
            data.op_style(1:new_nobj) = 1;
            data.op_sign(1:new_nobj) = 1;
            data.pp_style(1:new_nobj) = 1;
            data.pp_sign(1:new_nobj) = 1;
            set(handles.op_style,'String',['[' num2str(data.op_style) ']']);
            set(handles.op_sign,'String',['[' num2str(data.op_sign) ']']);
            set(handles.pp_style,'String',['[' num2str(data.pp_style) ']']);
            set(handles.pp_sign,'String',['[' num2str(data.pp_sign) ']']);      
            
            setappdata(gcbf, 'Userdata', data);                 % store parameter
            
            uiwait(warndlg({'The number of objective function has been changed.',...
                '','Redefine plotting parameters',''},'Warning','modal'));
            
            if data.fp_nobj == 1;
                objmode = 'S'; objmodetip = 'Single-objective optimization';
            else 
                objmode = 'M'; objmodetip = 'Multi-objective optimization';
            end

            set(handles.ff_mode,'String',objmode,'Tooltipstring',objmodetip);
        end 
    end
end

% === Objective to optimize ===============================================
function fp_obj(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    nobj = str2num(get(handles.fp_nobj,'String'));
    value = str2num(get(hObject,'String'));
    
    % check if fp_obj > fp_nobj and fp_obj ~= 0 when fp_nobj = 1
    if value >  nobj | ( nobj == 1 & value == 0)
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.fp_obj);
        uiwait(errordlg('Invalid objective function number','Error','modal'));
    end
end

% -------------------------------------------------------------------------
%   Evaluation Option 
% -------------------------------------------------------------------------
% === Evauation option button =============================================
function ev_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.ev_inbxsdw handles.ev_inbx1 handles.ev_inbx2...
     handles.ev_inbxtitle handles.ev_bev_txt handles.ev_bev ...
     handles.ev_are_txt handles.ev_are handles.ev_ssd_txt ...
     handles.ev_ssd handles.ev_inbxapp handles.ev_inbxcncl],...
     'visible','on');

% === Apply button ========================================================
function ev_inbxapp(hObject, handles)
set([ handles.ev_inbxsdw handles.ev_inbx1 handles.ev_inbx2...
     handles.ev_inbxtitle handles.ev_bev_txt handles.ev_bev ...
     handles.ev_are_txt handles.ev_are handles.ev_ssd_txt ...
     handles.ev_ssd handles.ev_inbxapp handles.ev_inbxcncl],...
     'visible','off');

data = getappdata(gcbf, 'Userdata');
data.ev_bev = get(handles.ev_bev, 'Value')-1;
data.ev_are = get(handles.ev_are, 'Value')-1;
data.ev_ssd = get(handles.ev_ssd, 'Value');
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function ev_inbxcncl(hObject, handles)
set([ handles.ev_inbxsdw handles.ev_inbx1 handles.ev_inbx2...
     handles.ev_inbxtitle handles.ev_bev_txt handles.ev_bev ...
     handles.ev_are_txt handles.ev_are handles.ev_ssd_txt ...
     handles.ev_ssd handles.ev_inbxapp handles.ev_inbxcncl],...
     'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.ev_bev,'Value', data.ev_bev+1);
set(handles.ev_are,'Value', data.ev_are+1);
set(handles.ev_ssd,'Value', data.ev_ssd);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%   Diversity Control Option
% -------------------------------------------------------------------------
% === Diversity control activation ========================================
function dc_act(hObject, handles)
flag = get(hObject,'value');
data = getappdata(gcbf, 'Userdata');
data.dc_act = flag;
if flag 
    set(handles.dc_act, 'BackgroundColor', 'w');
    set(handles.dc_btn, 'Enable','on');
else 
    set(handles.dc_act, 'BackgroundColor', .7*ones(1,3));
    set(handles.dc_btn, 'Enable', 'off');
end

setappdata(gcbf, 'Userdata', data);

% === Diversity control button ============================================
function dc_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.dc_inbxsdw handles.dc_inbx1 handles.dc_inbx2 handles.dc_inbxtitle ...
     handles.dc_alg_txt handles.dc_alg handles.dc_spc_txt handles.dc_spc ...
     handles.dc_mnt_txt handles.dc_mnt...
     handles.dc_mxt_txt handles.dc_mxt handles.dc_mnb_txt handles.dc_mnb...
     handles.dc_mxb_txt handles.dc_mxb handles.dc_ntr_txt handles.dc_ntr...
     handles.dc_dc_txt handles.dc_dc handles.dc_nt_txt handles.dc_nt...     
     handles.dc_inbxapp handles.dc_inbxcncl ],'visible','on');
 
% === Apply button ========================================================
function dc_inbxapp(hObject, handles)
set([handles.dc_inbxsdw handles.dc_inbx1 handles.dc_inbx2 handles.dc_inbxtitle ...
     handles.dc_alg_txt handles.dc_alg handles.dc_spc_txt handles.dc_spc ...
     handles.dc_mnt_txt handles.dc_mnt...
     handles.dc_mxt_txt handles.dc_mxt handles.dc_mnb_txt handles.dc_mnb...
     handles.dc_mxb_txt handles.dc_mxb handles.dc_ntr_txt handles.dc_ntr...
     handles.dc_dc_txt handles.dc_dc handles.dc_nt_txt handles.dc_nt...
     handles.dc_inbxapp handles.dc_inbxcncl ],'visible','off');

data = getappdata(gcbf, 'Userdata');
data.dc_alg = get(handles.dc_alg, 'value');
data.dc_spc = get(handles.dc_spc, 'value');
data.dc_mnt = str2num(get(handles.dc_mnt, 'String'));
data.dc_mxt = str2num(get(handles.dc_mxt, 'String'));
data.dc_mnb = str2num(get(handles.dc_mnb, 'String'));
data.dc_mxb = str2num(get(handles.dc_mxb, 'String'));
data.dc_ntr = str2num(get(handles.dc_ntr, 'String'));
data.dc_dc = str2num(get(handles.dc_dc, 'String'));
data.dc_nt = str2num(get(handles.dc_nt, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function dc_inbxcncl(hObject, handles)
set([handles.dc_inbxsdw handles.dc_inbx1 handles.dc_inbx2 handles.dc_inbxtitle ...
     handles.dc_alg_txt handles.dc_alg handles.dc_spc_txt handles.dc_spc ...
     handles.dc_mnt_txt handles.dc_mnt...
     handles.dc_mxt_txt handles.dc_mxt handles.dc_mnb_txt handles.dc_mnb...
     handles.dc_mxb_txt handles.dc_mxb handles.dc_ntr_txt handles.dc_ntr...
     handles.dc_dc_txt handles.dc_dc handles.dc_nt_txt handles.dc_nt...
     handles.dc_inbxapp handles.dc_inbxcncl ],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.dc_alg, 'Value', data.dc_alg);
set(handles.dc_spc, 'Value', data.dc_spc);
set(handles.dc_mnt, 'String', data.dc_mnt);
set(handles.dc_mxt, 'String', data.dc_mxt);
set(handles.dc_mnb, 'String', data.dc_mnb);
set(handles.dc_mxb, 'String', data.dc_mxb);
set(handles.dc_ntr, 'String', data.dc_ntr);
set(handles.dc_dc, 'String', data.dc_dc);
set(handles.dc_nt, 'String', data.dc_nt);
enablesomeinput(hObject, handles);

% === Minimum threshold - input error check ===============================
function dc_mnt(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if dc_mnt > dc_mxt
    if str2num(get(hObject,'String')) > str2num(get(handles.dc_mxt,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.dc_mnt);
        uiwait(errordlg('Min. threshold cannot be greater than Max. threshold',...
            'Error','modal'));
    end
end

% === Maximum threshold - input error check ===============================
function dc_mxt(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if dc_mxt < dc_mnt
    if str2num(get(hObject,'String')) < str2num(get(handles.dc_mnt,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.dc_mxt);
        uiwait(errordlg('Max. threshold cannot be smaller than Min. threshold',...
            'Error','modal'));
    end
end

% === Minimum number of bins - input error check ==========================
function dc_mnb(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if dc_mnb > dc_mxb
    if str2num(get(hObject,'String')) > str2num(get(handles.dc_mxb,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.dc_mnb);
        uiwait(errordlg('Min. No. of bins cannot be greater than Max. No. of bins',...
            'Error','modal'));
    end
end

% === Maximum number of bins - input error check ==========================
function dc_mxb(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if dc_mxt < dc_mnt
    if str2num(get(hObject,'String')) < str2num(get(handles.dc_mnb,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.dc_mxb);
        uiwait(errordlg('Max. No. of bins cannot be smaller than Min. No. of bins',...
            'Error','modal'));
    end
end

% -------------------------------------------------------------------------
%   Scaling Operator Setting
% -------------------------------------------------------------------------
% === Scalining opeator setting button ====================================
function sc_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.sc_inbxsdw handles.sc_inbx1 handles.sc_inbx2...
     handles.sc_inbxtitle handles.sc_alg handles.sc_inbxapp handles.sc_inbxcncl...
     handles.sc_alg_txt handles.sc_alg handles.sc_lin_txt handles.sc_kln_txt...
     handles.sc_kln handles.sc_sgt_txt handles.sc_cst_txt handles.sc_cst...
     handles.sc_sgm_txt handles.sc_kmxq_txt handles.sc_kmxq handles.sc_kmnq_txt...
     handles.sc_kmnq],'visible','on');

% === Apply button ========================================================
function sc_inbxapp(hObject, handles)
set([ handles.sc_inbxsdw handles.sc_inbx1 handles.sc_inbx2...
     handles.sc_inbxtitle handles.sc_alg handles.sc_inbxapp handles.sc_inbxcncl...
     handles.sc_alg_txt handles.sc_alg handles.sc_lin_txt handles.sc_kln_txt...
     handles.sc_kln handles.sc_sgt_txt handles.sc_cst_txt handles.sc_cst...
     handles.sc_sgm_txt handles.sc_kmxq_txt handles.sc_kmxq handles.sc_kmnq_txt...
     handles.sc_kmnq],'visible','off');

data=getappdata(gcbf, 'Userdata');
data.sc_alg = get(handles.sc_alg, 'Value')-1;
data.sc_kln = str2num(get(handles.sc_kln, 'String'));
data.sc_cst = str2num(get(handles.sc_cst, 'String'));
data.sc_kmxq = str2num(get(handles.sc_kmxq, 'String'));
data.sc_kmnq = str2num(get(handles.sc_kmnq, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function sc_inbxcncl(hObject, handles)
set([ handles.sc_inbxsdw handles.sc_inbx1 handles.sc_inbx2...
     handles.sc_inbxtitle handles.sc_alg handles.sc_inbxapp handles.sc_inbxcncl...
     handles.sc_alg_txt handles.sc_alg handles.sc_lin_txt handles.sc_kln_txt...
     handles.sc_kln handles.sc_sgt_txt handles.sc_cst_txt handles.sc_cst...
     handles.sc_sgm_txt handles.sc_kmxq_txt handles.sc_kmxq handles.sc_kmnq_txt...
     handles.sc_kmnq],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.sc_alg, 'Value', data.sc_alg+1);
set(handles.sc_kln, 'String', data.sc_kln);
set(handles.sc_cst, 'String', data.sc_cst);
set(handles.sc_kmxq, 'String', data.sc_kmxq);
set(handles.sc_kmnq, 'String', data.sc_kmnq);
enablesomeinput(hObject, handles);

% === sc_kmxq input error check ===========================================
function sc_kmxq(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if sc_kmxq < sc_kmnq
    if str2num(get(hObject,'String')) < str2num(get(handles.sc_kmnq,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.sc_kmxq);
        uiwait(errordlg('Max. scaling factor cannot be smaller than Min. Scaling factor',...
            'Error','modal'));
    end
end

% === sc_kmnq input error check ===========================================
function sc_kmnq(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    
    % check if sc_kmnq > sc_kmxq
    if str2num(get(hObject,'String')) > str2num(get(handles.sc_kmxq,'String')) 
        data = getappdata(gcbf, 'Userdata');
        set(hObject, 'String', data.sc_kmnq);
        uiwait(errordlg('Min. scaling factor cannot be greater than Max. Scaling factor',...
            'Error','modal'));
    end
end

% -------------------------------------------------------------------------
%   Selection Operator Setting 
% -------------------------------------------------------------------------
% === Selection operator setting button ===================================
function sl_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.sl_inbxsdw handles.sl_inbx1 handles.sl_inbx2...
     handles.sl_nts_txt handles.sl_nts handles.sl_inbxtitle...
     handles.sl_alg_txt handles.sl_alg handles.sl_cah_txt...
     handles.sl_cah_browse handles.sl_cah handles.sl_inbxapp...
     handles.sl_inbxcncl],'visible','on');

% === Custom selection operator file browse button =============================================
function sl_cah_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

% get the fitness function file
[filename,pathname] = uigetfile({'*.m'},'Select the M-file for the custom selection operator');

if filename     % filename is nonempty
    if strcmp(data.ff_path,pathname) | strcmp(data.gosetpath,pathname) % Is the path valid?
        set(handles.sl_cah,'String',filename);     % update infos 
        set(handles.sl_alg,'Value',3);
    else
        uiwait(errordlg('Custom algorithm must be in the same folder as the fitness function file or in the GOSET folder','Error','modal'));
        if isempty(data.sl_cah)
            set(handles.sl_cah,'String','none');
        else
            set(handles.sl_cah,'String',[data.sl_cah,'.m']);
        end
    end
end
     
% === Number of individuals for the tournament selection ==================
function sl_nts(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))
sl_nts = str2num(get(hObject, 'String'));
if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
data = getappdata(gcbf, 'Userdata');    
    % check if sl_nts >= 2
    if sl_nts < 2
        set(hObject, 'String', data.sl_nts);
        uiwait(errordlg('Number of individuals for the tournament must be at least 2',...
            'Error','modal'));
    end   
    % check if sl_nts < data.fp_npop
    if sl_nts > str2num(get(handles.fp_npop,'String')) 
        set(hObject, 'String', data.sl_nts);
        uiwait(errordlg('Number of individuals must be smaller than the population size',...
            'Error','modal'));
    end
end

% === Apply button ========================================================
function sl_inbxapp(hObject, handles)
set([handles.sl_inbxsdw handles.sl_inbx1 handles.sl_inbx2...
     handles.sl_nts_txt handles.sl_nts handles.sl_inbxtitle...
     handles.sl_alg_txt handles.sl_alg handles.sl_cah_txt...
     handles.sl_cah_browse handles.sl_cah handles.sl_inbxapp...
     handles.sl_inbxcncl],'visible','off');

data = getappdata(gcbf, 'Userdata');
data.sl_alg = get(handles.sl_alg, 'Value');
data.sl_nts = str2num(get(handles.sl_nts, 'String'));
fname = get(handles.sl_cah, 'String');
if strcmp(fname,'none')
    data.sl_cah = [];
else
    data.sl_cah = fname(1:length(fname)-2);
end
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);


% === Cancel button =======================================================
function sl_inbxcncl(hObject, handles)
set([handles.sl_inbxsdw handles.sl_inbx1 handles.sl_inbx2...
     handles.sl_nts_txt handles.sl_nts handles.sl_inbxtitle...
     handles.sl_alg_txt handles.sl_alg handles.sl_cah_txt...
     handles.sl_cah_browse handles.sl_cah handles.sl_inbxapp...
     handles.sl_inbxcncl],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.sl_alg, 'Value', data.sl_alg);
set(handles.sl_nts, 'String', data.sl_nts);
if isempty(data.sl_cah)
    fname = 'none';
else
    fname = [data.sl_cah,'.m'];
end
set(handles.sl_cah, 'String', fname);
enablesomeinput(hObject, handles);


% -------------------------------------------------------------------------
%   Death Operator Setting 
% -------------------------------------------------------------------------
% === Death operator setting button ===================================
function dt_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.dt_inbxsdw handles.dt_inbx1 handles.dt_inbx2...
     handles.dt_nts_txt handles.dt_nts handles.dt_inbxtitle...
     handles.dt_alg_txt handles.dt_alg handles.dt_cah_txt...
     handles.dt_cah_browse handles.dt_cah handles.dt_inbxapp...
     handles.dt_inbxcncl],'visible','on');

% === Custom death operator file browse button =============================================
function dt_cah_browse(hObject, handles)
data = getappdata(gcbf, 'Userdata');

% get the fitness function file
[filename,pathname] = uigetfile('*.m','Select the M-file for the custom death operator');

if filename     % filename is nonempty
    if strcmp(data.ff_path,pathname) | strcmp(data.gosetpath,pathname) % Is the path valid?
        set(handles.dt_cah,'String',filename);     % update infos and change directory  
        set(handles.dt_alg,'Value',5);
    else
        uiwait(errordlg('Custom algorithm must be in the same folder as the fitness function file or in the GOSET folder','Error','modal'));
        if isempty(data.dt_cah)
            set(handles.dt_cah,'String','none');
        else
            set(handles.dt_cah,'String',[data.dt_cah,'.m']);
        end  
    end
end
     
% === Number of individuals for the tournament selection ==================
function dt_nts(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))
dt_nts = str2num(get(hObject, 'String'));
if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
data = getappdata(gcbf, 'Userdata');    
    % check if dt_nts >= 2
    if dt_nts < 2
        set(hObject, 'String', data.dt_nts);
        uiwait(errordlg('Number of individuals for the tournament must be at least 2',...
            'Error','modal'));
    end   
    % check if dt_nts < data.fp_npop
    if dt_nts > str2num(get(handles.fp_npop,'String')) 
        set(hObject, 'String', data.dt_nts);
        uiwait(errordlg('Number of individuals must be smaller than the population size',...
            'Error','modal'));
    end
end

% === Apply button ========================================================
function dt_inbxapp(hObject, handles)
set([handles.dt_inbxsdw handles.dt_inbx1 handles.dt_inbx2...
     handles.dt_nts_txt handles.dt_nts handles.dt_inbxtitle...
     handles.dt_alg_txt handles.dt_alg handles.dt_cah_txt...
     handles.dt_cah_browse handles.dt_cah handles.dt_inbxapp...
     handles.dt_inbxcncl],'visible','off');

data=getappdata(gcbf, 'Userdata');
data.dt_alg = get(handles.dt_alg, 'Value');
data.dt_nts = str2num(get(handles.dt_nts, 'String'));
fname = get(handles.dt_cah, 'String');
if strcmp(fname,'none')
    data.dt_cah = [];
else
    data.dt_cah = fname(1:length(fname)-2);
end
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function dt_inbxcncl(hObject, handles)
set([handles.dt_inbxsdw handles.dt_inbx1 handles.dt_inbx2...
     handles.dt_nts_txt handles.dt_nts handles.dt_inbxtitle...
     handles.dt_alg_txt handles.dt_alg handles.dt_cah_txt...
     handles.dt_cah_browse handles.dt_cah handles.dt_inbxapp...
     handles.dt_inbxcncl],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.dt_alg, 'Value', data.dt_alg);
set(handles.dt_nts, 'String', data.dt_nts);
if isempty(data.dt_cah)
    fname = 'none';
else
    fname = [data.dt_cah,'.m'];
end
set(handles.dt_cah, 'String', fname);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%   Mating and Crossover Operator Setting
% -------------------------------------------------------------------------
% === Mating and crossover operator setting button ========================
function mc_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.mc_inbxsdw handles.mc_inbx1 handles.mc_inbx2...
     handles.mc_inbxtitle handles.mc_inbxapp handles.mc_inbxcncl handles.mc_pp_txt...
     handles.mc_pp handles.mc_fc_txt handles.mc_fc ...
     handles.mc_alg_txt handles.mc_alg handles.mc_simbin_txt...
     handles.mc_ec_txt handles.mc_ec handles.mc_rdnxov_txt handles.mc_gac_txt...
     handles.mc_gac],'visible','on');
 
% === Apply button ========================================================
function mc_inbxapp(hObject, handles)
set([ handles.mc_inbxsdw handles.mc_inbx1 handles.mc_inbx2...
     handles.mc_inbxtitle handles.mc_inbxapp handles.mc_inbxcncl handles.mc_pp_txt...
     handles.mc_pp handles.mc_fc_txt handles.mc_fc ...
     handles.mc_alg_txt handles.mc_alg handles.mc_simbin_txt...
     handles.mc_ec_txt handles.mc_ec handles.mc_rdnxov_txt handles.mc_gac_txt...
     handles.mc_gac],'visible','off');

data=getappdata(gcbf, 'Userdata');
data.mc_pp = str2num(get(handles.mc_pp, 'String'));
data.mc_fc = str2num(get(handles.mc_fc, 'String'));
data.mc_alg = get(handles.mc_alg, 'Value');
data.mc_gac = str2num(get(handles.mc_gac, 'String'));
data.mc_ec = str2num(get(handles.mc_ec, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function mc_inbxcncl(hObject, handles)
set([ handles.mc_inbxsdw handles.mc_inbx1 handles.mc_inbx2...
     handles.mc_inbxtitle handles.mc_inbxapp handles.mc_inbxcncl handles.mc_pp_txt...
     handles.mc_pp handles.mc_fc_txt handles.mc_fc ...
     handles.mc_alg_txt handles.mc_alg handles.mc_simbin_txt...
     handles.mc_ec_txt handles.mc_ec handles.mc_rdnxov_txt handles.mc_gac_txt...
     handles.mc_gac],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.mc_pp, 'String', data.mc_pp);
set(handles.mc_fc, 'String', data.mc_fc);
set(handles.mc_alg, 'Value', data.mc_alg);
set(handles.mc_gac, 'String', data.mc_gac);
set(handles.mc_ec, 'String', data.mc_ec);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%   Mutation Operator Setting
% -------------------------------------------------------------------------
% === Mutation operator setting button ====================================
function mt_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.mt_inbxsdw handles.mt_inbx1 handles.mt_inbx2...
     handles.mt_inbxtitle handles.mt_inbxapp handles.mt_inbxcncl...
     handles.mt_label handles.mt_tgm_txt handles.mt_ptgm handles.mt_rgm_txt...
     handles.mt_prgm handles.mt_srgm handles.mt_agm_txt handles.mt_pagm...
     handles.mt_sagm handles.mt_rvm_txt handles.mt_prvm handles.mt_srvm...
     handles.mt_avm_txt handles.mt_pavm handles.mt_savm handles.mt_igm_txt...
     handles.mt_pigm],'visible','on');

% === Apply button ========================================================
function mt_inbxapp(hObject, handles)
set([ handles.mt_inbxsdw handles.mt_inbx1 handles.mt_inbx2...
     handles.mt_inbxtitle handles.mt_inbxapp handles.mt_inbxcncl...
     handles.mt_label handles.mt_tgm_txt handles.mt_ptgm handles.mt_rgm_txt...
     handles.mt_prgm handles.mt_srgm handles.mt_agm_txt handles.mt_pagm...
     handles.mt_sagm handles.mt_rvm_txt handles.mt_prvm handles.mt_srvm...
     handles.mt_avm_txt handles.mt_pavm handles.mt_savm handles.mt_igm_txt...
     handles.mt_pigm],'visible','off');

data=getappdata(gcbf, 'Userdata');
data.mt_ptgm = str2num(get(handles.mt_ptgm, 'String'));
data.mt_prgm = str2num(get(handles.mt_prgm, 'String'));
data.mt_srgm = str2num(get(handles.mt_srgm, 'String'));
data.mt_pagm = str2num(get(handles.mt_pagm, 'String'));
data.mt_sagm = str2num(get(handles.mt_sagm, 'String'));
data.mt_prvm = str2num(get(handles.mt_prvm, 'String'));
data.mt_srvm = str2num(get(handles.mt_srvm, 'String'));
data.mt_pavm = str2num(get(handles.mt_pavm, 'String'));
data.mt_savm = str2num(get(handles.mt_savm, 'String'));
data.mt_pigm = str2num(get(handles.mt_pigm, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function mt_inbxcncl(hObject, handles)
set([ handles.mt_inbxsdw handles.mt_inbx1 handles.mt_inbx2...
     handles.mt_inbxtitle handles.mt_inbxapp handles.mt_inbxcncl...
     handles.mt_label handles.mt_tgm_txt handles.mt_ptgm handles.mt_rgm_txt...
     handles.mt_prgm handles.mt_srgm handles.mt_agm_txt handles.mt_pagm...
     handles.mt_sagm handles.mt_rvm_txt handles.mt_prvm handles.mt_srvm...
     handles.mt_avm_txt handles.mt_pavm handles.mt_savm handles.mt_igm_txt...
     handles.mt_pigm],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.mt_ptgm, 'String', data.mt_ptgm);
set(handles.mt_prgm, 'String', data.mt_prgm);
set(handles.mt_srgm, 'String', data.mt_srgm);
set(handles.mt_pagm, 'String', data.mt_pagm);
set(handles.mt_sagm, 'String', data.mt_sagm);
set(handles.mt_prvm, 'String', data.mt_prvm);
set(handles.mt_srvm, 'String', data.mt_srvm);
set(handles.mt_pavm, 'String', data.mt_pavm);
set(handles.mt_savm, 'String', data.mt_savm);
set(handles.mt_pigm, 'String', data.mt_pigm);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%   Gene Repair Operator Setting
% -------------------------------------------------------------------------
% === Gene repair operator setting button =================================
function gr_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.gr_inbxsdw handles.gr_inbx1 handles.gr_inbx2...
      handles.gr_inbxtitle handles.gr_inbxapp handles.gr_inbxcncl...
      handles.gr_alg_txt handles.gr_alg],'visible','on');
 
% === Apply button ========================================================
function gr_inbxapp(hObject, handles)
set([ handles.gr_inbxsdw handles.gr_inbx1 handles.gr_inbx2...
      handles.gr_inbxtitle handles.gr_inbxapp handles.gr_inbxcncl...
      handles.gr_alg_txt handles.gr_alg],'visible','off');

data = getappdata(gcbf, 'Userdata');
data.gr_alg = get(handles.gr_alg, 'Value');
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function gr_inbxcncl(hObject, handles)
set([ handles.gr_inbxsdw handles.gr_inbx1 handles.gr_inbx2...
      handles.gr_inbxtitle handles.gr_inbxapp handles.gr_inbxcncl...
      handles.gr_alg_txt handles.gr_alg],'visible','off');

data = getappdata(gcbf, 'Userdata');
set(handles.gr_alg, 'Value', data.gr_alg);
enablesomeinput(hObject, handles);


% -------------------------------------------------------------------------
%   Migration Operator Setting
% -------------------------------------------------------------------------
% === Migration operator setting button ===================================
function mg_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.mg_inbxsdw handles.mg_inbx1 handles.mg_inbx2...
     handles.mg_inbxtitle handles.mg_inbxapp handles.mg_inbxcncl...
     handles.mg_nreg_txt handles.mg_nreg handles.mg_tmig_txt handles.mg_tmig...
     handles.mg_pmig_txt handles.mg_pmig],'visible','on');
 
% === Apply button ========================================================
function mg_inbxapp(hObject, handles)
set([ handles.mg_inbxsdw handles.mg_inbx1 handles.mg_inbx2...
     handles.mg_inbxtitle handles.mg_inbxapp handles.mg_inbxcncl...
     handles.mg_nreg_txt handles.mg_nreg handles.mg_tmig_txt handles.mg_tmig...
     handles.mg_pmig_txt handles.mg_pmig],'visible','off');

data = getappdata(gcbf, 'Userdata');
data.mg_nreg = str2num(get(handles.mg_nreg, 'String'));
data.mg_tmig = str2num(get(handles.mg_tmig, 'String'));
data.mg_pmig = str2num(get(handles.mg_pmig, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function mg_inbxcncl(hObject, handles)
set([ handles.mg_inbxsdw handles.mg_inbx1 handles.mg_inbx2...
     handles.mg_inbxtitle handles.mg_inbxapp handles.mg_inbxcncl...
     handles.mg_nreg_txt handles.mg_nreg handles.mg_tmig_txt handles.mg_tmig...
     handles.mg_pmig_txt handles.mg_pmig],'visible','off');

data = getappdata(gcbf, 'Userdata');
set(handles.mg_nreg, 'String', data.mg_nreg);
set(handles.mg_tmig, 'String', data.mg_tmig);
set(handles.mg_pmig, 'String', data.mg_pmig);
enablesomeinput(hObject, handles);

% === Region number check ==================================================
function mg_nreg(hObject, handles)
goset('numericinputtest',gcbo,guidata(gcbo))

if get(handles.startbtn, 'Userdata')     % if numericinputtest passed 
    nreg = str2num(get(hObject, 'string'));
    data = getappdata(gcbf, 'Userdata');
    if (data.fp_npop/nreg) < 20
        uiwait(msgbox('Number of region is too big for current population size.','Warning','warn','modal')); 
        set(handles.mg_nreg,'string',data.mg_nreg);
    end
end

% -------------------------------------------------------------------------
%   Elitism Setting
% -------------------------------------------------------------------------
% === Elitism activation button ===========================================
function el_act(hObject, handles)
flag = get(hObject,'value');
data = getappdata(gcbf, 'Userdata');
data.el_act = flag;
if flag 
    set(handles.el_act, 'BackgroundColor', 'w');
    set(handles.el_btn, 'Enable', 'on');
else 
    set(handles.el_act, 'BackgroundColor', .7*ones(1,3));
    set(handles.el_btn, 'Enable', 'off');
end
setappdata(gcbf, 'Userdata', data);

% === Elitism setting button ==============================================
function el_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.el_inbxsdw handles.el_inbx1 handles.el_inbx2...
     handles.el_inbxtitle handles.el_inbxapp handles.el_inbxcncl...
     handles.el_fgs_txt handles.el_fgs handles.el_fpe_txt handles.el_fpe],...
     'visible','on');

% === Apply button ========================================================
function el_inbxapp(hObject, handles)
set([ handles.el_inbxsdw handles.el_inbx1 handles.el_inbx2...
     handles.el_inbxtitle handles.el_inbxapp handles.el_inbxcncl...
     handles.el_fgs_txt handles.el_fgs handles.el_fpe_txt handles.el_fpe],...
     'visible','off');

data=getappdata(gcbf, 'Userdata');
data.el_fgs = str2num(get(handles.el_fgs, 'String'));
data.el_fpe = str2num(get(handles.el_fpe, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function el_inbxcncl(hObject, handles)
set([ handles.el_inbxsdw handles.el_inbx1 handles.el_inbx2...
     handles.el_inbxtitle handles.el_inbxapp handles.el_inbxcncl...
     handles.el_fgs_txt handles.el_fgs handles.el_fpe_txt handles.el_fpe],...
     'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.el_fgs, 'String', data.el_fgs);
set(handles.el_fpe, 'String', data.el_fpe);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%   Random Search Setting
% -------------------------------------------------------------------------
% === Random search setting button ========================================
function rs_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([ handles.rs_inbxsdw handles.rs_inbx1 handles.rs_inbx2...
     handles.rs_inbxtitle handles.rs_inbxapp handles.rs_inbxcncl...
     handles.rs_fgs_txt handles.rs_fgs handles.rs_fps_txt handles.rs_fps...
     handles.rs_srp_txt handles.rs_srp handles.rs_sap_txt handles.rs_sap...
     handles.rs_frp_txt handles.rs_frp handles.rs_fea_txt handles.rs_fea],'visible','on');

% === Apply button ========================================================
function rs_inbxapp(hObject, handles)
set([ handles.rs_inbxsdw handles.rs_inbx1 handles.rs_inbx2...
     handles.rs_inbxtitle handles.rs_inbxapp handles.rs_inbxcncl...
     handles.rs_fgs_txt handles.rs_fgs handles.rs_fps_txt handles.rs_fps...
     handles.rs_srp_txt handles.rs_srp handles.rs_sap_txt handles.rs_sap...
     handles.rs_frp_txt handles.rs_frp handles.rs_fea_txt handles.rs_fea],'visible','off');

data=getappdata(gcbf, 'Userdata');
data.rs_fgs = str2num(get(handles.rs_fgs, 'String'));
data.rs_fps = str2num(get(handles.rs_fps, 'String'));
data.rs_srp = str2num(get(handles.rs_srp, 'String'));
data.rs_sap = str2num(get(handles.rs_sap, 'String'));
data.rs_frp = str2num(get(handles.rs_frp, 'String'));
data.rs_fea = str2num(get(handles.rs_fea, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function rs_inbxcncl(hObject, handles)
set([ handles.rs_inbxsdw handles.rs_inbx1 handles.rs_inbx2...
     handles.rs_inbxtitle handles.rs_inbxapp handles.rs_inbxcncl...
     handles.rs_fgs_txt handles.rs_fgs handles.rs_fps_txt handles.rs_fps...
     handles.rs_srp_txt handles.rs_srp handles.rs_sap_txt handles.rs_sap...
     handles.rs_frp_txt handles.rs_frp handles.rs_fea_txt handles.rs_fea],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.rs_fgs, 'String', data.rs_fgs);
set(handles.rs_fps, 'String', data.rs_fps);
set(handles.rs_srp, 'String', data.rs_srp);
set(handles.rs_sap, 'String', data.rs_sap);
set(handles.rs_frp, 'String', data.rs_frp);
set(handles.rs_fea, 'String', data.rs_fea);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%    Plotting Parameters
% -------------------------------------------------------------------------
% === Plotting parameters =================================================
function or_btn(hObject, handles)
disablesomeinput(hObject, handles);
set([handles.or_inbxsdw handles.or_inbx1 handles.or_inbx2...
     handles.or_inbxapp handles.or_inbxcncl handles.or_txt handles.op_txt...
     handles.op_list_txt handles.op_list handles.op_style_txt...
     handles.op_style handles.op_sign_txt handles.op_sign handles.pp_txt...
     handles.pp_list_txt handles.pp_list handles.pp_xl_txt handles.pp_xl...
     handles.pp_yl_txt handles.pp_yl handles.pp_zl_txt handles.pp_zl...
     handles.pp_title_txt handles.pp_title...
     handles.pp_style_txt handles.pp_style handles.pp_sign_txt...
     handles.pp_sign handles.pp_axis_txt handles.pp_axis...
     handles.dp_type_txt handles.dp_type handles.dp_np_txt handles.dp_np...
     handles.dp_res_txt handles.dp_res],'visible','on');

% === Apply button ========================================================
function or_inbxapp(hObject, handles)
set([handles.or_inbxsdw handles.or_inbx1 handles.or_inbx2...
     handles.or_inbxapp handles.or_inbxcncl handles.or_txt handles.op_txt...
     handles.op_list_txt handles.op_list handles.op_style_txt...
     handles.op_style handles.op_sign_txt handles.op_sign handles.pp_txt...
     handles.pp_list_txt handles.pp_list handles.pp_xl_txt handles.pp_xl...
     handles.pp_yl_txt handles.pp_yl handles.pp_zl_txt handles.pp_zl...
     handles.pp_title_txt handles.pp_title...
     handles.pp_style_txt handles.pp_style handles.pp_sign_txt...
     handles.pp_sign handles.pp_axis_txt handles.pp_axis...
     handles.dp_type_txt handles.dp_type handles.dp_np_txt handles.dp_np...
     handles.dp_res_txt handles.dp_res],'visible','off');

data = getappdata(gcbf, 'Userdata');
data.op_list = str2num(get(handles.op_list, 'String'));
data.op_style = str2num(get(handles.op_style, 'String'));
data.op_sign = str2num(get(handles.op_sign, 'String'));
data.pp_list = str2num(get(handles.pp_list, 'String'));
data.pp_xl = get(handles.pp_xl, 'String');
data.pp_yl = get(handles.pp_yl, 'String');
data.pp_zl = get(handles.pp_zl, 'String');
data.pp_title = get(handles.pp_title, 'String');
data.pp_style = str2num(get(handles.pp_style, 'String'));
data.pp_sign = str2num(get(handles.pp_sign, 'String'));
data.pp_axis = str2num(get(handles.pp_axis, 'String'));
data.dp_type = get(handles.dp_type, 'Value');
data.dp_np = str2num(get(handles.dp_np, 'String'));
data.dp_res = str2num(get(handles.dp_res, 'String'));
setappdata(gcbf, 'Userdata', data);
enablesomeinput(hObject, handles);

% === Cancel button =======================================================
function or_inbxcncl(hObject, handles)
set([handles.or_inbxsdw handles.or_inbx1 handles.or_inbx2...
     handles.or_inbxapp handles.or_inbxcncl handles.or_txt handles.op_txt...
     handles.op_list_txt handles.op_list handles.op_style_txt...
     handles.op_style handles.op_sign_txt handles.op_sign handles.pp_txt...
     handles.pp_list_txt handles.pp_list handles.pp_xl_txt handles.pp_xl...
     handles.pp_yl_txt handles.pp_yl handles.pp_zl_txt handles.pp_zl...
     handles.pp_title_txt handles.pp_title...
     handles.pp_style_txt handles.pp_style handles.pp_sign_txt...
     handles.pp_sign handles.pp_axis_txt handles.pp_axis...
     handles.dp_type_txt handles.dp_type handles.dp_np_txt handles.dp_np...
     handles.dp_res_txt handles.dp_res],'visible','off');

data=getappdata(gcbf, 'Userdata');
set(handles.op_list, 'String', ['[',num2str(data.op_list),']']);
set(handles.op_style, 'String', ['[',num2str(data.op_style),']']);
set(handles.op_sign, 'String', ['[',num2str(data.op_sign),']']);
set(handles.pp_list, 'String', ['[',num2str(data.pp_list),']']);
set(handles.pp_xl, 'String', data.pp_xl);
set(handles.pp_yl, 'String', data.pp_yl);
set(handles.pp_zl, 'String', data.pp_zl);
set(handles.pp_title, 'String', data.pp_title);
set(handles.pp_style, 'String', ['[',num2str(data.pp_style),']']);
set(handles.pp_sign, 'String', ['[',num2str(data.pp_sign),']']);
if isempty(data.pp_axis)
    ppaxis = 'Auto';
else
    ppaxis = ['[' num2str(data.pp_axis) ']'];
end
set(handles.pp_axis,'String',ppaxis);
set(handles.dp_type,'Value',data.dp_type);
set(handles.dp_np,'String',data.dp_np);
set(handles.dp_res,'String',data.dp_res);
enablesomeinput(hObject, handles);

% === List of objectives for plotting =====================================
function op_list(hObject, handles)
in = str2num(get(hObject, 'String'));
data = getappdata(gcbf, 'Userdata');

if ~isempty(in)
        if sum(abs(round(in)-in))>0             % check integer
            uiwait(errordlg('Input must be integer (vector)','Error','modal'));
            set(hObject,'String',['[',num2str(data.op_list),']']);            
        elseif sum((in<1)|(in>data.fp_nobj))        % check range
            uiwait(errordlg(['Objectives number lies between 1 and '...
                    num2str(data.fp_nobj) ],'Error','modal'));   
            set(hObject,'String',['[',num2str(data.op_list),']']);
        elseif max(size(in) ~= size(unique(in)))    % check for redundance
            uiwait(errordlg('Objectives are redundant','Error','modal'));
            set(hObject,'String',['[',num2str(data.op_list),']']);      
        else
            set(hObject,'String',['[',num2str(in),']']);  
        end
else                                % if string input or empty
    set(hObject,'String',['[]']);
end

% === Style for each objective ============================================
function op_style(hObject, handles)
in = str2num(get(hObject, 'String'));
data = getappdata(gcbf, 'Userdata');

if ~isempty(in)
    
        oplist = str2num(get(handles.op_list,'String'));
    
        if sum((in~=1)&(in~=0))        % check 
            uiwait(errordlg('Input must be 0 (log) or 1 (linear)','Error','modal'));   
            set(hObject,'String',['[',num2str(data.op_style),']']);            
        elseif (length(in) ~= length(oplist)) & ~isempty(oplist)   %
            uiwait(errordlg('Invalid number of elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.op_style),']']);   
        elseif (length(in) > data.fp_nobj)  %
            uiwait(errordlg('Too many elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.op_style),']']);               
        else
            set(hObject,'String',['[',num2str(in),']']);
        end
else                                % if string input or empty
    set(hObject,'String',['[]']);
end

% === Sign of fitness for each objective ==================================
function op_sign(hObject, handles)
in = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');

if ~isempty(in)
    
        oplist = str2num(get(handles.op_list,'String'));

        if sum((in~=1)&(in~=-1))        % check 
            uiwait(errordlg('Input must be -1 (negative) or 1 (pos/mixed)',...
                'Error','modal'));   
            set(hObject,'String',['[',num2str(data.op_sign),']']);
        elseif (length(in) ~= length(oplist)) & ~isempty(oplist)   %
            uiwait(errordlg('Invalid number of elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.op_sign),']']);   
        elseif (length(in) > data.fp_nobj)  %
            uiwait(errordlg('Too many elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.op_sign),']']);     
        else
            set(hObject,'String',['[',num2str(in),']']);
        end
else                                % if string input or empty
    set(hObject,'String',['[]']);
end

% === List of 2 or 3 objective for Pareto plot ============================
function pp_list(hObject, handles)
in = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');

if ~isempty(in)
        if sum(abs(round(in)-in))>0             % check integer
            uiwait(errordlg('Input must be integer (vector)','Error','modal'));
            set(hObject,'String',['[',num2str(data.pp_list),']']);            
        elseif sum((in<1)|(in>data.fp_nobj))        % check range
            uiwait(errordlg(['Objectives number lies between 1 and '...
                    num2str(data.fp_nobj) ],'Error','modal'));   
            set(hObject,'String',['[',num2str(data.pp_list),']']);         
        elseif max(size(in) ~= size(unique(in)))    % check for redundance
            uiwait(errordlg('Objectives are redundant','Error','modal'));
            set(hObject,'String',['[',num2str(data.pp_list),']']);  
        elseif (length(in) > 3) | (length(in) < 2)
            uiwait(errordlg('Pareto plot supports 2 or 3 objectives','Warning','modal'));
            set(hObject,'String',['[',num2str(data.pp_list),']']);               
        else
            set(hObject,'String',['[',num2str(unique(in)),']']); 
        end
else                                % if string input or empty
    set(hObject,'String',['[]']);
end

% === Style for each objective ============================================
function pp_style(hObject, handles)
in = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');

if ~isempty(in)
    
        pplist = str2num(get(handles.pp_list,'String')); 
        
        if sum((in~=1)&(in~=0))        % check 
            uiwait(errordlg('Input must be 0 (log) or 1 (linear)','Error','modal'));   
            set(hObject,'String',['[',num2str(data.pp_style),']']);
        elseif (length(in) ~= length(pplist)) & ~isempty(pplist)   %
            uiwait(errordlg('Invalid number of elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.pp_style),']']);           
        elseif length(in) > data.fp_nobj  %
            uiwait(errordlg('Too many elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.pp_style),']']);   
        else
            set(hObject,'String',['[',num2str(in),']']);
        end
else                                % if string input or empty
    set(hObject,'String',['[]']);
end

% === Sign of fitness for each objective ==================================
function pp_sign(hObject, handles)
in = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');

if ~isempty(in)
    
        pplist = str2num(get(handles.pp_list,'String')); 
        
        if sum((in~=1)&(in~=-1))        % check 
            uiwait(errordlg('Input must be -1 (negative) or 1 (pos/mixed)',...
                'Error','modal'));   
            set(hObject,'String',['[',num2str(data.op_sign),']']);
        elseif (length(in) ~= length(pplist)) & ~isempty(pplist)   %
            uiwait(errordlg('Invalid number of elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.pp_sign),']']);
        elseif length(in) > data.fp_nobj   %
            uiwait(errordlg('Too many elements','Warning','modal'));
            set(hObject,'String',['[',num2str(data.pp_sign),']']);   
        else
            set(hObject,'String',['[',num2str(in),']']);
        end
else                                % if string input or empty
    set(hObject,'String',['[]']);
end

% === Axis limits for Pareto plot =========================================
function pp_axis(hObject, handles)
in = str2num(get(hObject,'String'));
data = getappdata(gcbf, 'Userdata');


% find the No. of objective for Pareto plot
nop = size(data.pp_list,2);

if ~isempty(in)
        if length(in) ~= 2*nop             % check if number of elements is correct
            uiwait(errordlg('Invalid number of element','Error','modal'));
            set(hObject,'String','Auto');            
        elseif (in(1)>in(2)) | (in(3)>in(4)) | (nop==3)*(in(5)>in(6))  % check the range validity
            uiwait(errordlg('Upper limit value is smaller than lower limit','Error','modal'));
            set(hObject,'String','Auto');               
        else
            set(hObject,'String',['[',num2str(in),']']); 
        end
else                                % if string input or empty
    set(hObject,'String','Auto');
end

% -------------------------------------------------------------------------
%    CHECK SETTING
% -------------------------------------------------------------------------
function [newdata] = checksetting(data)

newdata = gapdefault;                   % load GAP default data           
newdata.ev_bev = 0;
newdata.ff_name = 'Choose fitness function';
newdata.ff_path = [];
newdata.ff_data = [];
newdata.ff_data_store = [];
newdata.fp_nobj = 1;
newdata.ngenes = 3;
newdata.dspgene = 1;
newdata.descgene = {'gene #1'  'gene #2'  'gene #3'};
newdata.gd_min = [0 0 0];
newdata.gd_max = [1 1 1];
newdata.gd_type = [2 2 2];
newdata.gd_cid = [1 1 1];  
newdata.ur_pre = [];
newdata.ur_post = [];

newfldnames = fieldnames(newdata);      % get default field names
fldnames = fieldnames(data);            % get current field names

for i=1:length(fldnames);
    if ~isempty(strmatch(fldnames(i),newfldnames)); % if valid field name in current data,
       eval(['newdata.',fldnames{i},'=data.',fldnames{i},';']); % update new value
    end
end
 
% -------------------------------------------------------------------------
%    APPLY SETTING
% -------------------------------------------------------------------------
function applysetting(hObject, handles)
global simflag
simflag = 0;        % reset the simulation status flag

data = getappdata(gcbf, 'Userdata');        % load data
fldnames = fieldnames(data);                % get field names

% Fitness function 
if data.fp_nobj == 1;
    objmode = 'S'; objmodetip = 'Single-objective optimization';
else 
    objmode = 'M'; objmodetip = 'Multi-objective optimization';
end


if strcmp(data.ff_name,'Choose fitness function');
    str_ff_dsp = data.ff_name;
    fclr = 'R';
    objmode = ''; objmodetip = '';
else
    str_ff_dsp = [data.ff_name '.m'];
    fclr = 'K';
end

set(handles.ff_dsp,'String',str_ff_dsp,'ForegroundColor',fclr);
set(handles.ff_mode,'String',objmode,'Tooltipstring',objmodetip);
set(handles.ff_name,'String',str_ff_dsp,'ForegroundColor',fclr);
set(handles.ev_bev,'Value',data.ev_bev+1);
[data,datafiledisp] = checkoptdata(data);
set(handles.ff_data,'String',datafiledisp);

% Fundamental parameters
set(handles.fp_ngen,'String',data.fp_ngen); 
set(handles.fp_ipop,'String',data.fp_ipop);
set(handles.fp_npop,'String',data.fp_npop);
set(handles.fp_nobj,'String',data.fp_nobj);
set(handles.fp_obj,'String',data.fp_obj);

% Diversity control
if data.dc_act 
    set(handles.dc_act,'Value',1,'BackgroundColor','w');
    set(handles.dc_btn,'Enable','on');
else 
    set(handles.dc_act,'Value',0,'BackgroundColor',.7*ones(1,3));
    set(handles.dc_btn,'Enable','off');
end
set(handles.dc_alg,'Value',data.dc_alg);
set(handles.dc_spc,'Value',data.dc_spc);
set(handles.dc_mnt,'String',data.dc_mnt);
set(handles.dc_mxt,'String',data.dc_mxt);
set(handles.dc_mnb,'String',data.dc_mnb);
set(handles.dc_mxb,'String',data.dc_mxb);
set(handles.dc_ntr,'String',data.dc_ntr);
set(handles.dc_dc,'String',data.dc_dc);
set(handles.dc_nt,'String',data.dc_nt);

% Scaling
set(handles.sc_alg,'Value',data.sc_alg+1);
set(handles.sc_kln,'String',data.sc_kln);
set(handles.sc_cst,'String',data.sc_cst);
set(handles.sc_kmxq,'String',data.sc_kmxq);
set(handles.sc_kmnq,'String',data.sc_kmnq);

% Selection
set(handles.sl_alg,'Value',data.sl_alg);
set(handles.sl_nts,'Value',data.sl_nts);
if isempty(data.sl_cah)
    fname = 'none';
else
    fname = [data.sl_cah,'.m'];
end
set(handles.sl_cah,'String',fname);

% Death
set(handles.dt_alg,'Value',data.dt_alg);
set(handles.dt_nts,'Value',data.dt_nts);
if isempty(data.dt_cah)
    fname = 'none';
else
    fname = [data.dt_cah,'.m'];
end
set(handles.dt_cah,'String',fname);

% Mating Crossover
set(handles.mc_pp,'String',data.mc_pp);
set(handles.mc_fc,'String',data.mc_fc);
set(handles.mc_alg,'Value',data.mc_alg);
set(handles.mc_gac,'String',data.mc_gac);
set(handles.mc_ec,'String',data.mc_ec);

% Mutation
set(handles.mt_ptgm,'String',data.mt_ptgm);
set(handles.mt_prgm,'String',data.mt_prgm);
set(handles.mt_srgm,'String',data.mt_srgm);
set(handles.mt_pagm,'String',data.mt_pagm);
set(handles.mt_sagm,'String',data.mt_sagm);
set(handles.mt_prvm,'String',data.mt_prvm);
set(handles.mt_srvm,'String',data.mt_srvm);
set(handles.mt_pavm,'String',data.mt_pavm);
set(handles.mt_savm,'String',data.mt_savm);
set(handles.mt_pigm,'String',data.mt_pigm);

% Gene repair
set(handles.gr_alg,'value',data.gr_alg);

% Migration
set(handles.mg_nreg,'String',data.mg_nreg);
set(handles.mg_tmig,'String',data.mg_tmig);
set(handles.mg_pmig,'String',data.mg_pmig);

% Evaluation
set(handles.ev_bev,'Value',data.ev_bev+1);
set(handles.ev_are,'Value',data.ev_are+1);
set(handles.ev_ssd,'Value',data.ev_ssd);

% Elitism
if data.el_act 
    set(handles.el_act,'Value',1,'BackgroundColor','w');
    set(handles.el_btn,'Enable','on');
else 
    set(handles.el_act,'Value',0,'BackgroundColor',.7*ones(1,3));
    set(handles.el_btn,'Enable','off');
end
set(handles.el_fgs,'String',data.el_fgs);
set(handles.el_fpe,'String',data.el_fpe);

% Random Search
set(handles.rs_fgs,'String',data.rs_fgs);
set(handles.rs_fps,'String',data.rs_fps);
set(handles.rs_srp,'String',data.rs_srp);
set(handles.rs_sap,'String',data.rs_sap);
set(handles.rs_frp,'String',data.rs_frp);
set(handles.rs_fea,'String',data.rs_fea);

% Plotting parameters
set(handles.rp_lvl,'Value',data.rp_lvl+2);
set(handles.rp_gbr,'String',data.rp_gbr);
if isempty(data.rp_crh)
    fname = 'none';
else
    fname = [data.rp_crh,'.m'];
end
set(handles.rp_crh,'String',fname);

set(handles.op_list,'String',['[',num2str(data.op_list),']']);
set(handles.op_style,'String',['[',num2str(data.op_style),']']);
set(handles.op_sign,'String',['[',num2str(data.op_sign),']']);

set(handles.pp_list,'String',['[',num2str(data.pp_list),']']);
set(handles.pp_xl,'String',data.pp_xl);
set(handles.pp_yl,'String',data.pp_yl);
set(handles.pp_zl, 'String', data.pp_zl);
set(handles.pp_title,'String',data.pp_title);
set(handles.pp_style,'String',['[',num2str(data.pp_style),']']);
set(handles.pp_sign,'String',['[',num2str(data.pp_sign),']']);
if isempty(data.pp_axis)
    ppaxis = 'Auto';
else
    ppaxis = ['[' num2str(data.pp_axis) ']'];
end
set(handles.pp_axis,'String',ppaxis);

set(handles.dp_type,'Value',data.dp_type);
set(handles.dp_np,'String',data.dp_np);
set(handles.dp_res,'String',data.dp_res);

% Others
if isempty(data.ur_pre)
    urpredisp = 'none';
    data.ur_pre = [];
else
    urpredisp = data.ur_pre;
end  
set(handles.ur_pre,'String',urpredisp);

if isempty(data.ur_post)
    urpostdisp = 'none';
    data.ur_post = [];
else
    urpostdisp = data.ur_post;
end  
set(handles.ur_post,'String',urpostdisp);
set(handles.ngenes,'String',data.ngenes);
set(handles.dspgene,'String',data.dspgene);
if data.ngenes == 1;
    slidermx = 2;
    sliderenable = 'off';
else
    slidermx = data.ngenes;
    sliderenable = 'on';
end
set(handles.selectgene_txt,'Enable',sliderenable);
set(handles.selectgene,'value',data.dspgene,'Max',slidermx,'Min',1,'SliderStep',...
    [1 ceil((data.ngenes-1)*0.2)]/(slidermx-1),'Enable',sliderenable);

set(handles.descgene,'String',data.descgene{data.dspgene});
set(handles.min,'String',data.gd_min(data.dspgene));
set(handles.max,'String',data.gd_max(data.dspgene));
set(handles.type,'Value',data.gd_type(data.dspgene));
set(handles.cid,'String',data.gd_cid(data.dspgene));

setappdata(gcbf, 'Userdata', data);

% -------------------------------------------------------------------------
%    CLOSE CHECKING 
% -------------------------------------------------------------------------
function closecheck(hObject, handles)

data = getappdata(gcbf, 'Userdata');
recentfiles = getappdata(gcbf,'Recentfiles');

if ~strcmp(data.ff_name,'Choose fitness function');
    % save setting of current fitness function
    savesetting(hObject,handles,[data.ff_path, data.ff_name],data);
  
    % confirm saving the current data
    answer = questdlg('Save data before closing?','','Yes','No','Cancel','Yes');
    switch answer,
        case 'Cancel',
            return    
        case 'Yes', 
            goset('savedata',gcbo,guidata(gcbo));
    end % switch
end

% save recentfiles in GOSET.SET
gosetver = lower(get(handles.figH,'Tag'));
location = which('goset.p');         % find the directory of GOSET.P file
if isempty(location)        % if GOSET.P does not exist, find the directory of GOSET.M file
    location = which('goset.m');
end
gosetpath = fileparts(location);       % and save last settings to GOSET.SET
save('-mat',[gosetpath filesep 'goset.set'],'recentfiles');  

%close all figures
figHandles = allchild(0);
figH = findobj(figHandles, 'flat', 'Tag', 'reportplot');
if ~isempty(figH)
    delete(figH);
end

% close main window
closereq;   

% -------------------------------------------------------------------------
%    Disable handles to prevent interruption
% -------------------------------------------------------------------------
function disablesomeinput(hObject, handles);
data = getappdata(gcbf, 'Userdata');
GAS = getappdata(gcbf, 'GAS');

set([handles.setmenu handles.filemenu handles.optionmenu handles.helpmenu...
     handles.startbtn handles.rp_lvl handles.rp_gbr...
     handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset handles.plotdata....
     handles.dispbst handles.stopbtn handles.contbtn],'Enable','off')
set([handles.ff_btn handles.ff_subfld handles.ff_dsp handles.ff_mode...
     handles.gp_btn handles.fp_btn handles.ev_btn handles.dc_btn...
     handles.dc_act handles.sc_btn handles.sl_btn handles.dt_btn...
     handles.mc_btn handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn...
     handles.el_act handles.rs_btn handles.or_btn],'visible','off');


if (data.fp_ngen > GAS.cg) & (GAS.cg > 1)  % continue case
    set(handles.startbtn,'visible','off');
    set(handles.startbtnoff,'visible','on');
    set(handles.stopbtn,'visible','off');
    set(handles.stopbtnoff,'visible','off');
    set(handles.contbtn,'visible','off');
    set(handles.contbtnoff,'visible','on');
else
    set(handles.startbtn,'visible','off');
    set(handles.startbtnoff,'visible','on');
    set(handles.stopbtn,'visible','off');
    set(handles.stopbtnoff,'visible','on');
    set(handles.contbtn,'visible','off');
    set(handles.contbtn,'visible','off');
end

% -------------------------------------------------------------------------
%    Enable handles back to normal
% -------------------------------------------------------------------------
function enablesomeinput(hObject, handles);
data = getappdata(gcbf, 'Userdata');
GAS = getappdata(gcbf, 'GAS');

set([handles.setmenu handles.filemenu handles.optionmenu handles.helpmenu...
     handles.startbtn handles.rp_lvl handles.rp_gbr...
     handles.rp_crh_browse handles.rp_crh handles.rp_crh_reset handles.plotdata....
     handles.dispbst handles.stopbtn handles.contbtn],'Enable','on')
set([handles.ff_btn handles.ff_subfld handles.ff_dsp handles.ff_mode...
     handles.gp_btn handles.fp_btn handles.ev_btn handles.dc_btn...
     handles.dc_act handles.sc_btn handles.sl_btn handles.dt_btn...
     handles.mc_btn handles.mt_btn handles.gr_btn handles.mg_btn handles.el_btn...
     handles.el_act handles.rs_btn handles.or_btn],'visible','on');

if (data.fp_ngen > GAS.cg) & (GAS.cg > 1)   % continue case
    set(handles.startbtn,'visible','on');
    set(handles.startbtnoff,'visible','off');
    set(handles.stopbtn,'visible','off');
    set(handles.stopbtnoff,'visible','off');
    set(handles.contbtn,'visible','on');
    set(handles.contbtnoff,'visible','off');
else
    set(handles.startbtn,'visible','on');
    set(handles.startbtnoff,'visible','off');
    set(handles.stopbtn,'visible','off');
    set(handles.stopbtnoff,'visible','on');
    set(handles.contbtn,'visible','off');
    set(handles.contbtn,'visible','off');
end


% -------------------------------------------------------------------------
%    LOAD RECENT FITNESS FUNCTION 
% -------------------------------------------------------------------------
function loadrecentfitfun(hObject, handles)
data = getappdata(gcbf, 'Userdata');
recentfiles=getappdata(gcbf, 'Recentfiles');

idx = str2num(get(hObject, 'Userdata'));

[pathname,filename,fileext]=fileparts(recentfiles{idx});
pathname = [pathname filesep];
filename = [filename fileext];

if exist(recentfiles{idx},'file')       % fitness function exists as an mfile?
    
    if strcmp(questdlg(...              % reconfirm loading the default setting
        {['Do you want to save current settings for ''', data.ff_name, '.m'' ?'],'',...
        'Any unsaved changes will be lost.',''},'Save current setting','Yes','No','No'),'Yes')
        savesetting(hObject,handles,[data.ff_path, data.ff_name],data);       % save setting of old fitness function
    end 

    cd(pathname);
    data.ff_path = pathname;        
    data.ff_name = filename(1:length(filename)-2);
    set(handles.ff_dsp,'String',[data.ff_name '.m'],'ForegroundColor','K');
    setappdata(gcbf, 'Userdata', data);   
    
    figHandles = allchild(0);                   % close figures
    figH = findobj(figHandles, 'flat', 'Tag', 'reportplot');
    if ~isempty(figH)
        delete(figH);
    end
    
    if exist([data.ff_path data.ff_name '.set'],'file') % if the setting file exists
            load('-mat',[data.ff_name '.set']);     
            data.ff_name = filename(1:length(filename)-2);    % Assign fitness function name without the extention .m
            data.ff_path = pathname;
            setappdata(gcbf, 'Userdata', data);
            data = checksetting(data);                  % check and fix setting
            setappdata(gcbf, 'Userdata', data);         % store parameter
            applysetting(hObject,handles);
    else
        defaultsetting(hObject,handles);
    end
        
    GAS = getappdata(gcbf, 'GAS');          % reset current generation No.
    GAS.cg = 1;
    setappdata(gcbf,'GAS',GAS);
    set(handles.cg,'String','');            % update evolution Status
    set(handles.bestfit,'String','');
    set(handles.meanfit,'String','');
    pos=get(handles.pbar,'Position');
    pos(3)=170;
    set(handles.pbar,'Position',pos);
    set(handles.pbar,'String','Progress bar'); 
    setappdata(gcbf, 'P', []);              % reset the population information

else
    uiwait(errordlg('Click OK to choose a fitness function','Fitness function not found','modal'));
    [filename,pathname] = uigetfile('*.m','Select the fitness function M-file');
    if isequal(filename,0) | isequal(pathname,0)
        uiwait(warndlg('Fitness function is not properly defined','Warning','modal'))
        return
    else  
        set(handles.ff_name,'String',filename);
        data.ff_name = filename(1:length(filename)-2);       % Assign fitness function name without the extention .m
        data.ff_path = pathname;
        setappdata(gcbf, 'Userdata', data);
        cd(pathname);
    end
    idx = find(strcmp([pathname filename],recentfiles));
end

% Reorder recent file list and update
if isempty(idx)
    for i=1:6    
        recentfiles{7-i}=recentfiles{6-i};
    end  
elseif idx ~=1
    for i=1:idx-1
        recentfiles{idx+1-i}=recentfiles{idx-i};
    end        
end
recentfiles{1}=[pathname filename];
updaterecentfiles(recentfiles,handles);
setappdata(gcbf,'Recentfiles',recentfiles);
enablesomeinput(hObject, handles);

% -------------------------------------------------------------------------
%   UPDATE RECENT FILES
% -------------------------------------------------------------------------
function updaterecentfiles(recentfiles, handles)

for i=2:6
    if exist(recentfiles{i},'file')
        n=length(recentfiles{i});
        if n>30
            abbname=['[''' num2str(i-1) '  '' recentfiles{' num2str(i)...
                '}(1:3) ''...'' recentfiles{' num2str(i) '}(n-26:n)]'];
        else 
            abbname=['[''' num2str(i-1) '  '' recentfiles{' num2str(i) '}]'];
        end      
    else
        abbname = ['[''' num2str(i-1) ''']'];    
    end;   

    eval(['set(handles.recentfile' num2str(i-1) ',''Label'',' abbname ')']);
       
end      
      

% -------------------------------------------------------------------------
%   VECTOR DISPLAY MODULE (vecdisp)
% -------------------------------------------------------------------------
function vecdisp(vec,fw,alg,lf,bt,hl)
n=length(vec);
for i=1:n;
    uicontrol('Style','text','Position',[lf (n-i)*15+bt hl 15],...
            'HorizontalAlignment',alg,'FontWeight',fw,'String',vec(i));
end;


% -------------------------------------------------------------------------
%   VIEW CURRENT SETTING
% -------------------------------------------------------------------------
function viewsetting(hObject, handles)
fWidth = 635;
fHeight = 470;

setfigH = findobj('Name','Settings');  

if isempty(setfigH)                       % if the figure does not exist,
    screen_s = get(0,'ScreenSize');     % detect current screen size
    pos = [screen_s(3)/2 - fWidth/2, screen_s(4)/2 - fHeight/2, fWidth, fHeight];

    setfigH = figure('Position',pos,'Resize','off','NumberTitle','off',...
        'Name','Settings','Interruptible','on','Menubar','none','Tag','reportplot',...
        'Color',get(0,'DefaultUIControlBackgroundColor'));
 
    setH.listbx = uicontrol( ...
        'Style', 'list', ...
        'HorizontalAlignment','left', ...
        'Units', 'points', ...
        'Visible', 'on',...
        'BackgroundColor', [1 1 1], ...
        'Fontname','courier new',...
        'Fontsize',9,...
        'Max', 2, ...
        'Value', [], ...
        'Enable', 'inactive', ...
        'Position', [10 20 455 300], ...
        'String', [], ...
        'Tag', 'DemoListbox');

    setH.mainwdwhdl = gcbf;

    setH.filepara = uicontrol('Style','pushbutton','Position',[16 428 120 30],...
        'HorizontalAlignment','Center','String','Fitness function',...
        'Callback','goset(''viewsetting'',gcbo,guidata(gcbo))');
    setH.genepara = uicontrol('Style','pushbutton','Position',[136 428 120 30],...
        'HorizontalAlignment','Center','String','Gene parameters',...
        'Callback','goset(''viewsetting'',gcbo,guidata(gcbo))');    
    setH.gaoppara = uicontrol('Style','pushbutton','Position',[256 428 120 30],...
        'HorizontalAlignment','Center','String','GA Operators',...
        'Callback','goset(''viewsetting'',gcbo,guidata(gcbo))');
    setH.export = uicontrol('Style','pushbutton','Position',[480 433 140 24],...
        'HorizontalAlignment','Center','String','Export to text file',...
        'Callback','goset(''viewsetting'',gcbo,guidata(gcbo))');
    
    uicontrol('style','text','position',[540 5 100 16],'String',get(handles.figH,'Name'));   
    setH.figH = setfigH;
    set(gcf, 'Userdata', setH);
else
    figure(setfigH);
end             


setH = get(setfigH, 'Userdata'); 
data = getappdata(setH.mainwdwhdl, 'Userdata');
          
settinglist ={  '',...
        '  -------------------------------------------------------------------------------',...
        '                           Parameters for GA operator',...
        '  -------------------------------------------------------------------------------',...
        '',...
        '   Fundamental parameters','',...
        '        Number of generations to evolve         GAP.fp_ngen                      ','',...
        '        Initial population size                 GAP.fp_ipop                      ','',...
        '        Population size                         GAP.fp_npop                      ','',... 
        '        Number of objective functions           GAP.fp_nobj                      ','',...
        '        Objective to optimize                   GAP.fp_obj                       ','',...
        '',...
        '   Diversity control parameters','',...
        '        Activate diversity control              GAP.dc_act                       ','',...
        '        Diversity control algorithm             GAP.dc_alg                       ','',...
        '        Diversity control applied space         GAP.dc_spc                       ','',...
        '        Minimum threshold (Algorithm 1)         GAP.dc_mnt                       ','',...
        '        Maximum threshold (Algorithm 1)         GAP.dc_mxt                       ','',...
        '        Number of trials (Algorithm 2)          GAP.dc_ntr                       ','',...
        '        Minimum number of bins relative to      GAP.dc_mnb                       ',... 
        '          population size (Algorithm 2)','',...
        '        Maximum number of bins relative to      GAP.dc_mxb                       ',...
        '          population size (Algorithm 2)','',...
        '        Distance constant (Algorithm 3 & 4)     GAP.dc_dc                        ','',...
        '        Test population size (Algorithm 4)      GAP.dc_nt                        ','',...
        '',...
        '   Scaling parameters','',...
        '        Scaling algorithm                       GAP.sc_alg                       ','',...
        '        Scalig factor for linear scaling        GAP.sc_kln                       ','',...
        '        Scalig constant for sigma truncation    GAP.sc_cst                       ','',...
        '        Quadratic scaling factor (most)         GAP.sc_kmxq                      ','',...
        '        Quadratic scaling factor (least)        GAP.sc_kmnq                      ','',...
        '',...
        '   Selection operator parameters','',...
        '        Selection algorithm                     GAP.sl_alg                       ','',...
        '        Number of individuals in a tournament   GAP.sl_nts                       ','',...
        '        Custom selection operator               GAP.sl_cah                       ','',...
        '',...
        '   Death operator parameters','',...
        '        Death algorithm                         GAP.dt_alg                       ','',...
        '        Number of individuals in a tournament   GAP.dt_nts                       ','',...
        '        Custom death operator                   GAP.dt_cah                       ','',...
        '',...
        '   Mating and crossover parameters','',...
        '        Percentage of population replaced       GAP.mc_pp                        ','',...
        '        Fraction of chromosomes of individual   GAP.mc_fc                        ',...
        '          who is selected for mating','',...
        '        Crossover algorithm                     GAP.mc_alg                       ','',...
        '        Generation between algorithm change     GAP.mc_gac                       ',...
        '          for random crossover','',...
        '        Tightness of distribution               GAP.mc_ec                        ',...
        '          for simulated binary crossover','',...
        '',...
        '   Mutation operator parameters','',...
        '        Total gene mutation probability         GAP.mt_ptgm                      ','',...
        '        Relative partial gene mutation','',...
        '                               Probability      GAP.mt_prgm                      ',...
        '                        Standard deviation      GAP.mt_srgm                      ','',...
        '        Absolute partial gene mutation','',... 
        '                               Probability      GAP.mt_pagm                      ',...
        '                        Standard deviation      GAP.mt_sagm                      ','',...
        '        Relative vector gene mutation','',...
        '                               Probability      GAP.mt_prvm                      ',...
        '                        Standard deviation      GAP.mt_srvm                      ','',...
        '        Absolute vector gene mutation','',...
        '                               Probability      GAP.mt_pavm                      ',...
        '                        Standard deviation      GAP.mt_savm                      ','',...
        '        Integer gene mutation probability       GAP.mt_pigm                      ','',...
        '',...
        '   Gene repair parameters','',...
        '        Gene repair method                      GAP.gr_alg                       ','',...
        '',...
        '   Migration operator parameters','',...
        '        Number of regions                       GAP.mg_nreg                      ','',...
        '        Time between migrations in generatons   GAP.mg_tmig                      ','',...
        '        Migration prob. for each individual     GAP.mg_pmig                      ','',...
        '',...
        '   Evaluation parameters','',...
        '        Block evaluation option                 GAP.ev_bev                       ','',...
        '        Evaluate                                GAP.ev_are                       ','',...
        '        Supplementary data pass                 GAP.ev_ssd                       ','',...
        '',...
        '   Elitism parameters','',...
        '        Activate elitism                        GAP.el_act                       ','',...
        '        Elitism starting point                  GAP.el_fgs                       ',...
        '          as a fraction of generation','',...
        '        Fraction of population protected        GAP.el_fpe                       ',...
        '          as elite for multi-objective case',...
        '',...
        '   Random search parameters','',...
        '        Random search starting point            GAP.rs_fgs                       ',...
        '          as a fraction of generation','',...
        '        Fraction of total population size used  GAP.rs_fps                       ','',...
        '        Relative perturbation std dev           GAP.rs_srp                       ','',...
        '        Absolute perturbation std dev           GAP.rs_sap                       ','',...
        '        Duty cycle for rel. random perturbation GAP.rs_frp                       ','',...
        '        Fraction of generations involved        GAP.rs_fea                       ','',...
        '',...
        '   Reporting and plotting paremeters','',...
        '        Reporting level                         GAP.rp_lvl                       ','',...
        '        Generations between reports             GAP.rp_gbr                       ',''...
        '        Custom report algorithm                 GAP.rp_crh                       ',...
        '',...
        '        List of objectives for objective plots  GAP.op_list                      ','',...
        '        Style for each objectives               GAP.op_style                     ',...
        '                                                                                 ','',...
        '        Sign of fitness for each objectives     GAP.op_sign                      ',...
        '                                                                                 ','',...
        '',...
        '        List of objectives used in Pareto plot  GAP.pp_list                      ','',...
        '        X axis label                            GAP.pp_xl                        ',...
        '                                                                                 ','',...
        '        Y axis label                            GAP.pp_yl                        ',...
        '                                                                                 ','',...
        '        Z axis label                            GAP.pp_zl                        ',...
        '                                                                                 ','',...
        '        Pareto plot title                       GAP.pp_title                     ',...
        '                                                                                 ','',...
        '        Style for each objectives               GAP.pp_style                     ',...
        '                                                                                 ','',...
        '        Sign of fitness for each objective      GAP.pp_sign                      ',...
        '                                                                                 ','',...
        '        Axis limits for Pareto plot             GAP.pp_axis                      ',...
        '                                                                                 ','',...
        '        Type of distribution plot               GAP.pp_type                      ','',...
        '        Max no. of population to plot (Type 1)  GAP.dp_np                        ','',...
        '        No .of bins in dist. plot     (Type 2)  GAP.dp_res                       ','',...
        '',...
        '   Gene characteristic description - Refer to ''Gene parameters''','','',...
        '  -------------------------------------------------------------------------------',...
        '                           End of GA operator parameters',...
        '  -------------------------------------------------------------------------------',''};
        
        sl = 8;
        
        settinglist{sl}(66:80)=sprintf('%15.5g',data.fp_ngen);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.fp_ipop);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.fp_npop);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.fp_nobj);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.fp_obj);sl=sl+5;
        
        if data.dc_act; flag = 'Yes';else flag = 'No';end;
        settinglist{sl}(66:80)=sprintf('%15s',[flag,' (',num2str(data.dc_act),')']);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15g',data.dc_alg);sl=sl+2;
        if data.dc_spc == 1; flag = 'Parameter space';else flag = 'Fit. func. space';end;
        settinglist{sl}(61:80)=sprintf('%20s',[flag,' (',num2str(data.dc_spc),')']);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_mnt);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_mxt);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_ntr);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_mnb);sl=sl+3;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_mxb);sl=sl+3;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_dc);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dc_nt);sl=sl+5;
        
        sclalg = {'None','Offset','Linear (avg)','Linear (med)',...
                'Linear (least)', 'sigma truncation', 'Quadratic'};
        settinglist{sl}(61:80)=sprintf('%20s',[sclalg{data.sc_alg+1},...
                ' (',num2str(data.sc_alg),')']);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.sc_kln);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.sc_cst);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.sc_kmxq);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.sc_kmnq);sl=sl+5;
        
        if data.sl_alg == 1; flag = 'Roulette wheel';else flag = 'Tournament';end;
        settinglist{sl}(61:80)=sprintf('%20s',[flag,' (',num2str(data.sl_alg),')']);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.sl_nts);sl=sl+2;
        if isempty(data.sl_cah);fname='none';else fname=[data.sl_cah,'.m'];end;
        settinglist{sl}(61:80)=sprintf('%20s',fname);sl=sl+5;
        dtalg = {'Replace parents','Replace randomly','Fit. tournament',...
                 'Age tournament','Custom algorithm', 'Random'};
        settinglist{sl}(61:80)=sprintf('%20s',[dtalg{data.dt_alg},' (',num2str(data.dt_alg),')']);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dt_nts);sl=sl+2;
        if isempty(data.dt_cah);fname='none';else fname=[data.dt_cah,'.m'];end;
        settinglist{sl}(61:80)=sprintf('%20s',fname);sl=sl+5;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mc_pp);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mc_fc);sl=sl+3;
        settinglist{sl}(66:80)=sprintf('%15g',data.mc_alg);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15g',data.mc_gac);sl=sl+3;  
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mc_ec);sl=sl+6;        
        
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_ptgm);sl=sl+4;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_prgm);sl=sl+1;      
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_srgm);sl=sl+4;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_pagm);sl=sl+1;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_sagm);sl=sl+4; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_prvm);sl=sl+1;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_srvm);sl=sl+4; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_pavm);sl=sl+1; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_savm);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mt_pigm);sl=sl+5; 
        
        gralg = {'Hard limiting','Ring mapping'};
        settinglist{sl}(61:80)=sprintf('%20s',[gralg{data.gr_alg},...
                ' (',num2str(data.gr_alg),')']);sl=sl+5;
        
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mg_nreg);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mg_tmig);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.mg_pmig);sl=sl+5;
        if data.ev_bev; flag = 'Yes'; else flag = 'No';end;
        settinglist{sl}(61:80)=sprintf('%20s',[flag,' (',num2str(data.ev_bev),')']);sl=sl+2;
        if data.ev_are; flag = 'all individuals'; else flag = 'only unevaluated';end;
        settinglist{sl}(61:80)=sprintf('%20s',[flag,' (',num2str(data.ev_are),')']);sl=sl+2;
        if data.ev_ssd; flag = 'Yes'; else flag = 'No';end;
        settinglist{sl}(61:80)=sprintf('%20s',[flag,' (',num2str(data.ev_ssd),')']);sl=sl+5;

        if data.el_act; flag = 'Yes';else flag = 'No';end;
        settinglist{sl}(66:80)=sprintf('%15s',[flag,' (',num2str(data.el_act),')']);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.el_fgs);sl=sl+3;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.el_fpe);sl=sl+5;
        
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rs_fgs);sl=sl+3;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rs_fps);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rs_srp);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rs_sap);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rs_frp);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rs_fea);sl=sl+5;
        alg = {'No report','Text only','Plot and text'};
        settinglist{sl}(61:80)=sprintf('%20s',[alg{data.rp_lvl+2},...
                ' (',num2str(data.rp_lvl),')']);sl=sl+2; 
        settinglist{sl}(66:80)=sprintf('%15.5g',data.rp_gbr);sl=sl+2;
        if isempty(data.rp_crh);fname='none';else fname=[data.rp_crh,'.m'];end;
        settinglist{sl}(61:80)=sprintf('%20s',fname);sl=sl+2;
        settinglist{sl}(61:80)=sprintf('%20s',['[ ',num2str(data.op_list),' ]']);sl=sl+3; 
        settinglist{sl}(1:80)=sprintf('%80s',['[ ',num2str(data.op_style),' ]']);sl=sl+3; 
        settinglist{sl}(1:80)=sprintf('%80s',['[ ',num2str(data.op_sign),' ]']);sl=sl+3;  
        settinglist{sl}(61:80)=sprintf('%20s',['[ ',num2str(data.pp_list),' ]']);sl=sl+3; 
        settinglist{sl}(1:80)=sprintf('%80s',data.pp_xl);sl=sl+3; 
        settinglist{sl}(1:80)=sprintf('%80s',data.pp_yl);sl=sl+3; 
        settinglist{sl}(1:80)=sprintf('%80s',data.pp_zl);sl=sl+3; 
        settinglist{sl}(1:80)=sprintf('%80s',data.pp_title);sl=sl+3;  
        settinglist{sl}(1:80)=sprintf('%80s',['[ ',num2str(data.pp_style),' ]']);sl=sl+3;
        settinglist{sl}(1:80)=sprintf('%80s',['[ ',num2str(data.pp_sign),' ]']);sl=sl+3;  
        settinglist{sl}(1:80)=sprintf('%80s',['[ ',num2str(data.pp_axis),' ]']);sl=sl+2;      
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dp_type);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dp_np);sl=sl+2;
        settinglist{sl}(66:80)=sprintf('%15.5g',data.dp_res);
 
        
geneparalist ={  '',...
        '  -------------------------------------------------------------------------------',...
        '                                 Gene parameters',...
        '  -------------------------------------------------------------------------------',...
        '',...
        '   Total number of genes:                                                        ','','',...
        '   Gene No.  Description           Maximum        Minimum       Type    Chrom ID ',''};
        gn = data.ngenes;
        geneparalist{6}(26:28)=sprintf('%3g',gn);
        
        for i=1:gn
            makespace={...
            '',...
            '                                                                                 '};
            makespace{2}(5:7)=sprintf('%3g',i);
            makespace{2}(14:32)=sprintf('%-19s',data.descgene{i});
            makespace{2}(36:46)=sprintf('%-11.5g',data.gd_max(i));
            makespace{2}(51:61)=sprintf('%-11.5g',data.gd_min(i));
            
            typelist = {'Integer','Linear','Exp.'};
            makespace{2}(65:71)=sprintf('%-7s',typelist{data.gd_type(i)});
            makespace{2}(75:77)=sprintf('%3g',data.gd_cid(i));
            
            geneparalist = [ geneparalist  makespace ];
        end            
        endofgeneparalist ={...
        '','',...
        '  -------------------------------------------------------------------------------',...
        '                               End of gene parameters',...
        '  -------------------------------------------------------------------------------',''};
        geneparalist = [ geneparalist endofgeneparalist ]';
        
        
        
    
fitfunlist ={  '',...
        '  -------------------------------------------------------------------------------',...
        '                            Fitness function information',...
        '  -------------------------------------------------------------------------------',...
        '',...
        '   Filename :                                                                    ','',...
        '   Path     :                                                                    ',...
        '                                                                                 ','',...
        '   Number of objective functions :                                               ','',...
        '   Optional data for fitness function :                                          ','','',...
        '  -------------------------------------------------------------------------------',...
        '                          End of fitness funtion information ',...
        '  -------------------------------------------------------------------------------',''};

        fitfunlist{6}(16:80)=sprintf('%-65s',['''' data.ff_name,'.m''']);
        fln = length(data.ff_path);
        if fln < 65
            fitfunlist{8}(16:80)=sprintf('%-65s',['''' data.ff_path '''']);
        else 
            for j=62:-1:21
                if data.ff_path(j) == filesep;
                    break
                end
            end
            fitfunlist{8}(16:80)=sprintf('%-65s',['''' data.ff_path(1:j),'...']);
            fitfunlist{9}(19:80)=sprintf('%-62s',[data.ff_path(j+1:fln),'''']);
        end
        fitfunlist{11}(41:80)=sprintf('%40g',data.fp_nobj);
        if isempty(data.ff_data); flag = 'none';else flag = data.ff_data; end;
        fitfunlist{13}(41:80)=sprintf('%40s',flag);
        
        
switch hObject 
    case setH.gaoppara
        set(setH.gaoppara,'Fontweight','bold','Foregroundcolor','k');
        set([setH.genepara setH.filepara],'Foregroundcolor',[.6 .6 .6],'Fontweight','Normal');    
        set(setH.listbx,'String',settinglist);
    case setH.genepara
        set(setH.listbx,'String',geneparalist);
        set(setH.genepara,'Fontweight','bold','Foregroundcolor','k');
        set([setH.gaoppara setH.filepara],'Foregroundcolor',[.6 .6 .6],'Fontweight','Normal');
    case setH.export

        % default filename
        filename = strcat(data.ff_path,data.ff_name,'_setting');

        [filename,filepath] = uiputfile([filename '.txt'],'Save as');   % choose save path

        if isnumeric(filename) | isnumeric(filepath)    % if the filename or path is empty
            return;                                     % do nothing
        else 
            fid = fopen([filepath filename],'w+');      % otherwise, save
            
            fitfunlist = fitfunlist(1:length(fitfunlist)-4);  
            % find goset main window
            figHandles = allchild(0);
            gosetmain = findobj(figHandles, 'flat', 'Tag', 'GOSET GUI');
            viewparaheading={'',...
            '  ===============================================================================','',...
            strcat(['                                   ',get(gosetmain,'Name')]),'',...
            '  ==============================================================================='};
            fitfunlist = [ viewparaheading fitfunlist];
            
            for i=1:length(fitfunlist)
                fprintf(fid,'%s',[fitfunlist{i} char(13) char(10)]);
            end
            geneparalist = geneparalist(1:length(geneparalist)-4);
            for i=1:length(geneparalist)
                fprintf(fid,'%s',[geneparalist{i} char(13) char(10)]);
            end
            settinglist(length(settinglist)-3:length(settinglist))={...
            '  -------------------------------------------------------------------------------',...
            '                                End of parameters',...
            '  -------------------------------------------------------------------------------',...
            '                                                                                 '};
            settinglist{length(settinglist)}(1:80)=sprintf('%80s',datestr(now,0));
            for i=1:length(settinglist)
                fprintf(fid,'%s',[settinglist{i} char(13) char(10)]);
            end
            fclose(fid);
        end
    otherwise
        set(setH.listbx,'String',fitfunlist);
        set(setH.filepara,'Fontweight','bold','Foregroundcolor','k');
        set([setH.gaoppara setH.genepara],'Foregroundcolor',[.6 .6 .6],'Fontweight','Normal');
end

% -------------------------------------------------------------------------
%   Numerical input test 
% -------------------------------------------------------------------------
function numericinputtest(hObject, handles)
% type      1: Postive real     2: Probability   3: Positve integer

set(handles.startbtn, 'Userdata', 1);  % use 'Userdata' of 'startbtn' field as the flag

input = get(hObject,'String');
value = str2num(input);
type = get(hObject, 'Userdata');

% find current fieldname
fn = fieldnames(handles);
for i=1:length(fn)
    if eval(['handles.' fn{i} '== hObject' ])
        currentfield = fn{i};
        break
    end
end
    
data = getappdata(gcbf, 'Userdata');

switch type 
    case 1      % nonnegative real
        if isempty(value) | value < 0
            uiwait(errordlg('Input must be a nonnegative number','Error','modal'));
            set(hObject, 'String', eval(['data.' currentfield]));
            set(handles.startbtn,'Userdata',0);
        end
     case 2     % [0, 1]
        if isempty(value) | abs(value-0.5)>0.5
            uiwait(errordlg('Input must be a value in [0, 1]','Error','modal'));
            set(hObject, 'String', eval(['data.' currentfield]));
            set(handles.startbtn,'Userdata',0);            
        end
     case 3     % nonnegative int
        if isempty(value) | value < 0 | abs(round(value)-value) > 0
            uiwait(errordlg('Input must be a nonnegative integer','Error','modal'));            
            set(hObject, 'String', eval(['data.' currentfield]));
            set(handles.startbtn, 'Userdata', 0);
        end
     case 4     % pos int
        if isempty(value) | value <= 0 | abs(round(value)-value) > 0
            uiwait(errordlg('Input must be a positive integer','Error','modal'));            
            set(hObject, 'String', eval(['data.' currentfield]));
            set(handles.startbtn, 'Userdata', 0);
        end
end

% -------------------------------------------------------------------------
%    Checking optional data of the fitness function for appropriate setting 
% -------------------------------------------------------------------------
function [data,datafiledisp] = checkoptdata(data)
% Check optinal data of the fitness function 
% and define 'data.ff_data', 'data.ff_data_store', and
% datafiledisp(used for handle.ff_data)

if isstr(data.ff_data)
    if exist([data.ff_path data.ff_data],'file') == 2;  % Exist as a MAT-file in fit func folder                        
        datafiledisp = data.ff_data;                    % as a valid data file name
    elseif ~isempty(data.ff_data_store)
        if strcmp(questdlg(...              % reconfirm loading the default setting
            ['There is a saved optional data for the fitness function ''',data.ff_data,....
            '''',char(10),'Proceed and load it into workspace?',char(10),...
            'The saved data will be lost by selecting ''No''.'],...
            ['Found a saved optional fitness function data''',data.ff_data,''''],'Yes','No','Yes'),'Yes')
            assignin('base',data.ff_data,data.ff_data_store);
            datafiledisp = data.ff_data;     
        else
            uiwait(msgbox('Optional data for the fitness function is set to ''None''.','Warning','warn','modal')); 
            datafiledisp = 'none';

        end        
    else
        uiwait(msgbox('Invalid optional data for the fitness function.','Error','Error','modal'));
        datafiledisp = 'none';
        data.ff_data = [];
        data.ff_data_store = [];
    end 
else
    if isempty(data.ff_data);
        datafiledisp = 'none';
        data.ff_data = [];
        data.ff_data_store = [];
    else
        datafiledisp = ['[' num2str(data.ff_data) ']'];
    end
end
% -------------------------------------------------------------------------
%   END OF  GOSET
% -------------------------------------------------------------------------


% === A button for testing ================================================
function testbtn(hObject, handles)

data = getappdata(gcbf, 'Userdata');
field ='rp_lvl';
%set(handles.testbtn,'string',['GAP.' field ' = ' eval(['data.' field])  ]);
set(handles.testbtn,'String',num2str(data.rp_lvl));

%  Copyright 2010 - Scott Sudhoff 
% 
%  The program is distributed under the terms of the GNU Lesser
%  General Public License(GNU LGPL). 
% 
%  This file is part of GOSET
% 
%  GOSET is free software: you can redistribute it and/or modify
%  it under the terms of the GNU Lesser General Public License as published
%  by the Free Software Foundation, either version 3 of the License, or 
%  (at your option) any later version.
% 
%  GOSET is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU Lesser General Public License for more details.
% 
%  You should have received a copy of the GNU Lesser General Public
%  License along with GOSET.  If not, see <http://www.gnu.org/licenses/>.

